/pol/ - Politically Incorrect - Archive - 4chan
Description: "/pol/ - Politically Incorrect" is 4chan's board for discussing and debating politics and current events.
Keywords: imageboard,politics,current events,debate,politically incorrect

[a / b / c / d / e / f / g / gif / h / hr / k / m / o / p / r / s / t / u / v / vg / vm / vmg / vr / vrpg / vst / w / wg] [i / ic] [r9k / s4s / vip / qa] [cm / hm / lgbt / y] [3 / aco / adv / an / bant / biz / cgl / ck / co / diy / fa / fit / gd / hc / his / int / jp / lit / mlp / mu / n / news / out / po / pol / pw / qst / sci / soc / sp / tg / toy / trv / tv / vp / vt / wsg / wsr / x / xs] [Settings] [Search] [Mobile] [Home]
Board
▼ Settings Mobile Home
/pol/ - Politically Incorrect
Return Catalog Bottom

[Return] [Catalog] [Bottom]

#### Displaying 3,000 expired threads from the past 3 days

No. | Excerpt |
389085363 | Saudi Arabia considers selling its oil in Chinese yuan insted of the petro dollor https://thehill.c… | [View]
389081797 | >white kids | [View]
389075240 | Putin: What the hell did he learn/do in the KGB? He looks scary. | [View]
389075678 | The moment jews were able to just print money instead of relying on taxes was the moment they became… | [View]
389085324 | >be fat fuck talking head >have highest rated show on cable news >do a show exposing the fe… | [View]
389085158 | IT'S FINALLY A GOOD THING PELOSI IS A CONTROL FREAK.: Apparently she drunkenly demanded to be i… | [View]
389073754 | TAIWAN IS NOT A COUNTRY regardless what American Jew media says Kike niggers will not succeed in for… | [View]
389085264 | oi fellow goyim, what are the new dog whistles so I, a fellow white supremacist, may identify my kin… | [View]
389082489 | Why is Disney Pushing this Shit All The Way?: Enough already.. | [View]
389083030 | The game is over, as I am fond of saying.: The bankers won. They are in control of the Pikes Peak b… | [View]
389085148 | The elites hate white working people more than anything else in the world. | [View]
389083209 | https://www.ewtn.com/radio/listen-live | [View]
389080062 | /pol/ music thread: beethoven's symphony nr. 9 the best recording that i know of yet. if you th… | [View]
389083863 | convince me niggers aren't subhuman, impulsive primates with no cognitive ability to function i… | [View]
389079622 | This is 100% true (and that's a good thing!) I recently moved to a barn in the middle of nowher… | [View]
389032840 | /MOG/ - Monkeypox Outbreak General #129 - 3 Deaths: 23,690 cases in 78 countries / 3 deaths >Monk… | [View]
389082582 | >Took 2 doses because 2 free days off >Never have Covid What is your excuse?… | [View]
389082580 | Will God curse me if I continue working on Sunday? I do freelance work and most weekends are usually… | [View]
389077743 | What should his punishment be?: Anthony Steven Fauci is responsible for the mass-murder of untold mi… | [View]
389078696 | So, uh...: Russians are fleeing their own country at a record rate. Why are they doing this if Russi… | [View]
389084682 | What are you going to do: To help save the White Race today? 1488 | [View]
389067216 | >THE US WILL SAVE EUROPE, LOL | [View]
389084362 | white genocide isn't real but it should be | [View]
389082913 | >bro you can't just tell women, gay people, immigrants, black people, fat people, atheists, … | [View]
389082747 | DAY 177 of the russian 3 day special military operation | [View]
389081210 | Why do people tell me my eyebrow is perfect? | [View]
389082966 | > I HAVE HERE IN MY HAND A LIST OF 205—A LIST OF NAMES THAT WERE MADE KNOWN TO THE SECRETARY OF S… | [View]
389077852 | You just don’t ‘get it’ >Trump ‘lost’ 2020 >All major courts swat down any lawsuit without loo… | [View]
389058566 | Why do they all have the same look? | [View]
389079367 | QUEEN ELIZABETH IMMIGRATING TO SOUTH KOREA: IT'S HAPPENING > Cherishes memories of visiting … | [View]
389084126 | stabs wife 30 times when she asked for divorce: A man was arrested Wednesday after police said he st… | [View]
389079607 | How do I cure insomnia without pills?: I haven't had had a good sleep in months and that was wh… | [View]
389071706 | Brit/pol/: >Grammar schools, Northern Rail and Love Island - key takeaways from first Tory leader… | [View]
389079295 | Nuke Switzerland: https://www.bloomberg.com/news/articles/2022-07-29/swiss-exports-to-russia-surge-i… | [View]
389073628 | Make sure you are vaccinated.: This is a friendly reminder that anti-vaccine narrative is promoted b… | [View]
389083122 | Do you love the United Mexican States? | [View]
389077564 | Wypeepo: Oh Whoaw Japan is so WEEEIRD dude, such an exotic culture and shieet, is that a heckin… | [View]
389074573 | Why do so called right wing and conservative americans simp and defend the ira so much, a group that… | [View]
389084033 | Friends, Indians and countrymen, lend me your ears: This is the Indian century. Brothers here lurkin… | [View]
389075827 | Is subhumanity cultural or genetic? | [View]
389083895 | Draft Publication Date: May 16, 2022 Author: Joshua Liu 1 How mass and social media ― and further th… | [View]
389081728 | GET THE FUCK IN HERE: ITS FUCKING HAPPENING https://www.bbc.com/news/health-62350022 | [View]
389080034 | What's /pol/ take on TIK? | [View]
389080204 | Shitskin tried to grab a bong child!: In Home Bargains | [View]
389078070 | The fact that both adults and children in China literally worship Mao Zedong like a god and see Mao … | [View]
389083092 | Rebound Cases: For other vaccines are there things like 'rebound cases' or the term they were using … | [View]
389083582 | Is this the future?: https://tl.net/forum/starcraft-2/597177-tsl9-week-1-preview-opening-act… | [View]
389083422 | Is the last wave of feminism the first wave of neo-misoginy? Why are Women telling me to disregard c… | [View]
389074020 | >hmm, why don't men want to defend their country anymore? | [View]
389080372 | > | [View]
389076852 | Niggress: She's criminally incompetent and needs to go back. Fucking dumbshit low IQ monkey… | [View]
389083302 | Bong bros WTF?: The UK will not let Venezuela have its own gold back. 'London's High Court has… | [View]
389083078 | The youth went from tech startup to gang start up: Wtf happened here? How do we go from, lookeet muh… | [View]
389081465 | MAJORITY OF EUROPE IN A DROUGHT: Why is nobody discussing the consequences of this? | [View]
389081861 | Steven Anderson is a snake and a false teacher | [View]
389077479 | Reminder to all the Nazis that you'd be speaking German if we didn't stop Hitler | [View]
389077453 | NO REFUNDS PT IV - SCIENCE DOESNT CARE ABOUT YOUR FEELINGS YOU HAVE NO T CELLS EDITION: Dead vaxxed … | [View]
389082880 | Why did the glowniggers kill spreadsheet anon?: What is in this spreadsheet that terrifies them? Spr… | [View]
389082855 | Ball Cutting - SBU False Flag: I am carrying on from a German anon's work yesterday. Don't… | [View]
389079661 | How do we solve the Jew Pedophile problem? | [View]
389082748 | The Glasgow Crisis: Hypothesis: The usual suspects contribute; diet, exercise, lack of vitamin D, po… | [View]
389078164 | Why is Lithuania the only country to call Finland by its actual name? Suomija | [View]
389075119 | Americans be like: >Yes, I love my government and know it protects me, that's why I pay 45% … | [View]
389074316 | Why do liberals and commies like to claim that Natsocs are capitalists when the nazis constantly den… | [View]
389066184 | The moment Nancy Pelosi steps one quarter of an inch of her putrit rotten foot inside Taiwan, you wo… | [View]
389081962 | I aggressively dislike Arm*nians, K*rds and Gr**ks. | [View]
389080465 | People are waking up about the jews | [View]
389068917 | ?????????????? | [View]
389077683 | As a huwhite male, I love Middle Eastern, Turkish, and Asian women the most. In terms of input and o… | [View]
389079976 | right wing individuals love taking that which is either mocking them or falsely associated with them… | [View]
389079985 | Doesn't feel so good, huh?: https://twitter.com/katelinthicum/status/1552306358053126149… | [View]
389082175 | Dios mio. la creatura. | [View]
389082209 | Poland: How could the nazi ''invade'' poland when the country didn't exist … | [View]
389058002 | Europeans do you have such things in your house/flat? Do you plan to buy it? | [View]
389068289 | Complete proof that 40,000 Russian army, Guard, Donbass, Chechnyan and Wagner have died: https://www… | [View]
389082111 | Question to the anons who are parents -: How are you keeping your children safe from Globohomo?… | [View]
389078085 | Boomer goes crazy and mass stabs zoomers who were river tubing: >A 52-year-old Minnesota man has … | [View]
389080414 | What was this demonic ritual happening at the opening ceremony of the commonwealth games? They are c… | [View]
389081078 | Can we discuss the average /pol/tards complete inability to spot a photoshop? Pic related; I see all… | [View]
389081242 | Why does Israel look so clean and modernized compared to parts of Britain?: Was watching a documenta… | [View]
389079313 | Why does the UN even exist? | [View]
389076396 | Who is this dude and why do I see his tweets constantly on Reddit? | [View]
389081488 | Clyde appreciation thread: Most spree shooters choose easy difficulty but Clyde chose ultra violence… | [View]
389071942 | Share some truth about Israel: The United States pays for 20% of Israel's military budget while… | [View]
389081512 | Ukranian UAV wounds five: >be russia >fail to achieve air supremacy against a country that has… | [View]
389073805 | This is a SIG MCX Spear. You know what that is? It's a polymer gun made in New Hampshire. It do… | [View]
389073136 | /uhg/ - Ukraine Happening General #3564: Prev:>>389064596 ▶Day: 158 - Daily battlefield assess… | [View]
389081291 | The Pelosi Taiwan situation | [View]
389081577 | Yamato won the Nakama war. Denialchuds lost. | [View]
389081563 | A Short Prehistory of Ccru The question of 'the' history of the Ccru is problematic, not l… | [View]
389079613 | Nothing in politics matters anymore. | [View]
389080500 | Racism: Racism is the biggest problem that humanity is facing at the moment, not the climate change … | [View]
389081457 | Rich liberals and kikes think they're gods but they are as mortal as we. | [View]
389080433 | Boomers are becoming homeless as rent keeps rising. Who’s fault is this? How do I get a chubby femal… | [View]
389078653 | Why don't they allow genuine and productive Nationalsocialist discussions? They have no problem… | [View]
389042313 | Why is /pol/ obsessed with Japan? | [View]
389081026 | Introducing the new DEM candidate for POTUS, fully approved by Biden AND Harris. ALL HAIL THE KING. | [View]
389078812 | Great Way to STOP Monkey Pox: Stop the spread. Don't spread your cheeks! | [View]
389079644 | Is Putin the surrogate father figure of /pol/? | [View]
389077770 | Redditors and zog apologists think they are smarter than 130+ I.Q. PhDs. When the data bears out tha… | [View]
389072032 | How hard is it to fight your 'inner American' for you?: Did a 90 min bike ride in the morning, liste… | [View]
389080438 | Stop monkeypox, stop the spread.: We stop malaria by killing mosquitos, lime disease killing tics. E… | [View]
389074337 | Owen Benjamin is the path to defeating globohomo within the United States | [View]
389073023 | /chug/ - Comfy Happening in Ukraine General #4764: Previous: >>389064542 Timeline /tug/: http… | [View]
389067548 | we gave women voting rights | [View]
389069656 | Soul map of Europe: Which people on Europe have the most soul (conscientiousness, affective empathy,… | [View]
389071484 | Emmett Till: What am I being lied to about this case? If I learned anything from Trayvon Martin/Mike… | [View]
389069957 | >Average Russians do love their neighbours | [View]
389080556 | >half the country destroyed, needs a trillion dollars to repair that will never arrive >hundr… | [View]
389080276 | CHINA WILL PAY FOR THIS | [View]
389077365 | The liberal agenda keeps destroying the world. | [View]
389079053 | How did the left become convinced that abortion rights are a legitimate ethical issue? | [View]
389080228 | Eurobros did this happens to your country ? In America yes. | [View]
389075512 | Was this already memory holed by the mainstream globohomo media? | [View]
389077572 | Blackpill and hypergamy, if they are completely real, is the best argument for transhumanism and pos… | [View]
389080019 | /CVBQ/ Covid-vaccine Bioweapon General: Awakening 4chan NoObs Edition>: If you still don't k… | [View]
389079458 | OHHH NO NO NO: Facts. | [View]
389079152 | Steve Bannon: If Trump doesn't bring him back into the fold and gets rid of Kushner, I can… | [View]
389077394 | Nice | [View]
389079585 | Traitor woman theory: Once you see this pattern, you behave differently. The amount of women involve… | [View]
389077319 | uh oh long covid bros: did we get too cocky? | [View]
389073558 | >democrats makes americans look like pussies again | [View]
389075766 | >loses to Afghanistan >loses to Russia >loses to China >loses to the bike footguard… | [View]
389079602 | /pol/ btfo: Gotcha | [View]
389079535 | Wish I could redpill these chinks that privilige means genetic superiority. > inb4 bugs lie about… | [View]
389076543 | JOE BIDEN CAUGHT COVID FOR THE SECOND TIME: Obviously I am not the part of the stupid anti vax commu… | [View]
389075068 | Western sanctions against Russia are the most ill—conceived and counterproductive policy in recent i… | [View]
389077803 | I took two doses of Pfizer and my job is brutal and I work under the heat 7 days a week. Can I pleas… | [View]
389074085 | What is going on in California? | [View]
389077060 | OPERATION: LOCKKKDOWN: Monkeypox is making the rounds, only a matter of time before the globalists f… | [View]
389051561 | LOTR is made by a Christian not a LARPagan: >'The Lord of the Rings is of course a fundamentally … | [View]
389076707 | What is so special about germans?: >muh Hitler? Lost, gone, never coming again. Cope. >muh Hig… | [View]
389076456 | This is what the establishment truly fears | [View]
389078428 | Act of Public Lewdness live-streamed in Newark NJ: Police in Newark are searching for a woman who th… | [View]
389078925 | Where did he go? | [View]
389078545 | How do we reclaim socialism from (((marxists)))? They've confused it's meaning and have tu… | [View]
389076497 | HAPPENING!! Meat Prices to Hit Sky High Prices!!: ITS OVER ANONS!! We will require to eat Impossible… | [View]
389076075 | What is the difference between PCR and Antigen tests?: I need to take one tomorrow. I Just want to k… | [View]
389073733 | HOW THE FUCK WERE WHITE PEOPLE COLLECTIVELY BRAINWASHED INTO HATING THEMSELVES. WE DESERVE A RIGHT T… | [View]
389078714 | I talked with God through TempleOS system and he told me that niggers and mutts are mostly going to … | [View]
389075933 | When will the hold-outs admit that Russians are literal niggers?: This is some 3rd-world tier Somali… | [View]
389078043 | Why did they do it? | [View]
389059670 | Naomi Seibt (born 18 August 2000) is a German political activist, known as a climate change denier a… | [View]
389075551 | Why can the right no longer produce quality clickbait that brings views? All I see is rightoids maki… | [View]
389077651 | /pol/ Meta thread- The Final Solution to the Gay Gypsy Question: Anons, if mods won't rangeban … | [View]
389072019 | i cant get a wamen because my standards are too high: Anons, I think I broke myself. I have set such… | [View]
389077045 | Why does the law of supply and demand always stop working when it comes to workers and wages? | [View]
389071129 | Are non-whites generally jealous of white beauty?: I feel like all racial tension stem from simple s… | [View]
389061926 | americans consume the majority of the world ressources, how can we stop them and save the planet | [View]
389075726 | BIG P | [View]
389078203 | You Wouldn't Patent the Sun: Debunking the Myth of Phase Cancellation OR How to Cook a Chicken … | [View]
389069268 | Why are women such fucking attention and virtue signaling whores in our time? Look at pic related. H… | [View]
389043165 | How do climatefags respond to this? | [View]
389057175 | >I am Kamala Harris, my pronouns are she and her, and I am a woman sitting at the table wearing a… | [View]
389072794 | They stopped her?? | [View]
389056067 | WHAT ARE THE POLITICAL IMPLICATIONS OF WANTING TO LIVE ON A FARM ?: I just want to relax | [View]
389077518 | My mom: Just talked to me about an Ethno-state. Wtf did you tell her anons? | [View]
389077012 | Wake up at 5am. Drink coffee eat mangos and avocados for breakfast. Smoke pipe on back porch exchang… | [View]
389071544 | How would Japan help out the USA if we go to war with China? | [View]
389077395 | You may not like it: But this is what Dugin's Eurasianist master race looks like. | [View]
389073069 | Kamerad*Innen aufgehorcht: Buy electric radiators for the upcoming winter to fuck with the power sup… | [View]
389076585 | >Brush your fucking teeth goyims New degenerate shit ad with a fucked up fat nigger with fucked u… | [View]
389076035 | This is the future of the white race. Your son will look like his filipino mother and post 'made for… | [View]
389071158 | SLOPPY JOB , SBU: After the hysteria by butthurt belters, let's look at this rationally >UAF… | [View]
389077294 | if china goes to war/tries to take over taiwan like russia did with ukraine, will the greedy west fi… | [View]
389077611 | If we were more multicultural and less nationalist the fascist overreaction to covid wouldn't h… | [View]
389076782 | Has sub-Saharan Africa ever contributed anything of scientific or cultural significance to the outsi… | [View]
389076114 | Are people dying from the injections?: What is the evidence that a great number of people have died … | [View]
389077153 | Jannies just woke up...: It's almost 11am EST. After doing a 10:30 wake and bake, slamming a mo… | [View]
389075337 | Daily Harvest poisoned people: >be Woman entrepreneur >see huge profit opportunity in health f… | [View]
389057368 | aus/pol/ - dick pusey edition: >https://www.news.com.au/finance/money/costs/ozharvest-australia-s… | [View]
389068377 | Libertarianism is in itself a self-defeating ideology because it 'tolerates' and enables its opposit… | [View]
389074482 | When did you realize true rightism is virtually non-existent in the West today and all we have is li… | [View]
389070800 | JP posting: What does /pol/ think about Jordan Peterson? | [View]
389077379 | Wait, are you telling me, all I have to do to achieve the perfect weight is to not eat anything for … | [View]
389073519 | 2 eggs and bacon. | [View]
389077339 | Women: why are they like this ? | [View]
389073996 | /nsg/ Z National Socialism General Z: >I acknowledge the existence of the Israeli nuclear arsenal… | [View]
389040870 | If you still don't know the covid vax is a Bio-weapon -: Look what Big Pharma and the Gov. did … | [View]
389075131 | The amish people: I've come to the realisation that the amish people were right and that everyo… | [View]
389073016 | What are the connections between COVID and Monkeypox? | [View]
389062769 | Remember, a state will never allow its symbols to be mocked and will do everything it can to keep it… | [View]
389074026 | How Did a Two-Time Killer Get Out to Be Charged Again at Age 83?: https://dnyuz.com/2022/07/30/how-d… | [View]
389076948 | What do the jews hope to accomplish with this? Is there anything that can be done? | [View]
389070967 | Why is it specifically Central-Eastern Europeans & Eastern Europeans like Baltoids that a relent… | [View]
389070658 | Niggas be like: >capitalism breeds innovation! The (((innovation))):… | [View]
389075222 | 4chan didnt used to hate trannies.. You guys just hate who the jews tell you to hate these days dont… | [View]
389071738 | Why is neither party pro-union and pro-domestic industry anymore? The Republicans refuse to do anyth… | [View]
389050636 | Why aren't you defending your country?: You should serve your country no matter what. If you do… | [View]
389071928 | What do we do about the Jew Pedophilia problem? | [View]
389076150 | Is USA a Brazil, fat and more degenerate? | [View]
389075489 | Now that the USA has chickened out of visiting the ROC and have therefore displayed to the world tha… | [View]
389074829 | what did Zelensky mean by this? | [View]
389076492 | These guys will be send in next to fight the ukrainian jew nazis. Wish them luck /pol/ :) >second… | [View]
389076443 | >I won’t get monkeypox Think again doubters. Old man almost ducked off | [View]
389076378 | they have zis crunchinezz. Its oh zo irrdiziztable.: vyou should trdy vone! Its good for youv! Vreal… | [View]
389062876 | U.S. bows to Chyna: >announce Taiwan trip >Xi says no >cancel on Taiwan trip Why is the U.S… | [View]
389074267 | /pol humor thread: Ghost of Kyiv, CCP Sleeper agent Samuyil Hyde edition | [View]
389073745 | Kissinger is dead: S to spit, so long you fat fuck | [View]
389074719 | Putin: If /pol/ hates pedophiles then why do you defend him? | [View]
389076234 | Thoughts? | [View]
389073858 | China has surpassed America: >Pelosi is not going to Taiwan >Biden has previously stated that … | [View]
389074426 | Embrace tradition: Smash degeneration | [View]
389073289 | Why can’t Americans mind their own business and stop inciting wars in Asia? | [View]
389072467 | too much negativity here try to be a little more positive | [View]
389073594 | Any good pre-Jewish Hollywood movie recommendations?: Like Dracula 1931? | [View]
389062858 | >toddler makes sound or moves in a way that a pitbull doesn't like >pitbull proceeds to t… | [View]
389075842 | What does /pol/ think about non-white ethnonationalists who happen to be socialists? Are they the eq… | [View]
389049291 | they're proto-caucasian black rather than jungle black | [View]
389074084 | Cultura Shock: So im helping this Chinese girl with her English on Whatsapp (we met on redditerino) … | [View]
389075742 | southwest japan under snow monkey assault: Nearly a month of constant attacks, now up to 58 confirme… | [View]
389074789 | /meg/ MANDELA EFFECT GENERAL: In my old reality the Soviet flag never had a star above the hammer an… | [View]
389074582 | Do women owe me sex? | [View]
389075547 | So much this. Date a girl the same age or older you fucking creeps. 26 and 21, predatory as fuck. 5 … | [View]
389075077 | What are the political implications of every single person on this planet thinking they’re right? Ev… | [View]
389074124 | 'Boomsticks': >no threads talking about the recent 'Boomstick' ban >not even on /k/ Fuck feder… | [View]
389064162 | lmao greeks explain yourselves https://www.youtube.com/watch?v=03ZK73LXhbI | [View]
389074942 | No CPAC hype bread?: CPAC hype bread. https://www.youtube.com/watch?v=0sLjOVC7ycY | [View]
389068033 | 22 y looks like 8: https://www.youtube.com/watch?v=s7In-KGxduU What would happen if it were legal to… | [View]
389073654 | I am not Jewish, but I can make you believe that I am simply by making the statement: 'I am not Jewi… | [View]
389062995 | FATHER WEPT AS HIS SON CAME IN TO TESTIFY AGAINST HIM ON JAN 6 CASE: Reffitt wept uncontrollably whe… | [View]
389073263 | >here's your army fighting western-degeneracy bro | [View]
389074528 | i am forgotten | [View]
389074605 | Is CA a trash state now offically?: Besides the weather, and northern CA - Why stay? | [View]
389073958 | Islam - 1 Judeo-Christianoty - 0 | [View]
389073602 | IT'S OVER: Hashtag Ukraine has clearly won. Russia stand no chance. | [View]
389043259 | I hope everyone in America has started learning Russian: Speaking of learning languages, what is the… | [View]
389074521 | Monkeypox can live on cash for up to two weeks | [View]
389068333 | Question for Māori on /pol/.: Can I live in Te Onetapu? | [View]
389073775 | Poland, Romania, Hungary, Slovakia What's your opinion on Ukrainian refugees? | [View]
389072202 | I'm so tired of seeing this senile old pant shitter and this dumb cackling hag. How did we fuck up t… | [View]
389056687 | NO REFUNDS PT III - YOU HAVE NO T CELLS EDITION: Dead vaxxed walking. From last thread >>38904… | [View]
389074296 | /nsg/ Z National Socialism General Z: >I acknowledge the existence of the Israeli nuclear arsenal… | [View]
389074005 | Does anyone here larp as Jewish as a way to guilty trip liberals? | [View]
389073459 | This is mural at the local part. What did they mean by this? | [View]
389070033 | You’re not immune to propaganda: >”they want to kill billions and leave only 500 million!” >li… | [View]
389063504 | Robin Hood is getting a reboot: Say hello to 'Robbin' Hood.' Interesting reboot to make as braz… | [View]
389072884 | Brits, sign my petition please: https://petition.parliament.uk/petitions/621167/sponsors/new?token=1… | [View]
389072719 | I thought you guys had free speech? Why is this even going to trial when the man simply expressed hi… | [View]
389062020 | There is no bigger hypocrite on this planet than the jew. | [View]
389073486 | Beyonce is now an official sponsor of the armed forces of Ukraine | [View]
389071934 | what dose /pol/ think of ISIS?! | [View]
389060518 | KINGS OF EUROPE: We Germans can be considered the high elves of the WHITE RACE. The Japanese of Euro… | [View]
389068922 | they are not sending their best: or so it goes https://www.reddit.com/r/PublicFreakout/comments/w9ft… | [View]
389071675 | QUESTION: Why did Trump pardon Kodak Black, Lil Wayne and half of Jared Kushner’s synagogue — but no… | [View]
389065504 | Unknown Earth: As long as your argument is within parameters thread will stay up. If you talk about … | [View]
389059173 | ITS HAPPENING!!!: TAIWAN IS CONFIRMED THE NEXT KYIV. #ISTANDWITHTAIWAN | [View]
389070284 | Wait, what? Models can be wrong know? I trusted my life to this shit! | [View]
389068711 | So, you really wouldn't fuck a black queen due to....? Uhhh... Ignorant racism? Welp, more for … | [View]
389071321 | Why white women are genetic trash?: I'm specifically talking about Northern Europe, those women… | [View]
389073427 | Russians of /pol/, is dying for Putin worth it?: Why do you support this? >At first sight, it loo… | [View]
389057643 | /ptg/ - PRESIDENT TRUMP GENERAL - RISE AND SHINE EDITION: PRESIDENT DONALD J TRUMP @POTUS45 https://… | [View]
389073440 | Are you a Russia shill?: You think Russia is ideal in ANY way? - It's top 10 in the world for … | [View]
389073766 | At what point did the right go full-retard? When did they jump the shark? I'm inclined to belie… | [View]
389071680 | Brit/pol/ Up The TERFs edition: >NHS Scotland is facing 'perpetual winter' with ongoing crises ht… | [View]
389074452 | crossdressing in serbia: nobody ever called me tranny irl beside 4chedditor seething smrds why are m… | [View]
389074588 | I don't understand why white western women are like this? I thought that a single white woman w… | [View]
389062476 | Refute Homosexuality without using jewish fairy tales like the bible or gospel I give you 10secs. Un… | [View]
389050234 | T A V I S T O C K Policy Seminar: Whiteness - A problem for our time: Do you even know who T A V I S… | [View]
389071467 | Nigger webm thread: Post wmbms of niggers doing wild shit like humping and dancing and spear chuckin… | [View]
389073546 | If you are not homeschooling your children then you're a terrible parent because schools are ce… | [View]
389072517 | Is there a political solution to education in America? How do we solve it? We're graduating hig… | [View]
389072769 | Political implications of 4chan becoming the scapegoat of everything?: https://apple.news/nowPlaying… | [View]
389063033 | What sane parent would have his own son's penis mutilated on demand? | [View]
389048485 | Greta's getting more womanly by the hour. If she ditches the shoes and goes barefoot, and swaps… | [View]
389073056 | What should his punishment be?: Considering that Anthony Steven Fauci is responsible for the mass-mu… | [View]
389065549 | What is french culture centered around? https://www.youtube.com/watch?v=lgHGU8gqz9U | [View]
389069642 | >literally do nothing wrong >go to jail Why are things like this?… | [View]
389073117 | Is working out more for right wing studs? | [View]
389073238 | NEVER GIVE UP NEVER SURRENDER | [View]
389071357 | Where do I find an EPUB of this? | [View]
389053451 | Reminder that Ukrainian men are dying for their country and for a future that does not exist as all … | [View]
389073283 | Do you still hate Islam?: >NO PLEASE I'M SORRY I'LL STOP BEING GAY I LOVE ALL-ACK… | [View]
389072995 | >when you marry | [View]
389072471 | Take back skate boarding from the left. | [View]
389073204 | German labour front: How do we revive it? | [View]
389072597 | Warning to all vatniks: Official statement of the temporary acting commander of the 'Azov' regiment,… | [View]
389073152 | Say some Gangsta is missing your Fly Girl | [View]
389069907 | How likely is it the Dem’s win midterms?: After the cheating accusations from 2020 it’s incredibly l… | [View]
389067434 | Mossad Agent Bald and Bankrupt caught: Now he does damage control for the israeli intelligence agenc… | [View]
389071818 | 837000 to house a single homeless person: Without taxes, who would build the roads? Just wageslave a… | [View]
389071775 | What you have to explain your white children everyday before they start going to school: I know many… | [View]
389068885 | OMAGOD WHITE SKIN IS THE BEST LOOK AT MY BEIGE-WHITE SKIN OOOH ISN'T IT GREAT OOH YEAH WHITE PE… | [View]
389062635 | I HATE USA: I hate the niggers. 60 million violent, impulsive, low IQ disgusting niggers with guns. … | [View]
389067776 | There is an epidemic of women who aren't able to make milk. They need to supplement with baby f… | [View]
389064542 | /chug/ - Comfy Happening in Ukraine General #4763: Previous: >>389058879 Timeline /tug/: http… | [View]
389071562 | I hope you understand that the moment jews can just print money instead of relying on taxes is the m… | [View]
389043204 | HR is watching Recruitment is watching Watch what you post online /pol/, it could cost you your care… | [View]
389064596 | /uhg/ - Ukraine Happening General #3563: Prev:>>389054029 ▶Day: 158 - Daily battlefield assess… | [View]
389072610 | Yo His palms are sweaty, knees weak, arms are heavy There's vomit on his sweater already, mom… | [View]
389060169 | This is the castrator of wh*toids. He is from Kalmykia, the only Buddhist country in Europe. Bow dow… | [View]
389072539 | As the master negotiator of Canada...: Us Canadian's will trade Ontario and Quebec to the Ameri… | [View]
389071741 | >Pay me $500 and I'll tell you how to sex a woman | [View]
389062521 | Why does the you will be happy guy look gay?: Why do the sodomites look the same? In addition to the… | [View]
389072324 | How long until he's 'mysteriously' assassinated? He's been way to based this past week and… | [View]
389057349 | Brit/pol/: >Grammar schools, Northern Rail and Love Island - key takeaways from first Tory leader… | [View]
389069460 | Americans believe in the right to air conditioning but their anime girlfriends never have air condit… | [View]
389061236 | WHY ARE SO MANY PEOPLE BECOMING FARMERS?: and what are the political implications? | [View]
389069662 | NIGGER! NIGGER! NIGGER! NIGGER! NIGGER! NIGGER! NIGGER! NIGGER! NIGGER! NIGGER! NIGGER! NIGGER! NIGG… | [View]
389072322 | White males are delusional: White males are so delusional that think they can somehow bleach Africa/… | [View]
389069522 | The End of History: When did you realize that change is bad? Change is pure evil, everything must st… | [View]
389056136 | Why didn't russia just do the same shit the US is pulling in every shithole country they destro… | [View]
389072113 | 10-00: Post webm of piggies getting wrecked | [View]
389071338 | r8 my map | [View]
389072064 | Why are some countries so resistant to freedom and democracy? What’s wrong with them? | [View]
389071627 | Why do so many here accept the 'money printing = inflation' narrative?: It mankes no sense. The stup… | [View]
389069055 | Does anyone else just really hate niggers and not give a shit about anything else regarding race? Li… | [View]
389069652 | Depopulation is a GOOD thing.: The elites are RIGHT to want to cull the population. They are doing i… | [View]
389071975 | Real reason why US is helping Ukraine: >At least it isnt Russia | [View]
389071664 | Leftist hysteria is going to create a new golden age of edginess like the 1990s or mid 2010s, I… | [View]
389071278 | Andrew tate: >claims to be smart and dominant >does a podcast with some lefty faggot >the… | [View]
389068270 | I hate white people. There is something inherently wrong with being white. There is no place for whi… | [View]
389059743 | >'Homosexuality has been a part of European societies and culture for millennia. It's not go… | [View]
389070381 | Spiritual prison: PERFECTED | [View]
389070310 | Bongland: I worked at a summer camp this summer and had to take young people from around the world o… | [View]
389069569 | Why is this book allowed even on Amazon? While others are banned everywhere | [View]
389071210 | It's official: /pol/chuds are retarded: You are clinically disabled now /pol/ | [View]
389069681 | Biden is the worst polling president in modern history: Bidensisters...I don't feel so good.… | [View]
389069538 | Gay marriages in pre-christian Pagan Europe: 0 Gay marriages after christianized Europe: Millions. W… | [View]
389071502 | Turks dont have to lie to themselves about their genetics: Now that we have seen that northerers are… | [View]
389065261 | WW3, let's gooo | [View]
389065295 | Why does /pol/ claim homosexualoty is degenerate? | [View]
389071433 | Will they keep lying up to after the nid-terms? | [View]
389071394 | Is this the reality of what happens when you let women drive? https://www.youtube.com/watch?v=tAzUWd… | [View]
388948932 | how do we get the normies to start stacking silver?: it would immediately drain the comex and destro… | [View]
389054418 | Operation Locate Zelensky: Let's put an end to our European brethren fighting each other. Where… | [View]
389061237 | Will IPEF ever come to pass as a competitive challenger to China's RCEP? Will Americans accept … | [View]
389065316 | The Final Redpill: Jews don't exist. | [View]
389069372 | Fuck Taiwan: Honestly the thought of going to WAR over an island that only like 6 countries even ack… | [View]
389064853 | Mixing Race and Mixing Animal breeds: I know why racemixing is so rampant and acceptable - it wasn’t… | [View]
389055448 | Why are all Indians rapists in India but then meek af in the West?: https://youtu.be/cUHcxVV29QA?t=4… | [View]
389066912 | Transphobes BTFO. https://www.timeout.com/chicago/news/chicago-was-just-voted-the-2nd-most-beautiful… | [View]
389069942 | Niggers prepare for war: ‼Are the Chinese preparing for war? Military-patriotic videos are actively … | [View]
389068949 | This is what capitalism was destined to turn into. All major corporations owned by a small number of… | [View]
389066139 | As it been debunked yet? | [View]
389062535 | Chechens are 'when the Saxon began to hate and went savage mode' blond rapebeast omnichads. | [View]
389067073 | Your witnessing history: World number 1 super power is going to is gonna pussy out to China, look li… | [View]
389069280 | now that google streetview is available in india, chuds will finally realise india is NOT a shithole… | [View]
389068256 | Why does Xi want dat smoke with the USA after witnessing the Russian invasion? | [View]
389070563 | Try to type up a thread: > Cancel posting > See same thread posted within minutes… | [View]
389061460 | Catch 22: One of the greatest 20th century novels, a searing satire on war and the military. Written… | [View]
389069342 | >Burying the mother of your kids in a shitty grave on a golf course to get tax breaks is this bas… | [View]
389064806 | Why isn't Africa one large country? | [View]
389066705 | My son has had language delay for the first 3 and a half years of his life. His speech at the age of… | [View]
389062406 | >tfw you went to hoholland and died, just so your vatnik parents can buy a lada KWAB… | [View]
389062680 | Say something nice about this dude | [View]
389064780 | Why is this nigger country so retarded?: >Signs an agreement >Do only things that they like … | [View]
389063654 | The actions of western governments show that they're foreign: The current governments of the 'w… | [View]
389048763 | Have you noticed that women took over entire branches of the economy just because all the men left a… | [View]
389062007 | Why Does Every Communist Revolution Ban Ownership of Guns? | [View]
389070443 | Why don't we support Palestine again? Cuz if we do, all the muslims will go back and we don… | [View]
389055677 | OH SAY CAN YOU SEE | [View]
389069390 | Good evening gentlemen. Take your seats. /pol/ logic school begins in a few minutes. https://cytu (p… | [View]
389070134 | Why don't we geographically separate racist white people from their victims so they can't … | [View]
389061416 | For fuck sakes you can’t make this up: Russia is becoming America | [View]
389021488 | BE TRIPLE VACCINATED AGAINST COVID-19 TO GO TO UNIVERSITY: Can't make this shit up. | [View]
389069674 | Jews are waging a war against Humanity through subversion, deception, and subterfuge: These are the … | [View]
389042061 | Even more delectable than Nigger Death: Amerivax death: Last night's broadcast was excellent. Y… | [View]
389035765 | SPAR19 is on air and headed for Taiwan! IT'S HAPPENING!!! Get in here losers! https://www.fli… | [View]
389069735 | https://youtube.com/shorts/uKWLz_KHk88?feature=share single mother couldnt find date to prom so is a… | [View]
389064114 | Interest on the US Public Debt: <<<<----Interest we paid so far in fiscal year 2022 to h… | [View]
389063584 | Reminder: Evolians of /pol/ are winning the occult war: Julius Evola - Orientations: https://de.catb… | [View]
389068937 | How come they are the darkest amoung west Asians and majoirty of them look like saudis? | [View]
389063191 | >the daily russian threads are made made by polaks and a German >Germany has the second larges… | [View]
389067663 | What is it that makes me so much more advanced in cognitive ability than my peers? I am able to spea… | [View]
389055130 | Are they allowed in the ethnostate? | [View]
389066517 | reminder that homosexuality is a mental illness and should be treated as such. | [View]
389052277 | He started as a trans activist: Just trying to raise awareness of the plight of the troons. | [View]
389069700 | capitalism be like: Remember to buy your proudburder goyim! Wouldn't want to cut into Mr.Shekel… | [View]
389060494 | Oh no, tranny sisters!?: FUUUUUUUUUUUUUUUUUUUUUUUUUUU | [View]
389065497 | Is he white or not? | [View]
389069612 | Is Zeihan right?: You’ll laugh at him for predicting the collapse of China, but his outlook for glob… | [View]
389063430 | I’m stuck in Pooland Gdansk after I was denied entry to Mother Russia. 2 days and counting. Somebody… | [View]
389060336 | Will Vladimir Putin Live Long Enough To See Russia Collapse & Balkanize Again?: Will he get capt… | [View]
389068509 | I just thought of something. Could we weaponise and turn ending words with '-x' as something racist… | [View]
389067286 | Guys, I got a slampig pregnant 7 months ago. There isn’t much more I fear than having to marry this … | [View]
389065338 | Did you guys see the White House press conference on Biden's wall? What the fuck is going on he… | [View]
389021104 | >be 29 year old American me >check goybook >pictures of my college friends getting married … | [View]
389063142 | How will faggot pox impact the black community? | [View]
389064317 | Why are pro west threads still being made on pol? Who’s making them? | [View]
389061678 | Do Russians really not give a fuck that thousands of their young are send to die for absolutely no r… | [View]
389057612 | /SKG/ SKYKING General - NO TIME FOR YOUR 7700 EDITION: Wide-band Web Receiver >http://websdr.k3fe… | [View]
389068362 | If they ever put children on the front lines of something you can be sure it's bullshit. Climat… | [View]
389046360 | What's going on here? | [View]
389069248 | So do I become a disgruntled narcissist when I decide to join the nsa or after it is joined? When do… | [View]
389064424 | /nsg/ Z National Socialism General Z: >I acknowledge the existence of the Israeli nuclear arsenal… | [View]
389067000 | /pol/ humour thread: What colour is your bugatti? | [View]
389047023 | Gentile Revolution: Realistically, what are the next countries likely to rebel against the Jewish fi… | [View]
389063750 | MONKEYPOX: Idk man. Listen to this. Gay men are gross. They literally can not stop dicking absolutel… | [View]
389064713 | Was the Left always this bad?: When did it go wrong? | [View]
389067981 | >the top superpowers are both multicultural shitholes Now what? | [View]
389063677 | Ruskie and Mutts are the same. This guy is responsible for rape and murder of inocent children and c… | [View]
389068664 | 7/10 Beanette shot down by niggers in a gun fight in Chimpcago: Of course, one of the niggers involv… | [View]
389067243 | How is the position of the Pope not Anti-Christ? The definition of antichrist is not only being agai… | [View]
389063474 | trans rights are women's rights >hoes mad | [View]
389053725 | When did you realize the 'Both sides bad!' Line is retarded? There's one side that's obvio… | [View]
389067191 | AAAAAAAAAAAAAAAAHHHHHHHHHHHH!!!! | [View]
389067962 | You are only allowed to be proud in perversions and deviant life styles instead of upright morality … | [View]
389066904 | When did you realize true rightism is virtually non-existent in the West today and all we have is li… | [View]
389058837 | Why was Stalin so anti-semitic? >The 'Doctors' plot' affair, also known as the case of sabot… | [View]
389037221 | We Germans are considered to be the strongest bullion of the soup: We are the peak of the White Race… | [View]
389067100 | I feel a false flag is coming about Taiwan. Give me some examples of what you think 'they'… | [View]
389065912 | Come home white man. | [View]
389067341 | When did you realize that if you don’t like being financially enslaved by a foreign country that mea… | [View]
389067464 | US is collapsing: >political division went beyond healing >now people stop talking about polit… | [View]
389055982 | Are we living in a worldwide Weimar? | [View]
389053217 | Why are conservatives ok with this type of grooming but not LGBT education? | [View]
389064729 | Where the hell is she going? | [View]
389065802 | /risk/ - European World Tour: Welcome to the resurrection of /risk/, game lasts until I deal with IR… | [View]
389066418 | Thanks for not aborting me!: Post funny fetuses and babies. | [View]
389066997 | Does you're country get flooded by these 'people'? | [View]
389056821 | itt famous people who are secretly based and redpilled | [View]
389067226 | Should boys have the full rights of adults?: Obviously, girls shouldn't, that's just silly… | [View]
389060811 | > still can’t leave country When will Biden remove the mandate btw | [View]
389061425 | >here's your based trad country fighting International jewishness bro… | [View]
389066167 | How much time do you spend on your phone, /pol/? | [View]
389064311 | USA vs Rome: Are Americans experiencing a collapse similar to that of Rome or a phase more like that… | [View]
389067025 | /nsg/ Z National Socialism General Z: >I acknowledge the existence of the Israeli nuclear arsenal… | [View]
389051491 | Give me at least one good reason why we shouldn't partition Poland, give everything east of Vis… | [View]
389066145 | BREAKING: Nancy Pelosi is shot down: She is currently drifting in West Pacific risking a Chinese cap… | [View]
389066446 | Nocturnal for climate!: During the hot summer months, you should be active at night time and sleep d… | [View]
389066394 | Meds and Slavs are brothers. | [View]
389064981 | Has Tim Pool ever talked about Freemasonry running the wesrern world, how they did 9/11? | [View]
389051149 | What would you have done as the father? | [View]
389054251 | Our neighbor countries attacked us in the Second Balkan War out of pure jealousy. Just like the Angl… | [View]
389066626 | Socialism is not a dirty word. Socialism is an ancient aryan institution. | [View]
389062198 | Now the official fact: Julian Assange 'was persecuted for exposing war crimes, torture and corrupti… | [View]
389055729 | Built for death camps and mass graves | [View]
389037916 | How can we solve the plastic problem? Be aware that China and India give no fucks about morals and v… | [View]
389046070 | why aren't you a communist? you're never going to be a part of the 1% | [View]
389065900 | Space is Fake, Earth is Flat.: heres what happened the us and russia had a space race which was actu… | [View]
389065091 | I find it funny how I can say “I wish slavery never existed!” and blacks would be like “hell yea whi… | [View]
389066037 | pelosi is landing in guam and it is going to capsize because she is so fat. | [View]
389056157 | CHIPS ACT: Why are we not talking about the chips act? >The bill, a Biden administration priority… | [View]
389060627 | need americans to answer pls: ok, you have a right to guns, fair enough and if anyone asks you to gi… | [View]
389063031 | >We'll take Kiev in 100 hours max >We've already entered Kharkiv >Soon bro >No… | [View]
389064510 | Global Hyperinflation General /GHG/ #89: Welcome to Global Hyperinflation General /GHG/ #89 Previous… | [View]
389051462 | https://www.youtube.com/watch?v=H_pLkD9ty8s This shop would last about 60 seconds until it was robbe… | [View]
389065684 | ALGERIA: A Cameroonian victim of a gang rape in Algeria. Last week, Louisa Hanoune, during a press c… | [View]
389065579 | WW3 may be a deliberate attempt to distract the Americans away from Civil War: >gun grab is about… | [View]
389060389 | I genuinely don't care about the vaxxie cunts that die off, it will be easier to create a bette… | [View]
389062222 | Not my problem. | [View]
389063521 | But muh 43% | [View]
389056906 | I turned 20 about a week ago, and I’m terrified, all of my peers want the following; >bug and pla… | [View]
389063478 | blackpill me on emerson's self reliance: tell me why government reliance is preferred over the … | [View]
389064539 | High Iq here. WEST is baiting China in war: Trap is laid, like in Ukraine. If China attacks, from un… | [View]
389057335 | I've been interested in Georgism for a while, and I have a question: 1. Georgism taxes land usa… | [View]
389060894 | >Russia insisting it is an equal partner with China. | [View]
389063425 | Are we gonna to great again?: thought it was just the beginning, but didn't realize it was alre… | [View]
389063666 | Are trans people mentally insane? The detrans community is starting to push back hard and showing hw… | [View]
389063955 | The Pitbull of countries | [View]
389064687 | tranny hate thread: post 'em | [View]
389051089 | Norwegian Consul Elisabeth Ellingsen at the Murmansk hotel was asked to wait until her room was clea… | [View]
389052886 | You. Are. Here. Forever.: What do you do when the only place you can have an intelligent discussion … | [View]
389052377 | SERBIA vs. ALBANIA WAR incoming: >fuck kebabs >fuck islam >fuck shitskins >fuck their wh… | [View]
389032407 | Why does this plant make pharmakikes seethe so hard? Now that their anti depressants have been DEBOO… | [View]
389064340 | NIGGER: and children who are shouting and acting like monkeys at my house now and probably for anoth… | [View]
389052172 | Do you support hispanic immigration to the US?: I do, because they are hard-working people, and I re… | [View]
389034164 | How is this piece of shit supposed to take out 1 F35?: What are the political implications of NATO/A… | [View]
389058879 | /chug/ - Comfy Happening in Ukraine General #4762: Previous: >>389046047 Timeline /tug/: http… | [View]
389056250 | Why yankees hate China? | [View]
389054780 | NEW SCIENCE JUST DROPPED: green or orange sky = climate change | [View]
389054044 | Post images relating to the fall of the West | [View]
389064030 | Is there a more lowly and confused 'fight' than LGTBQ+ activism? We evolve to enjoy some shit that o… | [View]
389059754 | Why do liberals think everyone who disagrees with them is a bot? Really contradicts their 'open-mind… | [View]
389063879 | Japs are insanely good at (((shaping minds))) through media: >demon slayer, an extremely popular … | [View]
389058469 | DISCUSS: Why is Lex Wexner not in jail? | [View]
389061068 | Oof: At least they're not speaking German | [View]
389055911 | >presidet receives kalergi prize >romania is flooded with niggers and pakis 1 year later Huh..… | [View]
389063099 | Why you don't look for food in supermarket garbage cans: Why you don't look for food in su… | [View]
389055950 | First time on this site: Hey fellas, I just watched a YouTube clip of kids messing with Shia. Pretty… | [View]
389060709 | Nature says differently. Faggots will die off from monkeypox/vaids. | [View]
389058449 | What are your guy's thoughts on the attached research? None of the authors are Jewish. Keep you… | [View]
389056213 | Why did England import so many pakis? What is the exact reason? | [View]
389060579 | >premodernism: god is lord, fuck niggers and kikes, i just want enough grain to survive the winte… | [View]
389061996 | Where did all of the zoomer mutts come from?: Was racemixing really that common between 2000 and 201… | [View]
389058159 | he stole my heart <3 | [View]
389054029 | /uhg/ - Ukraine Happening General #3562: Prev:>>389045022 ▶Day: 158 - Daily battlefield assess… | [View]
389061116 | When did you realize: that the Schizos were the fittest? > 0 VAXX > Refuse any pridepox VAXX … | [View]
389063145 | How to end the war on drugs: I have a powerful idea I can end the war on drugs and the addiction cr… | [View]
389062142 | Why is Satanism and Masonry often associated with wignat and Nazi stuff? | [View]
389061217 | Have any female soldiers died in Ukraine? Are they abused when captured? We've seen several tor… | [View]
389049332 | I'm curious, is there just a bunch of genuine trolling or do Europeans really not have air-cond… | [View]
389049718 | When will Sweden and Finland be in NATO?: It looks like the day is coming closer. | [View]
389060167 | >5 months, 1 week and 1 day | [View]
389062768 | Now America has accepted the fact that they have to share the world with China.: As pointed out befo… | [View]
389062149 | Why do the schizo theories from this Cambodian Basketweaving forum always seem to come true? | [View]
389057984 | If you believe in the climate change hoax you are working for THEM: and are assisting THEIR plans. C… | [View]
389062708 | Ted was right about everything >The industrial revolution and its consequences have been a disast… | [View]
389057372 | Do they deserve to be countries? Cant even protect themselves and have to rely on America. 25% of th… | [View]
389052407 | Christian Conservative Cuisine: Obviously, as a demographic, evangelical white Christians are the mo… | [View]
389060549 | Reminder: Germans invented the Skateboard | [View]
389062609 | What if corn pop wasn't that bad of a dude?: what then? | [View]
389059458 | There are no checks and balances: there is only one 'political' party, everything is a lie. | [View]
389054055 | Why is germany collapsing?: Is it really only because of gas or are there other reasons? | [View]
389035395 | Nz/pol/ aka NZG: Is coffee good for you edition >https://www.rnz.co.nz/news/business/471792/nati… | [View]
389062265 | I don't think I understand: https://www.reuters.com/world/us/after-starting-new-mexico-fire-us-… | [View]
389002614 | /pol/ humor thread: the classics: time to have some lulz and relax for the weekend | [View]
389057917 | England: Imagine not being English.................................. | [View]
389062054 | MexiCACA is a shithole: Imagine ever visiting this country and thinking you're safe. As expecte… | [View]
389048314 | The entire idea of space is demoralization.: Flat earthers: you are the center of God's creatio… | [View]
389061299 | Breaking: USA SURRENDERS: IT'S OVER | [View]
389045299 | I declare a new term 'Bath-Watering' to describe astroturfed theories like Flat Earth.: 'Gas Lightin… | [View]
389058290 | post your food stash for when shit hits the fan | [View]
389059267 | >Dear diary, today is day 158 of my 3 days invasion of Ukraine | [View]
389061202 | Holy shit it’s actually happening. | [View]
389051199 | Local communist government decided to shut down public transport for the next 10 months 'for repairs… | [View]
389058755 | Far right militias in Russo-Ukraine war: so Azov, Kraken, Right sector, Wagner PMC and many other si… | [View]
389057105 | do you have an '''expat''' problem in your country?: seems like redditors do https://www.reddit.com/… | [View]
389059181 | >not knowing that xi pushed vladimir to invade ukraine, so china can take over russias role as th… | [View]
389055388 | CHANGE MY MIND: Companies must operate under their registered company name instead of hiding behind … | [View]
389049303 | Self improvement (videos, supplements): What are some interesting self improvement youtubers (not An… | [View]
389058171 | The current state of the West: 34yo French Anthony Loffredo who identifies as an alien chopped off h… | [View]
389057329 | Be American: >go to school, get shot >go to a festival, get shot >open your hotel window, t… | [View]
389052469 | Does anyone have some red pills on Israel? | [View]
389051706 | Pastor breaks down in tears over the martyrdom of St George Floyd: https://m.youtube.com/watch?v=dvp… | [View]
389059376 | >already cucked to china It's over | [View]
389057556 | The browning of America is a threat to all Whites: >America projected to become White minority by… | [View]
389054726 | LIST OF DEAD BODIES: PUBLISHED https://kurer-sreda.ru/2022/07/30/minoborony-opublikovalo-spisoki-pog… | [View]
389012929 | We should all become Feds. | [View]
389054108 | Vaccines ruin lives: >Be normal kid >Take coof vax at age 4 >develop seizure and brain dama… | [View]
389053453 | Is moldova just romania but instead of gypsys there are russians? | [View]
389050889 | Can we just ban these people and their golems? God, I hate them. | [View]
389056626 | How can you hold a grudge for 2000 years even women forget faster | [View]
389058778 | Putin: idiot or genius? | [View]
389052691 | Redpill me on Kabbalah: Is it true that it has its origins from Ancient Sumer/Babylon, Egypt and Can… | [View]
389059092 | What are the political implications of everyone who was lucky enough to buy house pre-2010 having ov… | [View]
389057411 | >He really thought WW3 was going to start over Nancy Pelosi What a fucking turd. Nothing ever hap… | [View]
389058620 | Meanwhile in Sodom and Dakota | [View]
389059974 | The west is filled to the brim: with demons. The temple of set/church of satan is the religion of th… | [View]
389060153 | If you think this guy is making things up then you are a brainwashed boob | [View]
389058668 | Warning to all vatniks: Official statement of the temporary acting commander of the 'Azov' regiment,… | [View]
389051452 | THE ABSOLUTE STATE OF THE USA: HAHAHAHA BOW DOWN TO CHINA | [View]
389051007 | >globalism bad, guise >bad bad bad! >supply chains breakdown >prices of some products sk… | [View]
389058492 | Stop calling it a recession: You're not qualified to decide. | [View]
389020707 | How is she still alive?: Where's the client list? | [View]
389059316 | Guess what? | [View]
389059580 | White people be cheating out of their asses: Now these motherfuckers are gathering data like a mothe… | [View]
389057118 | >28c / 82f | [View]
389058697 | Should we put in efforts to medically restore foreskin to men who were forced to be cut as babies? | [View]
389053300 | Depopulation agenda is good: Women like these won't have children because they've been bra… | [View]
389045503 | AMERICA JUST BANNED GUNS: NO MORE GUNS FOR DUMB AMERIFAT CHUDS >https://nypost.com/2022/07/29/hou… | [View]
389053051 | /chug/ - Comfy Happening in Ukraine General #4761: Previous: >>389046047 Timeline /tug/: http… | [View]
389049118 | Is there any other fun communities aside from Pol and Int on 4ch?: I have been on these community( d… | [View]
389056886 | Why don’t terrorists hire SpaceX for an asteroid deflection mission?: Just imagine how much money th… | [View]
389056259 | Do you support iran or usa? | [View]
389054465 | NAFRIS OR SYRIANS ?: Now that the dust has settled... was it nafris or syrian rapefugees ? I believ… | [View]
389057260 | how do I become this smart | [View]
389052424 | I AM CIRCUMCISED | [View]
389019379 | Guess who wins: https://www.asian-dawn.com/2022/07/30/man-who-assaulted-asian-elder-released-tries-t… | [View]
389057938 | Toledo is an absolute......ly alright city. It's getting gentrified. Tons of professional, frie… | [View]
389054402 | >jewish pokemon >immune to Poison Gas Is pokemon trying to tell us something??… | [View]
389056142 | Women hate: Post images of straight hate towards women | [View]
389048492 | might have covid ( no symptoms but had contact few days ago) and I will meet girl that friendzoned m… | [View]
389038276 | What does /pol/ think about Hitler? | [View]
389045476 | If Hitler was alive today: would he be browsing /chug/ or /uhg/? | [View]
389058034 | >'Bolsonaro is a nazifascist' >gets knifed by a random skizo >'wtf Bolsonaro is a fellow de… | [View]
389053480 | Putin is preparing to flee Russia to Syria, once he lose the war: >The Russian President and clos… | [View]
389057256 | What movies are good from 2020-2022: Seems like all the new movies are devoid of substance | [View]
389057120 | >Be me >Rest break at work >Russian co-worker asks me if I have a cigarette >Tell him no… | [View]
389057392 | china is becoming too powerful: in less than 5 years the chinese navy will be too powerful for the u… | [View]
389057962 | beef=hovězí=dark red: Did your country also stopped eating beef in 21st century? Whats the reason be… | [View]
389040744 | Brit/pol/ community policing edition: >Scientists suggest mystery paediatric hepatitis outbreak c… | [View]
389055977 | /GENERAL CHRISTIAN BOARD/: GENERAL CHRISTIAN BOARD/SOCIAL THREAD. >what is the best way to gather… | [View]
389053793 | What does /pol/ think of Religious Syncretism?: >inb4 Is LE BAD So explain to me why Europeans sy… | [View]
389056688 | >cheddar man wasn't brown that's a jewish lie! >hehe my based aryan steppe ancestors… | [View]
389050414 | >Poland bought $24B worth of weapons from S. Korea >these weapons are probably headed to Ukrai… | [View]
389047620 | Well, /pol/? What's the simple reason they're locking up toothpaste? | [View]
389053262 | Capeshit is inherently Jewish: The first two Superheroes - Superman and Captain America - were creat… | [View]
389043060 | PRESIDENT TRUMP GENERAL - GOOD MORNING SUNDAY MORNING EDITION /ptg/: PRESIDENT DONALD J TRUMP @POTUS… | [View]
389015110 | MUH WALL: >pic related is 53 years old >”heh women hit dA WaLl after 20 years of age” Why are … | [View]
389052033 | Was Top Gun Zionist bait to send more white kids to die? It's the only time I didn't see o… | [View]
389052650 | Only oldfags remember this meme | [View]
389056895 | So the new boss successfully threatened the old boss: What does this pivotal moment -that the Chinks… | [View]
389038901 | HENRY KISSINGER WARNS WE ARE HEADING TOWARDS WORLD WAR THREE: GET IN HERE! Henry Kissinger has said … | [View]
389056521 | i support ethnic deportation for americans to europe and mass migration from europe to america and m… | [View]
389054474 | We live in a world where women think actual sexual jokes and interactions are actually devoid of any… | [View]
389057379 | The action after the murder of Ukrainian prisoners of war by Ukraine in Yelenovka. Everyone blames R… | [View]
389055770 | Why is the thought of nuclear war so comfy?: Am I mentally ill? | [View]
389023554 | Niggers on Twitter celebrate black girl violently beating white girl https://twitter.com/rosemisuba/… | [View]
389049684 | Why do you put up with it?: Why do you put up with being pretty much abused like a cuck by your empl… | [View]
389053708 | Israelis outraged as Big Brother contestant performs Nazi salute: >If the Big Brother internation… | [View]
389055271 | rothschilds need to come out as the despondent anti-elite. All it takes is one | [View]
389055841 | Has /pol/ scene this movie? I think it's onto something. https://www.youtube.com/watch?v=AdE7yo… | [View]
389047600 | >Tfw a pajeet is the Englands only hope | [View]
389050559 | Name one good thing about pic related Protip: you cant | [View]
389037586 | FAGGOTS RAPE CHILDREN: the children who got monkey pox were traces to gays (who raped them as that… | [View]
389055551 | please... I can't stand the obsession anymore, I sold my tv and bought a bookshelf because this… | [View]
389046888 | >started having tranny thoughts bros...how do i fix this? i don't want to be a fucked up npc… | [View]
389055368 | Ethan Ralph is the quintessential american: A fat pig squealing and running his mouth on the interne… | [View]
389054310 | You cant refute dis.: Russian culture is centered around tatars. They have holidays for tatars. They… | [View]
389054771 | Zelensky will be putted out from the game? https://youtu.be/mactoSForFY I just wander how some one … | [View]
389056476 | listen jew: were not gonna fight for you. were gonna wake pl up to your tribes kikery every day. uni… | [View]
389043656 | Say what you want: We all listened to him and thought he was based ! | [View]
389055481 | Let's be real here.: I believe most of /pol/ wants to see the world depopulated. That said, how… | [View]
389056340 | It's over... | [View]
389034625 | Opinion on Ol'Brenty? | [View]
389053876 | what kind of people are south america types?: do they have empathy? Are they sexual deviants? Thieve… | [View]
389050400 | Why is Gen Z so dumb?: The education system has failed. We are absolutely fucked. A generation of mu… | [View]
389011522 | How will history remember this? | [View]
389052126 | how do we get america to start building up? >no more car dependent bull shit >more housing opt… | [View]
389056139 | >DENIES YOUR TRANNY PROPAGANDA IN EAST ASIA Meanwhile /pol/ shills tell you it can't be done… | [View]
389055612 | European here. I pretend to hate America online but that's because I'm extremely jealous o… | [View]
389054311 | What actions should you not do now to have consequences in the future?: For example: Buy on Amazon, … | [View]
388995180 | Japanese TV program for kids: Did you notice anything? | [View]
389053440 | What are the political implications?: 'Alexa, where did 'Joe Biden' fall off his bicycle!'… | [View]
389035385 | aus/poz/ - the daily unna: >Youre the voice try and understand it https://theconversation.com/alb… | [View]
389049346 | Where were you when USA was officially buck broken? | [View]
389035214 | 20 years since WLP died: >At the time of Pierce's death in 2002, the National Alliance was b… | [View]
389044072 | APOLOGIZE: /pol/ will unironically defend this | [View]
389052341 | How many people will die by 2030? | [View]
389048656 | Should this country be divided 50% to Bulgaria 50% to Greece? | [View]
389055106 | When WW3? | [View]
389054801 | Why do I imagine most 4chan posts as some guy with a fedora and anime pillow yelling at a screen? | [View]
389053880 | > Moldovian region (north-east) in Romania is the country's cultural cradle What are the po… | [View]
389033214 | /pol/ Barfren - Taiwan Numba One edition: Hello frens, Come and grab a seat at the bar and discuss t… | [View]
389029328 | sneaky hohols: hohols castrated their own just like how they bombed azov castrated guy was probably … | [View]
389054997 | Best strategic practice game: Why dont white people play this game? literally the game to practice s… | [View]
389050851 | only eastern euros find this normal https://youtu.be/UU8iImCwC80?t=343 | [View]
389054266 | I'm Still Not Convinced: I saw Gulf War II live on TV. This Russia/Ukraine stuff doesn't e… | [View]
389050609 | CIA is not spying on you. What would the point of collecting that date even be? Nobody cares what de… | [View]
389047874 | The vulcan science directorate has determined,,,,: That jews are not actually human. | [View]
389048393 | Why are asians so anti-gun? | [View]
389052032 | Is there any decent search engine these days? One that actually searches the web and isn't bias… | [View]
389054429 | Other than total genocide, is there a solution to the American question? Americans will always put m… | [View]
389045161 | You're a porn addict: You may not realize this, but your unhealthy penchant for mentioning the … | [View]
389051129 | if you don't pick fishing over women, are you even a man? https://www.youtube.com/watch?v=1vFmL… | [View]
389053798 | GOOD MORNING, SIRS.: I JUST CAME IN TO SIP A CUP OF TEA AND STATE FUCK KIKES NIGGERS GLOWNIGGERS AND… | [View]
389054043 | Looney?: Have a listen. https://rumble.com/embed/v1azq4z/?pub=4 So what's the deal here? Is thi… | [View]
389051980 | Romanian President (picrel) SLAMS Viktor Orban’s recent race speech: >Klaus Iohannis issued a sca… | [View]
389053171 | biden finally blinked | [View]
389027162 | this terrifies and confuses the european | [View]
389051254 | god hated me and made me be born in America which is nice he wanted me to suffer and he enjoyed it … | [View]
389047122 | Can I sue my mom if she chose to get me circumcised? | [View]
389053655 | >Is that a NIGGER on Television? This is WHITE GENOCIDE! | [View]
389050900 | Popular conservative writer Ann Coulter called ( https://www.express.co.uk/news/world/1647823/Piers-… | [View]
389041848 | The diversification of fantasy: Is it ok to modify traditional white male roles to females and black… | [View]
389054084 | Can the elites and leaders of this world stop having sex with children ? | [View]
389042935 | KEK MUTTS BRUTALLY BTFO BY CHINESE SCIENTISTS | [View]
389053362 | >mfw European kuffar are killing eachother again | [View]
389053483 | I went out: I'm a schizo looser with no friends, and came to the conclusion my life is better t… | [View]
389031615 | So the Rothchilds are a very well known rich banking family that has way to much control and influen… | [View]
389045243 | What is the solution to the serbian question? | [View]
389054172 | Lie or truth detector?: What do you think /pol/? Why did they started this during the pandemic? Why … | [View]
389054137 | Project S.O.A.T: The institutions in my country, and in many of our countries, have been captured. S… | [View]
389049601 | Are you 100% European /pol/? | [View]
389044691 | when does it end?: when does the cock sucking end for canada? what is the end goal of these natives.… | [View]
389050606 | https://youtu.be/5qGkIu0szSI I’m torn on this. It would be funny to see Nancy get shot down… but nuc… | [View]
389051015 | My pronouns are: faithful to Jesus Christ, Son of God who died and was risen to wash away the sins o… | [View]
389033401 | NPC test: Never vaxxed never masked never tested never watched game of thrones | [View]
389050940 | MODERN PHYSICS IS POZZED NONSENSE: 6 MILLION JEWS FALSIFIES THE HOLOCAUST edition If you conduct a b… | [View]
389053071 | Why did he do it? | [View]
389047249 | NO REFUNDS PART DEUX: Dead vaxxed walking. From last thread >>389038788 >In a recent situat… | [View]
389052656 | >USA BENDS THE KNEE: How is Communism so powerful? | [View]
389045438 | I'm tired of seeing this 'women': I don't know if it's a troll or not But stop fantas… | [View]
389050949 | just found out chinese age of consent is 14 | [View]
389048114 | Come home, black man. | [View]
389045679 | This borad summarum: >Hunter Biden dick pics >Gay monkeypox anus and dick pics >Russian pai… | [View]
389049320 | Seattle bros: Why can’t we put a Nazi flag on the king dome Ever since that shit hosted black eyed p… | [View]
389042687 | I don't feel so good bros | [View]
389045022 | /uhg/ - Ukraine Happening General #3561: Prev:>>389021717 ▶Day: 158 - Daily battlefield assess… | [View]
389045870 | why Mediterranean are so cheap and stingy and 'broker' than rest of europe even east europe motherfu… | [View]
389053330 | https://mobile.twitter.com/seawatch_intl https://sea-watch.org/ Be a real shame if someone doxed the… | [View]
389047601 | NICK LAND CAR 加速主义: thoughts and political implications | [View]
389044809 | >Spends millions on security >can affort a decent fence or dogs No wonder so many buildings a… | [View]
389047733 | Should marriage be illegal?: Name one reason for it and I’ll counter your stupid statement | [View]
389052237 | You jerks won't have Clott Adams to kick around much longer: now that he's riddled with mo… | [View]
389047516 | They do “gender balance” and “race diversity”: but where are all the transgender and gay characters … | [View]
389046782 | why did men stop wearing skirts? | [View]
389044405 | Almost 25 living with parents in rural Ireland because I can't find a place to rent. How did it… | [View]
389038914 | Can you homos stop sucking and fucking FOR JUST FIVE MINUTES!?: Jesus Christ, I thought we're s… | [View]
389048832 | Glownigger Hate General /#1/ Amateur Baker Edition: I hate the glowniggers and Shlomutts and apsire … | [View]
389050015 | /pol/tard Caught on Camera Fighting a Nigger: https://brandnewtube.com/watch/fight-on-the-ny-subway_… | [View]
389037456 | Was the Falklands War justified? | [View]
389052817 | Happy Sunday /pol/. Watch this documentary about arab men doing ficki ficki to german women. https:/… | [View]
389050739 | repents, confess frens, and god will forgif | [View]
389052343 | lol: >Last week, Eyolfson, who has been injected four times for COVID-19, suffered a sudden heart… | [View]
389048895 | Why is pol against the great reset ?: >waaah rent >waaaaah can’t afford nothing okay here is … | [View]
389046447 | Why is Monkeypox spreading so fast in the USA /pol/? | [View]
389052128 | Good news thread: Nigger gets seen to. How did anyone know which of them was Italian? | [View]
389049266 | Who is this guy? I keep seing him here | [View]
389051545 | not gonna lie 50 cent bros, i'm getting a little tired of winning. it's just too much winn… | [View]
389046047 | /chug/ - Comfy Happening in Ukraine General #4760: Previous: >>389034676 Timeline /tug/: http… | [View]
389050114 | If reddit was a country: >Argentina’s Government Collapsing >People Refuse to Work Amid Major … | [View]
389051593 | This board is for children and manchildren. This is literally You | [View]
389050132 | What can you tell me about the secret space program? | [View]
389051397 | Redpill: China and Taiwan and Semi-conductors: The most complex and hardest part of semiconductor ma… | [View]
389047668 | DUDE IMAGINE lol holy shit imagine believing this shit from the beginning. This is the most hilariou… | [View]
389049198 | Can you feel it?: There's a consciousness shift coming along. Communism is winning the hearts a… | [View]
389050248 | Is /int/ smarter than Yale economists? | [View]
389045896 | Are they gonna push a monkeypox vaccine?: Please tell me they aren't going to. It was so hard t… | [View]
389050817 | is e celebrity bull shit demoralization? i never have felt as depressed until i saw this crap >se… | [View]
389048779 | When will /pol/tards learn not all Jews have big noses. How can you tell Raviv Ullman (Picrel) isn’t… | [View]
389050496 | white race mixing?: i want /pol to explain to me how marrying and having kids between two different … | [View]
389036136 | When will the hold-outs admit that Russians are literal niggers?: This is some 3rd-world tier Somali… | [View]
389036699 | Gringos please can you stop moving to mexico? pls: Seriusly what is happenig in BurgerLand™? today i… | [View]
389038203 | ITT post your highest level conspiracy theories. Whoever is called schizo or told to take their meds… | [View]
389046022 | Calling for Mr. Redpill: Could President Biden's latest speech gaffe be a Manchurian Candidate … | [View]
389051195 | Join this discord. Debate me retards: check this out discord gg/BP6ebRvF | [View]
389045935 | I just miss it bros | [View]
389047954 | I HAVE A BONE JUTTING OUT MY ARSE; They will not silencd KLAUS!’nn I AM REPRESENTED BY SELF ONLY SEL… | [View]
389050712 | Will Dear Leader Be Okay?: Super rare rebound case. Get your boosters Chuds. | [View]
389051051 | Take the Shabbos Goy pill: >Day of The Rope Fictional fairy tale that has less chance of happenin… | [View]
389046156 | China: why do we still have this disgusting stain on earth disguise as country? wipipo, do america t… | [View]
389040081 | One dude earns 3x more than ALL WOMEN COMBINED in his field: This is insane | [View]
389043179 | AZOV BATTALION about to CRUCIFY pig Soviet rape baby Chechens: ONLY JEWISH ((RUSSIAN)) SHILLS CAN AC… | [View]
389042331 | India/pol/ - Politics discussion thread: --->Daily reminder that India is the world's 5th la… | [View]
389049866 | i hate this country and its people i have become the uncle ruckus of mutts fuck you mutts and fuck y… | [View]
389046599 | Why puccian FSB is soo butthurt about China?: Since few days I see many threads how Pooh sucks and C… | [View]
389042730 | Foot-fag bros...: I don't feel so good... | [View]
389034025 | We did it Reddit! | [View]
389040398 | Where are the real Nazis?: Obviously, all major right wing movements since WWII have been globohomo … | [View]
389049020 | Pelosi chickened out, no Taiwan visit: >BREAKING: Press release by US House Speaker Pelosi lists … | [View]
389045133 | Adam Lanza: Adam Lanza the sandy hook elementary shooter in 2012 Is based because i knew most of the… | [View]
389049476 | Why are Americans like this? | [View]
389049490 | No fate: Politically, why do we have to accept the corrupt system we have now with a few rich people… | [View]
389046359 | The baddest and most powerfull nigger was totally destroyed by the Super Aryan within a minute. How … | [View]
389049060 | What do you think bros? Is it over? https://www.bustle.com/articles/187476-4chan-is-on-deaths-door-t… | [View]
389049323 | look sir we know shit aint over yet we still got the waffle house the jews will never take waffle ho… | [View]
389042773 | Trannies don’t groo…: ACK! Why would anyone go to comet ping pong if they were part of pizzagate?… | [View]
389049257 | What can we do about the happy menace? | [View]
389049745 | Pets are not people!: >We’ve become a nation of pet owners instead of parents. Nearly 85 million … | [View]
389046891 | Does Russia have a right to defend itself?: Russia has means to defend itself against NATO. Yugoslav… | [View]
389046944 | The ‘Jaffe Memo’: The ‘Jaffe Memo’ is an infamous document produced by Planned Parenthood in 1969 wh… | [View]
389044815 | European high shools and univercities produce so many useless fucking bums I don't know why the… | [View]
389045825 | Wtf is wrong with women nowadays? It seems like in the past decade they've become really mean a… | [View]
389047281 | >download >burn >distribute >Remastered original version without the online edits such a… | [View]
389045864 | Why are white people more inclined to commit mass shootings /pol/? How do we solve this issue >pi… | [View]
389044680 | Did you ever met someone in real life that was red pilled about the JQ ?: The only ones I met were s… | [View]
389028564 | Spencer bros.... | [View]
389038802 | How much better are women at manipulating and social skills than men? (False accusations, simps, gas… | [View]
389045327 | i just came across some marijuana seeds, how viable is it to try and grow them and turn a profit? i … | [View]
389048853 | The free and democratic, U.S. installed puppet regime, short Progressive Pan Green Coalition, raided… | [View]
389038709 | CERN Shenanigans: What the hell kind of timeline are we in now? Apparently Japan invaded Alaska duri… | [View]
389043866 | Teach them to read you fucking racists. | [View]
389047101 | Every non european on the planet is destroying the world through pollution why do they only blame it… | [View]
389041720 | Polish LGBT free zones: Cringe or based? /pol/ska anons extra welcome itt, pls tell if you live in s… | [View]
389040795 | Is college the best place for socio-sexual development? | [View]
389044386 | the swaztika flies for an army in the east for the first time since 1945 | [View]
389046037 | It begins.: https://www.dw.com/en/hanover-turns-off-hot-water-with-eye-to-winter-gas-shortages/a-626… | [View]
389037280 | Moving to Europe #2: continued from the previous thread.... https://boards.4chan.org//thread/3890179… | [View]
389048015 | d&q cope: niggers and faggots who are shill and cry about muh divide and conquer are race mixing… | [View]
389045262 | This is why I need a gun you fucking retards I’m not getting blown down by some autist with a ar 15 … | [View]
389043020 | HISPANISTS ON JAPAN: JAPAN HAS HISPANISTS https://www.youtube.com/watch?v=0EidP6uO4WM | [View]
389046860 | Brit/pol/- Fucking M25 Edition: >https://www.bbc.co.uk/news/world-62361744 European culture is n… | [View]
389038533 | How do we stop the spread? | [View]
389045931 | We already know the political implications of bullying and isolating mentally ill white men because … | [View]
389047379 | >know two guys through my work >One is a veteran cop, now instructor at the police academy in … | [View]
389046109 | you know what would help reduce climate change? women not changing outfits 10 times a day. | [View]
389045596 | How to avoid this new terrible pandemic?: I'm scared | [View]
389042912 | ((RUSSIA)) CONSCRIPTING POORFAG GOYIM FODDER EN MASSE TO DIE IN UKRAINE: 75,000 CASUALTIES ALREADY T… | [View]
389046266 | Say something nice about them. | [View]
389038619 | Nobody is dying from the vaccine | [View]
389044357 | Argentina is a shithole: Argentinabros, how are you doing? https://www.zerohedge.com/geopolitical/ar… | [View]
389047006 | What if the we elected couples of men and women both to positions of politic power to rule together … | [View]
389043002 | The Russians captured a Croatian volunteer from Azov, Vjekoslav Prebeg | [View]
389042428 | Would Ron desantis have done operation warp speed? | [View]
389042857 | US democratic Senate majority leader: Chuck Schumer. Isn't he a handsome jew? | [View]
389041287 | Fuck Italy: I hate Shitalians so much, they stole my culture and turned it into a degenerate cesspit… | [View]
389043451 | >wagies be driving citroens yikes | [View]
389044435 | If the Holocaust is a hoax, as you insist: so that's happening on this photo in your opinion?… | [View]
389046380 | You're stuck in the demiurges prison planet of constant death/rebirth. When you die, do not go… | [View]
389038788 | NO REFUNDS: Vaxxies are dead meat. AIDS officially confirmed. Shills irrevocably btfo. >In a rec… | [View]
389044316 | Was he right? are women just barely sentient NPC's? | [View]
389044536 | /pol/ what’s your opinion on cops and the police Webm related | [View]
389033832 | >be fat fuck talking head >have highest rated show on cable news >do a show exposing the fe… | [View]
389022309 | The pope admits that Catholicism is genocide. Even though he made the comments to indians, the gener… | [View]
389037988 | BREAKING: US CUCKS OUT: THE MUTT EMPIRE KEKED OUT LMFAO THE CHINK ERA BEGINS | [View]
389042899 | You guys are being chads or something | [View]
389032410 | /pol/ is basically leftist at this point: This place is just a hub for retards and subversives who w… | [View]
389046283 | LIST OF DEAD BODIES: PUBLISHED https://kurer-sreda.ru/2022/07/30/minoborony-opublikovalo-spisoki-pog… | [View]
389046062 | >MUH FUTURE Why should I care about anything that happens after I'm dead? I either go to hea… | [View]
389044175 | Gorbachev: Does he bear moral responsibility for the bloodshed and tens of thousands of dead in Ukra… | [View]
389043991 | NANCY PELOSI HAS DIED: Nancy Pelosi has passed away. We are immensely sad to hear about the passing … | [View]
389037914 | WAKE UP AMERICA | [View]
389027396 | I am now LGBTQ unfriendly: I had to stop going to my local cafe because the guy serving my coffee wa… | [View]
389039257 | Why are you on /pol/ at this hour? | [View]
389045829 | i wish this country had a chance man i really do well time to leave before i get into put a goy cag… | [View]
389041449 | WE WILL FORCE YOU TO BE INJECTED: SNP government supremo Anas Sarwar has laid down the law on antiva… | [View]
389042425 | >i just want to live on a farm Me too. I want you to live on a farm, this one… | [View]
389032198 | China's coming collapse: Stratfor, America's leading geopolitical intelligence platform an… | [View]
389034676 | /chug/ - Comfy Happening in Ukraine General #4759: Previous: >>389024333 Timeline /tug/: http… | [View]
389045815 | I don't understand how people who have the school shooter phenotype are not observed more close… | [View]
389042003 | The industrial revolution and its consequences..... | [View]
389020848 | RUSSIA WARNS AMERICA DO NOT 'PROVOKE CHINA': HAPPENING The Kremlin has offered strong supp… | [View]
389041752 | Why didn't America invade it like Hawaii? it seems really dangerous geopolitically speaking | [View]
389044905 | GET TEH AMBERLAMPS! Serious note what happens and where can I find the find? | [View]
389043914 | Change wins, America cucks out: Ffs, we can't rely on you cunts for anything. | [View]
389044221 | EMIRATS: Why are they like this? Also, how come mutts still can't manage to provide even a basi… | [View]
389043577 | The United States is about to collapse: Thanks Obama | [View]
389044792 | new fact check just dropped: stop calling it Recession, chuds https://odysee.com/@RTDE:e/biden-us-re… | [View]
389039721 | Assault Weapons Ban - Passed in House of Reps: Assault Weapons Ban Bill has been passed by the House… | [View]
389045002 | >Democrats call for gun control and an end to gun violence >Meanwhile Democrats are also about… | [View]
389030381 | Brave woman organizes a flash mob at victorias secret: She exposed victoria secret for what it is...… | [View]
389042325 | Prove to me that you are not a Jew or a nigger. | [View]
389044786 | It only went down from there: This was the last kino moment in Usa history . | [View]
389038803 | Comfy WW3 General Countdown Thread #8: Previous thread >>389028209 SPAR19 is in the air https:… | [View]
389042523 | Have blacks contributed to western society at all?: If so has their contribution been greater than t… | [View]
389041152 | I have a theory that humans domt really eat meat and it’s all part of a Jewish animal sacrifice ritu… | [View]
389044780 | Dear white people, and Americans. Stop having sex and spreading monkey pox. -The spirit of Abe | [View]
389035242 | >Anon, It seems you've been living...two lives. Or three or four. or more. We have actually … | [View]
389034408 | Do you think the war between China and USA would happen?: Over Taiwan. And if that happens, as is su… | [View]
389040012 | https://nypost.com/2022/07/21/texas-men-homero-zamorano-christian-martinez-charged-in-deaths-of-53-m… | [View]
389036701 | How can you have Kebab without immigrants? | [View]
389044209 | thought son social darwinism? | [View]
389029555 | Would the banning of porn put a stop to alot of the strife going on in western society?: Is it feasi… | [View]
389043129 | Watkin's files an ethics complaint against Wendy Rogers.: For being antisemitic | [View]
389044351 | Is the hedonist far right the solution?: Playing and having fun can be the key to the growth and suc… | [View]
389042008 | CAN MODS PLEASE FUCKING RANGE BAN AUSTRALIA? I AM SICK OF THAT FUCKING COUNTRY I WILL FUCKING MURDER… | [View]
389042052 | Hypothetically, what would you do if he came up to you and forced you to hand over your wife or girl… | [View]
389040328 | Is Russia the bad guy? | [View]
389021717 | /uhg/ - Ukraine Happening General #3560: Prev:>>389000336 ▶Day: 158 - Daily battlefield assess… | [View]
389038220 | Operation 'Spot the commie': Americans, what the fuck is going on in your country? Why do you allow … | [View]
389039406 | Mafia question.: Three famous groups are the Italian, irish, and Jewish mafia. The irish and Italian… | [View]
389037300 | Why are shitskins, especially niggers and middle-easterners, so obsessed with designer clothing? Muh… | [View]
389043756 | This is a russian doomer thread, very political.: Teплoe мecтo, нo yлицы ждyт Oтпeчaткoв нaших нoг. … | [View]
389041633 | . | [View]
389029965 | The Great Wet Rapture: >25 drowned Appalachian hillbilly red state scum Pretty good start. Wonder… | [View]
389036458 | CLIMATE CRISIS: >'Oh boy, time to enjoy a nice summer day since global warming isnt rea--- ACK!'… | [View]
389043837 | /pol/ish Qaunt: >be me >openly reformationist >has trump supporting capitalist Q believer a… | [View]
389031192 | UN. FUCKING. BELIEVABLE. | [View]
389031139 | >these dull 85 IQ coffee colored consumers are the human material the future of America is made u… | [View]
389043819 | Literally what's going on with Monkeypox. | [View]
389044001 | THE: NIGGER HATE THREAD I FUCKING HATE THESE ANIMALS AND THOSE WHO THINK THEY ARE REALLY SAME SPECIE… | [View]
389031131 | HUGE DEVELOPMENT: US is hinting that is ready to drop UKRAINE.: The United States, its allies and pa… | [View]
389042057 | Is this true? | [View]
389043084 | Fuck your pitbulll hatred, the first dog on the ban list is pic related: I've successfully de-e… | [View]
389016531 | /SKG/ Skying General Goodbye Nancy: Wide-band Web Receiver >http://websdr.k3fef.com:8901/ >htt… | [View]
389039398 | South Korea is Americas greatest ally: They fought in Korea and Vietnam alongside eachother and they… | [View]
389043718 | SERVING JEWISH MANLET MELTING INTO BUNK BED SPILLING YOUR INTESTINES FOR JEWLENSKIY'S MANSIONS | [View]
389041345 | Words should only have one meaning: By giving words multiple meanings you make debating and describi… | [View]
389029223 | Hey /pol/ I'm looking for the 'lol superman' 9/11 video that is rumored to be one of the most h… | [View]
389040239 | I hate this nigger like you wouldn't believe | [View]
389041221 | How did the jews do this. ? | [View]
389041319 | Why does media designed to criticize 'fascism' usually end up making it look awesome? | [View]
389040781 | The white working class are the new Kulaks in this country, even /pol/tards bash them (no surprise s… | [View]
389041592 | 13th Amendment makes it illegal to own a Nigger so Musk is in the clear from leftoid lawfare: https:… | [View]
389042009 | I, Nathaniel Higgers: That is all | [View]
389036580 | Putin didn't even started.: Winter is coming Europe cumskin bros. are you prepared for picking … | [View]
389036888 | >Ping pong nong ming don-ACK | [View]
389035416 | LIST OF DEAD BODIES: PUBLISHED | [View]
389041882 | 'I'm going to drain the swamp': Based Zion Don | [View]
389034076 | It appears that political influencer 'Scott Adams' has contracted monkey pox at Bohemian Grove (his … | [View]
389037323 | 'Go woke, go broke': Why do cuckservatives repeat this phrase and afterwards say 'they get woke to s… | [View]
389028692 | PRESIDENT TRUMP GENERAL - GEE, HOW COME BRANDON GETS TWO POSITIVES EDITION /ptg/: PRESIDENT DONALD J… | [View]
389041164 | Oh no no noooo: https://archive ph/EX1vJ | [View]
389043035 | 75,000 DEAD VATNIK POORFAG GOYIM DIE FOR JEW MASTERS: THE ((RUSSIAN LEADERSHIP)) WILL HAVE TO LISTEN… | [View]
389039396 | Mexican Cannibalism: I have noticed a couple of years ago, specially with president Lopez Obrador, a… | [View]
389040889 | predictive programming>: https://www.youtube.com/watch?v=S03T47hapAc https://genius.com/Gorillaz-… | [View]
389042749 | American Physics Olympiad Team: How do we stop US from stealing our top talent? | [View]
389038011 | WTH Happens Here?: All of them speak Spanish and totally irrelevant despite having half billion popu… | [View]
389036019 | I just wanna live on a farm | [View]
389041591 | I want a 4chan mod: I want to know where I stand I want to hear it from you. You are all powerful im… | [View]
389027142 | You thought you could hide out in Asia?: There is no escaping globohomo. Japan is getting BLACKED RA… | [View]
389042426 | https://archive.is/PIFEY | [View]
389041469 | How do we handle the issue of random attention whoring women making false rape claims against men th… | [View]
389042539 | Breaking News: nancy pelosi plane has set off from hawaii heading to taiwan. >>Will china shoo… | [View]
389042388 | She's terrified: When has America become so pathetic? | [View]
389039209 | are cats parasites turning women into depressed schizo lunatic humans? | [View]
389039989 | Fox Fisher UK Non-binary advocate Dies aged 42: Fox Fisher, Star of Channel 4's 'My Transexual … | [View]
389042168 | America love thread: post nice things you only see in America | [View]
389042469 | You clean toilet bitch | [View]
389027424 | They killed him, they killed the spreadsheet anon: It has been more than a month and the spreadsheet… | [View]
389040909 | . | [View]
389040458 | Everyone on this board is a robot except me | [View]
389028980 | What industry has remote jobs where you can move anywhere in the world: I basically want a remote jo… | [View]
389033402 | Reminder that this actually happened. Disgusting. | [View]
389022816 | I'm thinking of becoming a criminal: I don't want to do anything that I consider immoral, … | [View]
389041331 | >speaks Russian with a Polish accent >larps that it's an actual language Holy fuck hohol… | [View]
389041467 | what can you do to save this third world nation | [View]
389040416 | I fixed the united states state borders: Why is there more than 10 again? | [View]
389040818 | “Buttfuckin Pox”: How has no one thought of that? | [View]
389038385 | The GPL is Revocable.: >('[N]onexclusive licenses are revocable absent consideration.'). Where co… | [View]
389039612 | facism vs natsoc vs socialim vs capatalism: so I feel Italy was morally in the right, Germany was to… | [View]
389036672 | I fixed the united states state boarders. | [View]
389040187 | Why do Jews have their own Olympics?: Notice anything strange? Oh and the financial crisis in Argen… | [View]
389040234 | What does pol think about Patrick Little? | [View]
389038568 | Happening Cancelled: Now that america pussied out what are you doing to welcome your new chink overl… | [View]
389038847 | Why does this man make Brits seethe so much? | [View]
389039344 | Why are conservatives obsessed with intersectional politics and relationships as much as liberals? L… | [View]
389041127 | Jesus loved you, the earth is uniromically flat: https://youtu.be/7j1gc6ex9C0 Globe earth implies yo… | [View]
389041364 | Anyone up?: Testing.Testing. >tap tap tap This thing on? >tap tap Testing. >tap Sandy Hook… | [View]
389041274 | Some of you are alright: Don’t come to /pol/ tomorrow. | [View]
389019247 | Should makeup be considered legally fraudulent? Should it be outlawed? | [View]
389040965 | Ethnostate go brrrr: Jews are aight. Israelis should be nuked. Change my mind | [View]
389028650 | /Pol/ meta thread: Frens only | [View]
389037137 | COVIDs real or I got a shitty immune system: Symptom's Feelin g drunk Feve Low blood pressure F… | [View]
389029840 | This is China's best military opportunity in decades: There are thousands of Chinese 'volunteer… | [View]
389028415 | cuba: what pol thinks about this hell hole? seems like a mad comunist experiment | [View]
389040016 | Did the Ottomans and Germans need to ally? Why didn’t they succeed? | [View]
389040991 | If Taiwan is a part of China.: Then our demented retarded president successfully invaded China witho… | [View]
389013163 | 'Jeopardy fans threaten boycott': You know, I was just wondering why Jeopardy seemingly forced this … | [View]
389029843 | So this schizo mf ended up being right about everything huh | [View]
389040748 | Why does nothing ever happen? It only happened with Russia because they are Slavs and are insane. | [View]
389038877 | https://globe.adsbexchange.com/?icao=ae503d MJ's on the move! Hee hee! What song do you think h… | [View]
389039180 | 4chan is a glowop: why do you still come here? its just zog-central most of you just post threads to… | [View]
389037726 | ATTENTION DUELISTS: OPERATION I DON'T TRUST THE GOVERNMENT: WHEN YOU GO TO VOTE IN THE PRIMARY … | [View]
389039010 | Why Old Spice, Colgate and Dawn are locked up at drug stores: It’s because niggers. | [View]
389038237 | Pelosi isn’t going to visit Taiwan but China will still invade. The plans have already been put in m… | [View]
389035514 | /POL/ HUMOR THREAD | [View]
389030656 | Do any VPN's work on Omegle? I got banned while redpilling people. | [View]
389035083 | HAPPENING CANCELED PELOSI IS A BITCH: https://www.speaker.gov/newsroom/73122 | [View]
389039770 | How accurate is this? | [View]
389037781 | Global warming isn’t rea…: ACK! This can’t be happening. This is not survivable. Why didn’t republic… | [View]
389037273 | You WILL wear your seat belt. You WILL come to a complete stop at stop signs You will NOT exceed the… | [View]
389040430 | FTN 508: Mr Balogh goes to Berlin: New FTN very interested topic More and more noticeable week every… | [View]
389037147 | OY VEY | [View]
389035004 | Andrew Tate is a homosexual that got dominated by women and faggots on reality tv: But to pol he is … | [View]
389039718 | Germany has been occupied for most of it's existance: 'Germany' as an amalgam of smaller countr… | [View]
389032812 | Weed smokers, it might not be too late: You can stop being a drain on society RIGHT NOW if you swear… | [View]
389037231 | UC Berkley: Is this the right way to talk to a Professor from UC Berkley: Asking for a friend.… | [View]
389030902 | Why is Mexico superior to the rest of Latin America?: >Argentina: 50% unemployed, 80% inflation … | [View]
389038722 | Why did you miss this?: I'm so disappointed in you. How could you miss the fact the pic related… | [View]
389036063 | After watching threads I’ve realized that being part of the police/military is the best way to ensur… | [View]
389039280 | HAPPENING: Wikipedia changes the definition, of the word definition Prepare for your 1984 dystopia.… | [View]
389039509 | The Day is August 8th: Remember the January 6th attempt to take the Capital building to get Trump ba… | [View]
389039455 | Chris has a decent chance of having his case dropped and go home scott-free as long as he doesn… | [View]
389039123 | YOU WILL NEVER BE A WOMAN: BEHOLD! PLATOS WOMAN! | [View]
389024365 | Why are violent video games allowed but not video games about sex?: Why is porn allowed but not gore… | [View]
389039572 | Russia wants his remaining Jews to go to Israel/US Why is that? Tens of thousands of Russians, many … | [View]
389031430 | Pelosi is up. https://globe.adsbexchange.com/?icao=ae503d | [View]
389036758 | HAPPENING: BREAKING: PELOSI SEEN TRAVELING OVER TAIWAN | [View]
389039719 | This looks shopped: I can tell from some of the pixels and from seeing quite a few shops in my time … | [View]
389034434 | California is a shithol-: Literally dozens of heaven of earth cities in California. >South Bay A… | [View]
389038815 | USA WEAK AS FUCK: AMERICAN GLOBOHEGEMON FLED LIKE A WHORE AND PELOSI DID NOT FLY TO TAIWAN, THIS IS … | [View]
389033376 | ATTENTION: fuck christcucks. that is all. | [View]
389035344 | ITS OVER: White population in the 5 largest cities in the US - New York - 33.3% - Los Angeles - 28.7… | [View]
389007471 | Monkeypox awards: We need something like the Hermain Cain Award but for faggots who catch Monkeypox.… | [View]
389039310 | I want to merc 1 of u: So let's go | [View]
389039211 | It was not horseplay. Drop it already. | [View]
389039304 | Opposing Beliefs & Ideals in Personal Relationships: In your opinion, do differing beliefs in a … | [View]
389036975 | Islam is the only threat to the JWO: That's why they're so focused on dividing and destroy… | [View]
389039177 | The fact that this shiteating faggot exists is kind of proof that God doesnt exist.: In my mind, if … | [View]
389037926 | Why is it that kikes hate Christians in every single conflict they got into, but they glorify pagans… | [View]
389038525 | poles are subhuman niggers. they need to be liberated from their tyrannical zionist nazi government … | [View]
389019698 | Why does the world economic forum hate tobacco so much? | [View]
389036198 | Tradcaths: why are they as autistic as communist trannies? | [View]
389037783 | Zoomers Are Annoying Faggots: >No Cap! >Bussin! >You an NPC! >Bro! >Dawg that's … | [View]
389038882 | God. This makes me happy. More hopefully. | [View]
389034393 | OMG I NEED AN ABORTION: I NEED TO GO GET FAHKED STACY https://www.youtube.com/watch?v=QbULS8w4c4s… | [View]
389038971 | Xi sama....I kneel... | [View]
389035022 | /pol/ Loses Bacon Goyslop. Bacon is S○Y: You're not a seed oil, s○y consuming s○yboy zogbot are… | [View]
389032626 | Gays cause monkeypox: It's time to end gays to stop the spread | [View]
389035021 | Spain past its Muslim period failed to produce any relevant philosophers, mathematicians, scientist,… | [View]
388999915 | Masculinity Gift Thread: Have seen a growing number of advertisements and 'influencers' targeting me… | [View]
389021895 | HOLY BASED | [View]
389020577 | I don't deserve this. | [View]
389036903 | What is happening in Northern America? >children are being trannies and gays >'men' are actua… | [View]
389036006 | The promise that the next gen has it better than the previous gen is long over: However, are we now … | [View]
389034948 | guys im gonna be totally honest with you: after reading all these fag stories about how they caught … | [View]
389037053 | Steven Anderson is a snake and a false teacher | [View]
389037153 | SHE CUCKED OUT: KEK MUTTS ON SUICIDE WATCH CHINA WINS AGAIN | [View]
389038468 | https://www.speaker.gov/newsroom/73122: MUTTS KEKED OUT AHAHAHAHAHAHAHAHAHAHAHAHAHAHAHAHAHAHAHAHAHAH… | [View]
389036322 | i am becoming wayward how do i live a normal peaceful life | [View]
389022670 | TRUMP SAYS 'KLAUS SCHWAB HAS DONE A FANTASTIC JOB': https://twitter.com/philthatremains/st… | [View]
389034041 | Stores are forced to lock spam up: >“Someone is stealing this because they need it,” agreed Delia… | [View]
389036766 | 'The Provisional Government is going to fall': 'and when governments fall people like me are the fir… | [View]
389038307 | have sex: >marry and reproduce | [View]
389008544 | The ozone scam, and DuPont: Remember the hole in the ozone layer….. let me redpill you on what happe… | [View]
389036949 | How to reprogram Wiggers: What are the ways you made Wiggers and White Bitches who act like Niggers … | [View]
389033178 | SO BASICALLY……: China is a country on Earth, and they killed the speaker of the house. And that’s ba… | [View]
389036943 | What would be the best option (besides suicide) for someone with $100k in savings, but literally no … | [View]
389003130 | N | [View]
389035357 | Fuck, people are just killing each other for insignificant and non life threatening and not even rel… | [View]
389033390 | Looking at moving to Wyoming from Alaska for family and economic reasons, is there anybody with expe… | [View]
389014349 | New Breadpanes just dropped: Thoughts, y'all? | [View]
389035837 | /pol/ really be like >I'LL LET A THOUSAND CHILDREN DIE BEFORE I GIVE UP MY AR-15… | [View]
389037457 | 'Monkeypox is just a gay disease! Not my problem!': ...until a faggot molests a child (and I think w… | [View]
389028241 | this terrifies and confused the american | [View]
389036942 | Monkeypox thread - God’s wrath edition: We are were indicated on pic relater. When will we have the … | [View]
389028830 | N | [View]
389033778 | Literally EVERYTHING bad is because of jews | [View]
389032333 | STAGE SET FOR THE INVASION OF EU: CHINA TO PROVIDE UNLIMITED MANPOWER | [View]
389017589 | why is racism so FUCKING funny: The amerimutt meme, niggers, spics, wops, jewkraine. My god /pol/ is… | [View]
389037528 | >tfw mark of the beast was actually just boils from cum stains | [View]
389037655 | Why didn’t people learn from GRIDS/AIDS?: If the poofters don’t care about dying a horrible painful … | [View]
389037575 | https://www.youtube.com/watch?v=j7lilklyiek | [View]
388980696 | Trudeau Mandatory Gun Grabbing: Give up your guns, Leafs! Glorious Leader says they're too dang… | [View]
388998967 | Redpills: Leave one take one: I'm really just looking for the list of comms in the media and th… | [View]
389036953 | ((RUSSIA)) CONSCRIPTING POORFAG GOYIM FODDER EN MASSE TO DIE IN UKRAINE: THE TIME HAS COME FOR YOU T… | [View]
389037076 | So what are the legal ramifications for a private corporation obtaining and using a real nuclear bom… | [View]
389025083 | >whites are utterly insane by globohomo brainwashing and are going to be outbreed >blacks can… | [View]
389029708 | Does it make evolutionary sense to get huge (hugely fat)?: I mean, come on. Life is unstable, the wo… | [View]
389037111 | We need to go to the moon.: We need to go to the moon, we need to go mars. There's water there … | [View]
389037156 | 75,000 DEAD VATNIK POORFAG GOYIM DIE FOR JEW MASTERS: 75,000 CASUALTIES ALREADY THATS MORE THAN 2x T… | [View]
389031128 | niggers stand with Israel: If you stand with Israel you stand with niggers. | [View]
389003503 | NUCLEAR TOTAL WAR SUMMONING ROOM: ITT: WE SUMMON WW3 | [View]
389032996 | So my Mom has Nigger Fatigue: Niggers literally give Fatigue through exposure. I'm witnessing p… | [View]
389034459 | How much do PMC operators make?: I have a friend who is interested in doing private military contrac… | [View]
389032172 | Where is the best place to live for someone that has enough money not to have to work? | [View]
389036555 | There are government agents on this board right now from some of the most powerful countries in the … | [View]
389036944 | I thought Spain had pretty women. | [View]
389036984 | What are the political implications of me playing the song of my village itt?: *inhales* >TOOT...… | [View]
389025350 | Why Couldn't Argentina Take Some Islands Right off Their Coast?: They got absolutely humiliated… | [View]
389035473 | Russia wants his remaining Jews to go to Israel/US: Why is that? —— Tens of thousands of Russians, m… | [View]
389033317 | Is there a political solution to education in America? How do we solve it? We're graduating hig… | [View]
389030861 | TAIWAN IS NOT A COUNTRY regardless what American Jew media says Kike niggers will not succeed in fo… | [View]
389008428 | Russian Bro We Never Can Stop Winning! | [View]
389020306 | Let’s go Bran- | [View]
389019065 | How the fuck is Colorado the least obese state? | [View]
389036698 | Why Amercan don't accepting Islam .?: Islam will make the US better country .What in Islam don… | [View]
389014703 | What are the political implications of marrying and breeding Turkish women? It’s not even race mixi… | [View]
389000552 | Why did Hitler betray Stalin? I thought he was a man of honor. By making Stalin an enemy he singleha… | [View]
389035504 | https://www.speaker.gov/newsroom/73122 So is she going or not? I am honestly tired of waiting | [View]
389028869 | I have many original papers on 9/11: And just curious if this matters to anyone up | [View]
389035493 | XI GOD EMPEROR WINS AGAIN: BIDEN POOP HIS PANTS AGAIN. US IS A PAPER TIGER WONT DO SHIT TO THE GREAT… | [View]
389029467 | Why more and more mature transitioning every day?: He literally looks like a battle hardened mercena… | [View]
389011091 | Groid woman owned.: I could never understand how the ugliest race of women are the most confident. I… | [View]
389034131 | What are your thoughts on black churches? Do they pass the test? | [View]
389031608 | I discovered an anomaly tonight.: It seems the timeline barrier is weakening. I’ve heard many report… | [View]
389017979 | have any American anons successfully moved to Europe? | [View]
389013677 | You will own nothing: World Economic Forum calls to reduce private vehicles by eliminating 'own… | [View]
389030989 | Women and blacks being stupid: >It’s white people, they created governments and industries all in… | [View]
389008469 | aus/pol/ - aussie owned edition: >https://www.news.com.au/lifestyle/relationships/dating/abbie-ch… | [View]
389031984 | 'The East' is literally globohomo 2.0 | [View]
389028209 | Comfy WW3 General Countdown Thread #7: Previous thread >>389022551 WHERE IS PELOSI NOW | [View]
389026035 | Why Aren't to applying to carry a gun?!: The Supreme Court of The United State ruled that the c… | [View]
389034649 | i recently started wearing a tinfoil lined hat when outside and, hear me out /pol/, I think the tinf… | [View]
389030881 | im sick of hearing women cry about their bodies being outlawed or something. can we talk about how t… | [View]
389030910 | Alright which one of you did this?: An assessment by the auction house reads that the watch was take… | [View]
389032681 | Who won the debate between them? https://youtu.be/S1umh-Pkmxc | [View]
389017919 | How will the white race being raised on medical meth influence civilization? | [View]
389033134 | What's the least nigger car or means of transportation? What's the /white-mode/ of moving … | [View]
389024333 | Previous: >>389016879 Timeline /tug/: https://files.catbox.moe/iupdck.pdf ▶WARNING Be aware, a… | [View]
389033584 | Where are the normal people?: Why is everyone here a fucking sperg when it comes to politics? Faggot… | [View]
389034720 | CHINA'S AIR FORCE IS FLYING TO THE ISLAND OF TAIWAN TO PROTECT THE NATIONAL SOVEREIGNTY AND TER… | [View]
389035122 | Why does it have to be like this? | [View]
388995274 | COLONIZED: The British have been UTTERLY COLONIZED in their own land. >Working class British man… | [View]
389003038 | Women hate children yet we let them raise children.: Isn't that unavoidably unsafe? https://www… | [View]
389022920 | Cannabis & Psilocybin politics: Discuss thoroughly and swiftly, /pol/ | [View]
389033003 | Pastor breaks down in tears over the martyrdom of St George Floyd: https://m.youtube.com/watch?v=dvp… | [View]
389032243 | Was he right? | [View]
389029436 | Rapper JayDaYoungan shot and killed in Louisiana home town: We really need to address this black-on-… | [View]
389022867 | Jim and Chris Chan: Jim's threatening to do daily livestream broadcasts covering the Chris Chan… | [View]
389035032 | Well anons firearm confiscation is here: for your information what is considered a firearm in Canada… | [View]
389033331 | You are not entitled to a job. You are not entitled to be a fascist. You are not entitled to trampl… | [View]
389033668 | Why are Americans so obsessed with race despite being the most mixed country on earth | [View]
389026318 | Assault Rifle Ban: Dey Tak'n Er Gunz | [View]
389021412 | Brit/pol/ - PPE Edition: >Britain pays China £23m a year to store PPE used by healthcare workers … | [View]
389032980 | He fucked ur gf faggot | [View]
389034954 | The holocaust never happened, but Lebensraum was a real objective of Germany and German genocide of … | [View]
389032024 | Good Morning: Can someone explain to me why Americans are like this? | [View]
389034560 | How can whites survive the next century? | [View]
389029676 | When did you realize Christianity is a dead religion? What are the political implications of this? h… | [View]
389031701 | What do you think of Adolf Hitler? | [View]
389030739 | United Statians, everyone. | [View]
389033385 | >O say does that star-spangled banner yet wave... | [View]
389034216 | Can Niggers even organize?: If it was a race war can Niggers even organize and not dancing to oooogg… | [View]
389031851 | Nazis were left wing it's in the name national SOCIALIST | [View]
389034588 | What are the implications of realistic combat simulations for Ukrainē conscripts? | [View]
389029869 | why is everyone making WWIII threads | [View]
389031410 | Any of you retards ever been to Hawaii?: I wish I were brown https://www.youtube.com/watch?v=q6fgVVl… | [View]
389026837 | >2 months of testing >no gov or independent oversight of testing >can't be sued why di… | [View]
389030756 | how the FUCK did this get memory holed? | [View]
389034406 | The Right Is Hanging On: Article from a small town, red state newspaper: The Left Wants To Abolish E… | [View]
389027581 | Would cities be kino if it was whites only? | [View]
389001247 | Two NASA engineers robbed Chick-fil-A in LA for food on the table: Video with sound: https://files.c… | [View]
389034053 | The nice doctrine: for frens | [View]
389028147 | I love my 101 pound anorexic jewish twink bf and there's nothing you can do about it. <3 | [View]
389028130 | Chink shills umad?: The fuck u bitches gonn do bout it? | [View]
389033909 | Ok /pol/, the jig is up. I wanna hear it.: What are your best arguments on why Taiwan shouldn't… | [View]
389031141 | /nsg/ Z National Socialism General Z: >I acknowledge the existence of the Israeli nuclear arsenal… | [View]
388994366 | Rockstar is going to go broke for going woke... wait a minute.. | [View]
389013700 | Why do white people do this? | [View]
389032152 | Heil Hitler: That is all | [View]
389031109 | FUHHHHHH: https://youtu.be/m_BqvhG96Ls in a world far far away, there's only one thing to do...… | [View]
389021982 | The red is how much land the United States military uses in the Japanese island of Okinawa. Why are … | [View]
389023491 | Youtuber /pol/ watches Steven Crowder is transexual proof: Firstly Steven Crowder has admitted to be… | [View]
389023016 | Endgame 2.0: Anyone remember a documentary called 'Endgame 2.0' by Alex Jones? It's been comple… | [View]
389022584 | can it even be called pedophilia if she genuinely loves you?: the whole selling point against pedoph… | [View]
389032266 | Steven Anderson is a snake and a false teacher | [View]
389032502 | Why have all of these major corporations like Disney become political entities driven by Marxist ide… | [View]
389028133 | Pictures of black people you respect: Ill start | [View]
389027890 | So many fucking psyops: How are Yall coping? | [View]
389028995 | Why is it always niggers that steal from companies? When food delivery apps glitched and allowed peo… | [View]
389030301 | i am demoralized as hell why should i not give up on this hell hole and let it die seriously | [View]
389004805 | Zelenskyy is defending his country, how exactly is he worse than Putin? | [View]
389021354 | Working retail in the current day: How do you deal with the niggers that get 'bout it bout it' or tr… | [View]
389018383 | OH MY HECKIN TRUMP DID THEY JSUT SAY NO CANCEL CULTURE? Time to move to a third worldshithole! >… | [View]
389031003 | Fuck off janny trannies. This is a POLITICS board.: Why does the nightshift trannitor keep banning p… | [View]
389029252 | dylan klebold and eric harris did nothing wrong: change my mind. | [View]
389026026 | Anti white movies: I saw alot of anti white crap when I was a kid and when I was a teenager, I never… | [View]
389018199 | Why are christians so degenerate?: The christian world sucks when you compare kids but don't no… | [View]
389023875 | AHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHH | [View]
389020835 | Enlighten me: /pol/ what is your opinion on circumcision? Seen people talking about the evils of cir… | [View]
389001232 | Huge new: Jews are going full on protection mode after the massive study last week proved antidepres… | [View]
389028586 | Israel: Daily reminder that Israel has a logic bomb. https://youtube.com/playlist?list=PLJvL0yl5dUGg… | [View]
389029611 | I love science: Why the fuck do we not put our prison population to good use? We have over 2,000 peo… | [View]
389032484 | ***: o7 | [View]
389024493 | Why did Americans in the 60s think having a castrated basedboy son was better than having a chad gay… | [View]
389023746 | Memory Holed Thread | [View]
389031699 | The future has already been decided.: Here are some “predictions”: >Most of the 1st world falls i… | [View]
389023888 | Why do leftists worship sociology......: and see it as objective truth when it's mostly pseudos… | [View]
389031980 | /pol/ summers are full of spam: It's just past the peak of summer, /pol/. Anyone who was here f… | [View]
389030727 | Femoids: Should they be aIIowed on the internet? | [View]
389019419 | Revive this thread!: I want to know what was said in it. jannies always prune the DMT QRD of what wa… | [View]
389028624 | Hahahhahahahahahahahahahhaha: >Obama supporter >took kids to drag Queen strip show >Outed a… | [View]
389025061 | ARIZONA LEADS THE CHARGE TO RESTORE THE REPUBLIC: https://www.zerohedge.com/political/arizona-attorn… | [View]
389023555 | Anti Porn Addiction: Tyler Durden: Stop..., touching, ....your dick. What're you fucks!? God … | [View]
389028728 | why don't commies just open a co-op though. and redistribute the surplus value evenly according… | [View]
389027447 | Sailplanes Now Part of FBI Airborne Fleet: Sailplane Surveillance Drones: The Newest Cost-Cutting Me… | [View]
389026910 | Explain to me pol why there’s bad people in every group: then how can you be mad at the entire black… | [View]
389032034 | Why are they going after Prince Cuck now?: https://www.dailymail.co.uk/news/article-11065403/Prince-… | [View]
389031532 | Those who belong to darkness will return to it, regardless of which land mass they occupy. | [View]
389019539 | Reddit is the future of social media: Snapchat is for pedos & drug dealers Facebook is for boome… | [View]
389028140 | Pinocchio: Can /pol/ decode this? It will be necessary to avoid a [bad fate] | [View]
389030936 | Inflation Status: DESTROYED: Jacinda Ardern has done it again! Take note third world shit countries,… | [View]
389029804 | WMAF: the future the save the white race? | [View]
389028101 | These retards are sleeping let's talk about them.: >muh grul poor mans food >muh tomboys… | [View]
388996035 | Why are capitalist countries ending up like Zimbabwe? | [View]
389027906 | Putin isn’t a retard. He knows things won’t end with Ukraine. Don't miss the forest for the tre… | [View]
389029509 | Based Skaven: The libturds tried to make the Skaven unappealing by making them resemble rats but if … | [View]
389028788 | Physical features in a mate: What makes women age like this? Pic rel. is Kelly McGillis who played C… | [View]
389030382 | Mex /pol/ thread: Recent news >Americans are flooding Mexico City https://www.latimes.com/world-n… | [View]
389021507 | The Civil War Was Fake: The civil war was a fake war designed to create an environment that would be… | [View]
389031456 | Sources familiar with Timcast say...: Tim Pool's real name is Gabriel Walden >I searched the… | [View]
389026596 | A miss the pre-2006 decentralized internet. It felt like a new frontier; every new page, a new world… | [View]
389031426 | ENDGAME?: Nobody ever mentions Metabiota or their pandemic tracker. WHY??? | [View]
389027786 | Does the USA need to hurry up and swat China?: So that the USA can rule the world for at least the r… | [View]
389030839 | China is getting primed boys.: Lets cup check them. Lulz | [View]
389030181 | The Magical Origin of Niggers: Eons ago, a powerful wizard decided to show off his skills by enchant… | [View]
389025865 | Schizo thread: HIV >spread through animal to human blood contact >Happens in Africa , from men… | [View]
389025272 | What does pol think about this guy | [View]
389027282 | White lives matter: What are the political implications of this movement and why has it been slow to… | [View]
389030385 | TAIWAN STRAIT MEAT BRIDGE: TAIWAN STRAIT MEAT BRIDGE TAIWAN STRAIT MEAT BRIDGE OMFG SO HARD FOR TA… | [View]
389029174 | guys wtf is going on with pelosi are we actually gonna ww3 over this 1-foot-in-the-grave corruptocra… | [View]
389023676 | No black people are bas-... oh shit: https://www.youtube.com/watch?v=wKYg5P2yem4 | [View]
389017086 | MAGA CANDIDATE BUSTED FOR TAKING KIDS TO DRAG QUEEN STRIPSHOW | [View]
389015763 | >Why aren't millennials buying houses or having children? | [View]
389030830 | Submission to torture is their culture. They ask for it. >Thank you for your service to Israel, … | [View]
389026285 | The jewish american legal and government system is basically cancer: If you are already aware of the… | [View]
389029321 | conspiracy mega thread: take one leave one | [View]
389030586 | Gathering of Gaeltacht: Our Guiding Principles A place where Irish is spoken. A place where families… | [View]
389019762 | President Joe Biden has tweeted:: Folks, today I tested positive for COVID again. This happens with … | [View]
389017939 | Albanians are whiter than most Serbs. People in Serbia worship Djokovic a shitskin Gypsy, take a loo… | [View]
389028018 | moskal hate thread | [View]
389027755 | /ALBERTA/ Saturday Style: Thread discussion about Alberta politics, culture, and future. ----- UCP L… | [View]
389010652 | In your honest opinion, what should be the cut off age to live at home as an adult? | [View]
389009205 | The Narcosatanists of Matamoros: >Adolfo de Jesús Constanzo (November 1, 1962 – May 6, 1989) was … | [View]
389028727 | Where is this guy?: He's not rotting away in Guantanamo or anything like that, is he? | [View]
389030257 | The Big Lez Show: What are the political implications of the Big Lez Show? Big Lez was reimagined as… | [View]
389028437 | OI YA GOT UH LIOCENSE FOR THEM RUDE SOCIAL MEDIA POSTS?: Kek, and they say Americans can't hand… | [View]
388987637 | My brother is an “antinatalist”: What are some good arguments against antinatalism? He says the worl… | [View]
389028407 | Slava: Ukraini Slava. Ukraini Slava. Ukraini, Slava Ukraina. Slava Ukraina Slava Ukraina Sla-a-va, S… | [View]
389008747 | LIVE NOW: Mister Metokur — Discussion Thread | [View]
389027262 | Why do so many non rural Southerners say folk \folks nowadays? Especially leftist I hear it has some… | [View]
389027174 | Is the end imminent? | [View]
389028781 | U-ukrainesisters, I thought we're winning. | [View]
389029376 | Are ya ready, folks ? https://youtu.be/-5i4ZGVQGa8 | [View]
389018753 | Shoot it down. | [View]
389023910 | Libertarian /thread (Land Owners and Hunters addition): Let's discuss why we are better then th… | [View]
389028321 | >scared of monkeypox >'gay people spreading monkeypox' stop having sex with men then faggot… | [View]
388964838 | /MOG/ - Monkeypox Outbreak General #128 - First Deaths Brazil/Spain: 23,663 cases in 77 countries … | [View]
388991880 | Nigger stomps italian kid to death: https://files.catbox.moe/4msx8o.mp4 | [View]
389029651 | Why are mudslimes scared of bugmen?: >Palestine jihad >Algeria jihad >Lebanon jihad >som… | [View]
389029612 | 2 tap suicide: What did he know? http://www.kathrynsreport.com/2022/07/casa-c-212-200-aviocar-n497ca… | [View]
389028215 | If you oppose American imperialism, you're a leftist.: Simple as | [View]
389023109 | Demicrats project themselves on incels | [View]
389029508 | >the reverence and love that the American people hold for Africans is superseded only by that for… | [View]
389025966 | Joe Biden said dumb thingy again: dumb dumb president make america look bad! i hate paying taxes to … | [View]
389029091 | I am forgotten: Now that the murals have been painted over and monuments disgraced, was it worth it … | [View]
389013568 | This is not the government: I do not recognize an masonic individual to have the authority to hold o… | [View]
389028997 | CIVILIZATION, not 'culture': https://www.youtube.com/watch?v=j7lilklyiek | [View]
389028051 | EAT SHIT | [View]
389025693 | Gun Owners Shooting Criminals: Hey /pol/ the last thread hit the limit but lets get your weekend sta… | [View]
389025088 | REMINDER THAT BEANERS ARE FAGS: >muh based latinx >muh pious Catholics >muh traditional val… | [View]
389027152 | he cute! | [View]
389028701 | /Pol/ told me that jews have attached earlobes. /Pol/ was wrong again. | [View]
389029094 | 'The East' is literally globohomo 2.0 | [View]
389017299 | The Post-White World: I had a daydream recently which stuck with me. What if the White race chose to… | [View]
389026213 | I support Ukraine, I support Taiwan: I support Ukraine, I support Taiwan, and there's nothing y… | [View]
389028471 | >Islamic State of Rome and Naples >Emirate of London >Islamic Democratic Republic of Sweden… | [View]
389020512 | Germbros, what was it like when you took the redpill and realized that what you were taught is the u… | [View]
389027151 | SLAVA UKRAINI AGHHHHH I THINK IM GONNA SPLODE UGGHHHHHH IM SPLOOOOOOOOOOOOODING AAAAAAAAGHHHHHHHH | [View]
388991800 | Thoughts on Lori Lightfood? | [View]
389025228 | Why did white people do this?: You have to understand everything, the niggers, the fags, the trannie… | [View]
389027324 | Apparently they were innocent: Ethan Liming a white boy who was killed by three remarkable pride of … | [View]
389027550 | Brittany: What happens here? | [View]
389010129 | /ptg/ - PRESIDENT TRUMP GENERAL - THE NIGHT FALLS EDITION: PRESIDENT DONALD J TRUMP @POTUS45 https:/… | [View]
389026691 | What has America contributed to world culture?: I mean beyond fast food, Jewwood, BBC porn, Jerry Sp… | [View]
389027391 | Steven Anderson is a snake and a false teacher | [View]
389026002 | ITT examples of when communism is a good thing | [View]
389025080 | Why Germans are such a faggot crybabies?: see these videos, they can't even show reaction, when… | [View]
389008231 | Is young earth creationism dead or does is still linger on like flat-earth? | [View]
389024329 | What is something you're optimistic about? | [View]
389026883 | Mexicans /Mex thread only: Hello again /Pol , I am asking again from mexicans , if the US civil war … | [View]
388999043 | 'We destroyed the Georgia Guidestones' | [View]
389024666 | Attacks on women are attacks on family: Jews want white men and women to hate eachother so they neve… | [View]
389027267 | You Goy Are Easy Marks: If you had any idea how badly you got fucked just on the Covid loan program,… | [View]
389020858 | My Mom said I have 'White Privlege' today and doesn't care I'm depressed: How over is it b… | [View]
389026445 | Why have there been so many crashes this year? | [View]
389001668 | Russians have spent the last 4 months fighting over the little green boomerang. For comparison the U… | [View]
389013661 | All pedos are white, every single one of them: https://youtu.be/NjPDMBpRbPQ?t=227 | [View]
389025782 | You vill eat the bugs. You will use the gigger.: https://youtu.be/8_8LTUmHWP0 | [View]
389026107 | How do men prevent picrel from happening to them in 2022? | [View]
389027153 | What the fuck was his problem?: Neurotic jew that trooned out. | [View]
389006210 | AMERICANS WOULD YOU VOTE FOR HER: AOC for President ! The Memo: No, really — What if Alexandria Ocas… | [View]
389026253 | Whores in this house There's some whores in this house There's some whores in this house T… | [View]
389007347 | MASS STABBING IN WISCONSON: https://www.fox9.com/news/apple-river-stabbing-one-dead-four-injured-aft… | [View]
389026282 | That's it. I'm done. I no longer care what your political affiliation is. I only care whet… | [View]
389009430 | Disarm the starving masses: Trudeau initiates gun buyback and fertilizer reduction at the same time?… | [View]
389025679 | This thing… | [View]
389027064 | Why it be illegal to doubt the hall of cost?: EXPLAIN IT LIKE I'M AN INDIAN NIG | [View]
389025716 | This map has the highest correlation with degenerate population than any other. Weird. | [View]
389023020 | I am scared, people.: What is the safest country to be during ww3? | [View]
389021786 | How do we stop this? | [View]
389026690 | Was Nick Fuentes in the capital during the insurrection? If yes, why isn’t anything being done to in… | [View]
389020987 | If hitler was truly 'racist' why did he hang out with non whites?: It is said that hitlers best frie… | [View]
389022959 | Why are Canadians so stupid?: Why do leafs consistently have such shit takes? It's like everywh… | [View]
389026030 | /pol puts itself totally outside the right wing with its paganism and anti-Christianity: The average… | [View]
389020130 | Historic | [View]
388983936 | CALIFORNIA IS SHI-: Literally dozens of heaven of earth cities in California >South Bay Area … | [View]
389026653 | why liberalism fail? | [View]
389017269 | Which nigger do you hate the most?: All niggers are worthless, but if you could pick one to just dis… | [View]
389018697 | Race war when?: I know we all want it to happen, but what would it seriously take for the genocide t… | [View]
389006765 | Trump's Thin Blue Line: Police Tackle Disabled Veteran & Tase His Dog For No Reason: North … | [View]
389026663 | Beautiful | [View]
388990620 | Why do trannies keep joining the 41%? | [View]
389026354 | The Hacker Known as 4chan: Goodbye, /pol/ It was fun for the time we had. https://youtube.com/watch… | [View]
389012466 | Were the 90's really better? | [View]
389025218 | how do we solve the '''expat''' problem? | [View]
389026291 | Sources familiar with Timcast say...: Tim Pool's real name is Gabriel 'Gabe' Walden | [View]
389025725 | Israel sucks: The United States should end military aid to Israel... 1. Israel can pay for its own m… | [View]
389026136 | Are childless women in their late 20s/early 30s worthless to society? | [View]
389003742 | You will keep boosting: Dr. Joseph Siedner, an infectious disease specialist at Massachusetts Genera… | [View]
389026051 | 1973 in 2023.: Could a Military Coup be possible in America Today? It's fairly obvious the join… | [View]
389026118 | BILL! Where the Hell are you?!: Bitch, You know its Niggas Night Out | [View]
389022069 | On Patrol: Live #5 - Hooligan edition: On Patrol: Live - Starts at 9:00 PM EDT and ends at Midnight … | [View]
389023503 | I want proof that Jews are responsible for this. | [View]
389022200 | Fraudulent science: One of the most cited papers on Alzheimer's by Sylvain Lesné may have been … | [View]
389023018 | Yuval Noah Harari Must Go: The guy is demonic. | [View]
389026037 | Drought conditions SHTF collective good: My state is in a drought and I just took a long hot shower.… | [View]
389022090 | WE WUZ: We have come full circle now They are niggerfying robinhood literally casting niggers as thi… | [View]
389025647 | 557 days in office. 0 (zero) scandals. | [View]
389022005 | chinks just threatened to blow up our queen. How should /pol/ retaliate ? | [View]
389022551 | Comfy WW3 General Countdown Thread #6: Previous Thread: >>389015799 WHERE IS PELOSI NOW | [View]
389025828 | Boomer Preppers: >All worst things will happen before 2025 What have you prepared so far to get h… | [View]
389025599 | Political implications???: I've met a 14 year old middle school at boxing MMA gym, where we con… | [View]
389020154 | Chief veryracist says niggers should hang like fruit in the trees | [View]
389015084 | NAFRIS OR SYRIANS: Now that the dust has settled Was it nafris or syrian rapefugees ? I believe it … | [View]
389011248 | China Economic Crash: So the US and just about every single other Ally Power, even going so far as I… | [View]
388993747 | It's Over: NYC Locking Up Sardines, Spam: https://nypost.com/2022/07/30/spam-goes-on-lockdown-d… | [View]
389023610 | I wonder why | [View]
389017471 | China vs America: >Biden advises against Pelosi's visit to Taiwan because, according to his … | [View]
389024924 | Resist Putler: Free Ukraine | [View]
389020966 | I thought these guys were feds for months, but I looked them up on Telegram and they do regular post… | [View]
389024716 | Filipinos on Capitol Siege: >The famous Philippine 'walis tambo' was spotted on the Capitol durin… | [View]
389023690 | Damn it Facebook! | [View]
389025016 | Is monkeypox just super AIDS? | [View]
389021816 | This fucking tool: >monkeypax | [View]
389025072 | Nothing ever happens | [View]
389021562 | Where in the world is Nancy Drunk Pelosi? | [View]
389022250 | So I guess none of you cum guzzling retards are going to ask who the fuck this dude is.: Who the fuc… | [View]
389023630 | Nobody trusts niggers. Niggers don't trust niggers. What they call 'respect' is something they … | [View]
389024944 | >NOOOOOOOO THE SCIENCE SAYS DON'T DO THAT >YOU HAVE TO SUPPORT THE SCIENCE!!!!!!… | [View]
389017317 | Women should have to dye their hair and get plastic surgery. Old looking women are gross | [View]
389021001 | Israel 1st for Monkeypox Vaccine: https://www.abc.net.au/news/2022-07-31/after-covid-19-israel-gets-… | [View]
389021737 | Post wall women loving fuckers on this board should be banned | [View]
389016730 | Join the great Aryan awakening. The pic is a symbol of our race and movement. Here is more info. New… | [View]
388996150 | So when is Pelosi finally landing in Taiwan?: Why is she blueballing us so hard? I want to die in a … | [View]
389024167 | The Islamic state has conquered a huge chunk of land in north east Nigeria and neighboring African c… | [View]
389013364 | Reminder to /pol/ users: Stop watching porn. Stop hating women. Stop normalizing interracial porn/se… | [View]
389014045 | Redpill me on Slavery: More specifically the one in the USA. Were the blacks working against their w… | [View]
389014214 | I miss him, bros: What an interview before he died https://m.youtube.com/watch?v=bUhZmO6P0NU… | [View]
389021361 | ALERT ALERT ALERT: Gay men are now actively planning to spread monkeypox to the heterosexual populat… | [View]
389018682 | PRESS F | [View]
389022799 | How do you become a China Expert? | [View]
389021486 | It's a genocide out there | [View]
389021699 | >still no donbass *gasp* *wheeze* BWWAAHAHAHAHAHAHAHAHAHAHAHAHAHAHAHAHAHAHA… | [View]
389017515 | I CAN'T SNEED | [View]
389016879 | /chug/ - Comfy Happening in Ukraine General #4757: Previous: 389008169 Timeline /tug/: https://files… | [View]
389022881 | /nsg/ Z National Socialism General Z: >I acknowledge the existence of the Israeli nuclear arsenal… | [View]
389021619 | 'conservatives' on /pol/ be like: >A heterosexual christian happily married and with kids? >He… | [View]
389021725 | I get looks of admiration and compliments EVERY time I go out. How does this make you feel? Just how… | [View]
389017455 | I haven't showered in a month: I keep getting invited to parties People stand near me Can th… | [View]
389013968 | Mishima said assassination is necessary.: 'For example, if there were no assassinations at all, how … | [View]
389016156 | Comfy WW3 General Countdown Thread #4: Endgame Edition | [View]
389003805 | >fascists think they're revolutionary >they don't even have an international school … | [View]
389022658 | Gas prices are expected to fall. Do you think the same people who blamed Putin for high prices will … | [View]
389022544 | is it possible to hate the antichrist SO much that you die from hate? i just can't take it any… | [View]
388978149 | /pol/ History pictures/gifs | [View]
389020913 | how do we break the chains of goy typography? why can't we create fonts/signs and ligatures in … | [View]
389021843 | Why do Jews and atheists support LGBT so strongly? | [View]
389017077 | Should I fire him up?: ?? | [View]
388986225 | Athlete Deaths Up 1700% Since Death-Shot Rollout: >An investigation of official statistics has fo… | [View]
389021537 | Rate my solution to the world's energy crisis: I haven't gotten patens yet so pls don… | [View]
389022663 | THE INTERNET FORCED (((THEM))) TO REVEAL THEMSELVES: https://foreignpolicy.com/2013/07/14/u-s-repeal… | [View]
389001579 | Europeans are starting to favor learning German over english | [View]
389022709 | Cocksucker: My son, Kurt, loves to suck Jew cock. Do I kill him or let him live? What are the implic… | [View]
389005831 | BREAKING trump BANNED from Fox News: >election night >immediately calls states for Biden inclu… | [View]
389020089 | YOU CANT SAY THINGS: LIBTARDS: DONT SAY NIGGER, FAGGOT, BITCH CHRISTKEKS: DONT SAY FAGGOT, NIGGER, B… | [View]
389022562 | Hunter's not getting my friggin' goysyrup! | [View]
389021863 | Mods actually did something about embedded images, if you have the extension enabled the site doesn… | [View]
389015799 | Comfy WW3 General Countdown Thread #5: Previous Thread: >>389011781 IT'S COMFILY OGRE… | [View]
388972102 | H.R. 1808 - Assault Weapons Ban of 2022: This bill makes it a crime to knowingly import, sell, manuf… | [View]
389020027 | FUCK FLORIDAS NATURAL OJ: I used to drink gallons of this stuff everyday. I bought them over Tropica… | [View]
389019424 | Originally, Police was established to protect white people from the niggers. | [View]
388993473 | Will the United States ever have another decade whose culture was as romanticized as the 1950s? | [View]
389007348 | Sam Harris and NPC philosophy: >>https://www.youtube.com/watch?v=SYq724zHUTw How can he be so … | [View]
389018385 | On Patrol: Live #4 - It's MA'AM edition: On Patrol: Live - Starts at 9:00 PM EDT and ends … | [View]
389016638 | What the fuck is wrong with Arkansas? | [View]
389020385 | anybody else over there causing trouble and arguing with Jew bot5000s? Will there be implications of… | [View]
389017965 | Do you control the production of money or does the government Any government which controls the pr… | [View]
389017478 | /pol is basically leftist at this point: This place is just a hub for retards and subversives who wa… | [View]
389010655 | This is the ancestral land of the Anglo: https://www.youtube.com/watch?v=k0oiXYnc1m8 | [View]
389013136 | PELOSI JUST PASSED OVER OKINAWA: >TFW LESS THAN TWO HOURS TO THE CATACLYSM… | [View]
389020354 | When will he accept responsibility for ruining the economy by promoting this covid bs? | [View]
389020039 | 'Westernised Asians': I keep seeing /pol/cels using this term. >Westernised Asians are SJW libera… | [View]
389014838 | WHO WILL BE THE FIRST CELEBRITY TO GET MONKEYPOX?: They used Tom Hanks to scare normies about the Co… | [View]
388967416 | >You wake up in Philadelphia | [View]
389020725 | Godless sodomites should have listened | [View]
389010562 | I believe this: >CIA psychiatrists break the children and make the shooters. >Once the shooter… | [View]
389013375 | Will LGBT folk be forced to accept minor attracted people into their movement, in coming years? | [View]
389000336 | /uhg/ - Ukraine Happening General #3559: Prev:>>388988270 ▶Day: 158 - Daily battlefield assess… | [View]
388971313 | What causes depression, then? | [View]
389019986 | Fuck all of you, whities straights, all y’all: Homofascism is where it is at | [View]
389021018 | #OFFICIAL CHINA HAPPENING POLLS https://strawpoll.com/polls/BDyNjPz5OyR Will Xi be a cuck or actuall… | [View]
389021009 | /pol/ Humor Thread: Comfy Frens edition: Show me watchu got Fren | [View]
389012581 | Warning to all vatniks: Official statement of the temporary acting commander of the 'Azov' regiment,… | [View]
389015483 | You sure you want a race war non-blacks?: Brotha standard up with a 50 cal sniper rifle firing on se… | [View]
389019644 | >Ever thought of being a NORTHAMPTONSHIRE FIREFIGHTER? >Background image, 2 men (1 white) out … | [View]
389019737 | Is the US afraid of China?: Or will she stop in Taiwan? Place your bets now | [View]
389020776 | Why can’t China use the millions of sleeper agents planted in the island to depose the Taiwanese gov… | [View]
389020196 | Is the a strength of the US or an issue?: In the northeast US this is everywhere, no idea about othe… | [View]
389020229 | Elves = White Valinor = Promised Land wow | [View]
389019364 | I'm sick of your stupid fucking plane happening threads. 1. if pelosi was on a plane you wouldn… | [View]
389005494 | HOLY DOGSHIT AMERICA IS ABOUT TO HAVE A MUTT PRESIDENT | [View]
389019442 | Certificates of deposit: And jews. Why is 80% at least of clients with CDs jewish? I work in banking… | [View]
389020529 | Why did he do it guys?: Why did he cozy up to thatcher and reagen? Why did he cut ties with the east… | [View]
389012910 | Was Ben Franklin right about germans? | [View]
389018024 | What do you think of the idolization of politicians? | [View]
389006708 | Say something nice about 1960 Nancy Pelosi. | [View]
389020358 | T A V I S T O C K: has been in the news lately for encouraging gender dysphoria and shut down their … | [View]
389016142 | 'Trust the science': What does this actually mean in real-terms, /pol/? Where did this phrase actual… | [View]
389001281 | Brit/pol/: >Who will replace Boris Johnson as Prime Minister? Next PM odds and most likely succes… | [View]
389020275 | Have you heard Balkan progressive rock anon? You should: https://youtu.be/_HREqMxBiNE What are its p… | [View]
389020249 | Castration's Shoes - OSINT: Why do people recognize it so badly like my son is 9 months old? It… | [View]
389015530 | This asshole refuses to release the 100 million smallpox vaccines: in the US Strategic National Stoc… | [View]
389019237 | Have white people stopped believing?: I haven't heard this song in a while | [View]
388954536 | /GPG/ GeoPolitics General #2339 - death to iran edition: Palestine, Syria, Ukraine, Taiwan, Turkey, … | [View]
389011301 | What are the political implications of: …just chilling out and not stressing about your race, your c… | [View]
389015755 | OH NONONO BLACKANONS: Why didn’t you listen to the CDC and trust TheScience?? | [View]
389019290 | 7/11 is a part time job: the 9 tennents of the religion of /pol/ 1, darwins theory of evolution is a… | [View]
389016538 | chinks bout to go bye bye: FUCK GLOBOHOMOS FUCK THE COMMIES, EMBRASE THE BIG BAZAAR CHAD BUYS | [View]
389019109 | The question of food provision: Food is the most basic of human necessities. Should a nation be resp… | [View]
389018937 | YO! Xi!: ... this bitch just called you a faggot. | [View]
389018867 | Could this be important somehow? https://archive.org/details/fundamentallaws00ordegoog/page/n16/mode… | [View]
388988459 | TRUMP PRAISES KLAUS SCHWAB: Say it with me now: CONTROLLED OPPOSITION. One more time: CONTROLLED OPP… | [View]
389018426 | I live in a shit hole crime ridden city in Commiefornia: We want to move (of course we can't mo… | [View]
388984799 | What happened to giga-IQ posts on /pol/?: This thread ripped WEF agent Yuval Noah Harari to pieces. … | [View]
389019082 | His Holiness Grovels: NEW VIDEO FROM AMERICAN RENAISSANCE https://www.bitchute.com/video/3iZK9KCbk1… | [View]
389019284 | THERE IS NO WAR THERE IS NO ECONOMY AND THERE IS NO SCARCITY | [View]
389012434 | a pox be upon you fags: Is being a degenerate faggot political or not? Doesn't it affect the re… | [View]
388986915 | The first human to step on Mars will be female. What will she say as he steps down the ladder? | [View]
389019061 | WE NEED WORK WE NEED WIVES THEY DONT CARE ABOUT US! | [View]
389000320 | Would you drink this based QTs raw milk?: https://twitter.com/EvaVlaar/status/1553057546767835137?cx… | [View]
389019076 | Russians founded Rome: Rome founded Judaism and later Christianity and Islam and Dominating the Worl… | [View]
389017223 | Why dont we form our own army?: We all know the collapse is coming soon That we it come, the power i… | [View]
389017839 | this monkey subhuman fucking nigger walked by me today. He said something is his unintelligible nigg… | [View]
389013645 | How long does it take to fly to China from San Francisco?: 3-4 days? >2 weeks?… | [View]
389015558 | Why do Republican ran areas have such higher death rates than Democrat ran areas? | [View]
389015749 | So, you hate this country, but sold your soul to move here.. for what? The privilege of wandering ar… | [View]
389012090 | >those 20s based | [View]
389011572 | Bait thread posting: Post all bait thread images here Give me your best and your worst | [View]
389017512 | Sorry for bothering you: but I just want to know if my man Lil mosey will be accepted into the ethno… | [View]
389016287 | more of a comment really:: December 21, 2020: President-elect Joe Biden receives first dose of Pfize… | [View]
389006614 | McDonald's with Chinese characteristics | [View]
389014093 | If atheism is so bad, how do you explain Europe? | [View]
389009694 | How do you do it? How the fuck do you keep sane with all this shit going on? I feel like i am the on… | [View]
389015596 | There is no way the wildfires are natural: If you have ever been in a forest, the shit that's h… | [View]
389017741 | Okay so if a mexican woman gets pregnant in a pro-life state, is her unborn child considered an acti… | [View]
389014702 | What did he mean by this? | [View]
389018430 | YEAH SCIENCE!: >trannies had their brains damaged in utero >trans rights! I support transitio… | [View]
389018060 | Why are Christians so violent? | [View]
389009444 | Biden got COVID again: Thank god he's double jabbed and triple boosted https://twitter.com/POTU… | [View]
389018145 | If it’s not politically acceptable not to identify as you’re naturally boring sex now. Consider thi… | [View]
389017410 | Hiro said we're allowed one meta thread for board discussion, Janet.: What fucking day is it to… | [View]
389018296 | World Superpowers: if everyone in the world got random superpowers tomorrow, how would it affect the… | [View]
389014551 | nothing changes.: Few people know, but the first explosion of russophobia began during the reign of … | [View]
388952487 | Kraut/pol/ & DAP - Eternal Cycle Edition: >Polls http://www.wahlrecht.de/umfragen/ >Englis… | [View]
389015144 | On Patrol: Live #3 - OFFICER DOWN edition: On Patrol: Live - Starts at 9:00 PM EDT and ends at Midni… | [View]
389014390 | Is California really part of the United States? Be honest. | [View]
389017353 | Official breadtube thread!: This is the official thread for lovers of the comic breadtube. Post your… | [View]
389015496 | Betrayed, once again: Thread theme: https://youtube.com/watch?v=CrvZ9OIF_JQ | [View]
389010963 | Pibbles Webm Thread: Post Em | [View]
389016897 | N@zis on twitter (not sure if that word is banned her): >be me >be bored of just vore and gay … | [View]
389009335 | Current thing: Where do normies get list of %current thing% update ? | [View]
389014697 | Bring back sundown towns: Whites only, after dark. | [View]
389011116 | >Chinese volunteers signing up to take part in Russia’s Special Military operation That's co… | [View]
389017054 | Why do so called right wing and conservative americans simp and defend the ira so much, a group that… | [View]
389015921 | Operation Locate Zelensky: Let's put an end to our European brethren fighting each other. Wher… | [View]
389009339 | Visceral Racism is just Universal lookism biases with extra steps: If there was an ethnic groups / r… | [View]
389015864 | Just watch: /pol/ will refute this. | [View]
389016465 | >still no donbass *gasp* *wheeze* BWWAAHAHAHAHAHAHAHAHAHAHAHAHAHAHAHAHAHAHA… | [View]
389015862 | >shithole is 70% white >commit arson for a fucking nigger >gay as fuck Are you willing to a… | [View]
389008169 | /chug/ - Comfy Happening in Ukraine General #4756: Previous: >>389000882 Timeline /tug/: http… | [View]
389015277 | Women are watching tv show 'Sluttygoss Whoresisters' hosted by blacked pornstars: What are the polit… | [View]
389017070 | WEW today i was wolkin ta work and dis big bleck fakin cunt wolks up and steals mah fakin PETROL... … | [View]
389015654 | Shitpost: >be me >sit in class >listen to a 2hr lecture >the guy sitting next to me has … | [View]
389005956 | Soon, you will die. The nuclear holocaust will begin. A small group of people will survive. They go … | [View]
389008325 | NAFRIS ARE PARASITES: Why do nafris larp as arabs ? Don't they know arabs don't chimpout l… | [View]
389010669 | Some broad from The Gateway Pundit ripped off my /pol thread: Pic rel is her article. https://www.th… | [View]
389014528 | Gun grabbin Jude: How many of you jews are going to kick doors to get guns off the street? You talk … | [View]
389014811 | Niggerification: I live in a college town in downstate Illinois. I live in a decent, fairly middle c… | [View]
389014402 | AAAAAAAAAAAAAAAAAAAAAHHHHHHHHHH FUCKING SCOT FAGS ENJOY YOUR NO DIVERSITY, LOL ENGLAND IS THE BEST Y… | [View]
389006266 | My dad is a big wig official in the Ontario governmental health sector: For the past month he’s been… | [View]
389007714 | BREAKING: TRUMP PROMISES TO LOOK 'VERY SERIOUSLY' AT PARDONS FOR JAN 6TH PROTESTERS!: >… | [View]
388997334 | >trannies aren’t women because they don’t have wom- Oh… damn | [View]
389009107 | I thought the Le 56% face was just a meme: Explain yourselves burgers | [View]
389016281 | What sort of 4D chess is this? | [View]
389003393 | How is the life in a homogeneous country? | [View]
389009329 | /POL/ MUSIC THREAD: POWER VIOLENCE EDITION: ANY ANONS DOING PUSH-UPS IN THE PIT? DISSAPOINTED FULL O… | [View]
389016088 | Joe biden watching his army of obese faggots obliterate the entire Chinese military in 7 hours: Nanc… | [View]
389006220 | They were treated like they were insane, but they were right. Rick Santorum too. They said the slope… | [View]
389015859 | Now that the dust has settled: Was it? | [View]
389005909 | Nazi German music: I remember 10 years ago I used to be able to find Nazi German propaganda songs an… | [View]
389015879 | The Pelosi story is bogus and you're being played: >China never said it will shoot down the … | [View]
388987445 | I want to join, what am I in for? | [View]
389015227 | Trump 2024: https://www.youtube.com/watch?v=8-2umcHnUdo Post your Ultra Maga anthems | [View]
389011636 | The possible return of the Russian Empire: Depending on the results of the Ukrainian war I think we … | [View]
389012598 | Farewell, friends of the Internet. I will try to change my life, or even reduce the pain of being al… | [View]
389012226 | HAPPENING: DALL-E AI predicts the end of civilization https://twitter.com/LooksRare/status/155338045… | [View]
389006025 | Nothing you do matters. You cannot save society or civilization. We are in the decline before total … | [View]
389011781 | Comfy WW3 General Countdown Thread #3: Previous Thread: >>389003113 PLANES ARE REACHING TAIWAN… | [View]
389013974 | . | [View]
389009748 | Redpills on tranny thread? | [View]
389012053 | Dare I say, based? | [View]
389012094 | BARRON TRUMP: Now that the cheeto dust has settled... What was his power level? Was he controlling t… | [View]
389013362 | Half of whites in America over 44: This was 2019, it’s probably higher by now. Latinos can have a ba… | [View]
389006687 | the perfect grocery store for the ethnostate?: 1. grassfed, pasture raised dairy, meat, egg, milk 2.… | [View]
389008591 | https://youtu.be/_vO4hk4dxa0 not q huge fan of this guy but he posted this recently. Apparently it… | [View]
389008182 | Has China bombed Pelosi's plane yet? | [View]
389012683 | Lmaoooo | [View]
388985478 | https://youtu.be/KjaHsXUmv-8 I'm watching this movie rn for like the 5th time. It's so ins… | [View]
389010847 | On Patrol: Live #2 - 'Diabetic' edition: On Patrol: Live - Starts at 9:00 PM EDT and ends at Midnigh… | [View]
389012453 | Would they arrest him if told to? | [View]
389013526 | TWITTER BTFOS: MATT WALSH WITH FACT CHECK HE CANT REMOVE. Your thoughts WILL be corrected for the wo… | [View]
389014584 | What happened to Romania and Hungary?: These two countries used to have two of the strongest peoples… | [View]
389005964 | Russian women are fleeing to China: How do Russians cope? They are treated much better in China than… | [View]
389012525 | Ask an American communism vs monarchy their whole understanding is a spook | [View]
389006513 | This is fine | [View]
389013821 | ETA on WW3 Update: Pelosi left for her Asia trip around 4am CST. She either left from DC or from Cal… | [View]
389014283 | The VDV drop was supposed to work. Zelensky was supposed to flee Kiev. Their army wasn't suppo… | [View]
388998489 | Mixed race couple commercials: Is it just me or are the mixed race couple commercials just completel… | [View]
388998559 | Guess their names, pol | [View]
389014035 | Hot Mic: Matt Gaetz refers to Trump as 'The Boss': >'The Boss still has a very favorable view of … | [View]
389012650 | White and NatSoc thread: Why is the christian world so weak and degenerate? | [View]
389007876 | CHINA WILL BE A FULLY SUSTAINABLE COMMUNST COUNTRY WITH NO CAPITALIST INFLUENCE BY 2049: CHINA IS EF… | [View]
388988607 | MONKEY POX CASES INCREASING % WISE ON THE WEEKLY >LAST WEEK 20% INCREASE (4,000 cases) >THIS W… | [View]
389004100 | Does anyone else think talking to women is like walking on egg shells: They get offended so easily a… | [View]
389012786 | UC Berkley: Is this the right way to talk to a Professor from UC Berkley: Asking for a friend.… | [View]
389004733 | TAX. THE. FUCKING. BILLIONAIRES.: I HATE THE BILLIONAIRES >I HATE THE BILLIONAIRES I HATE THE BIL… | [View]
389014102 | Who's REALLY getting the pox? vaxxies only? Is there any pureblood who's infected with the… | [View]
389012678 | American Culture: In this thread we post examples of unique white American culture. https://www.yout… | [View]
389006637 | Why is medical bankruptcy a strictly American phenomenon? | [View]
389013879 | Idles: What is the politics of these fags? | [View]
389012858 | I want to go back to 2010: I want to be noticed by girls again I want to have a big dick again I wan… | [View]
389000230 | Does /pol/ want this? This would be the straw that broke the camels back and spark a civil war if it… | [View]
389002851 | >Europe about to get fucked by Russia and pulled into WW3 >niggers swarming Italy daily >ne… | [View]
389006674 | IT'S: OVER | [View]
388995633 | yep, clown world is officia | [View]
388991988 | /SKG/ SKYKING GENERAL: DO IT FAGGOTS Wide-band Web Receiver >http://websdr.k3fef.com:8901/ >h… | [View]
389012864 | Justice Dead!: Here is some truth: #Liberals and Country Club #Conservatives are 'anti-racist… | [View]
389004670 | Fox News Banning Trump From Network: https://www.newsmax.com/newsfront/fox-news-donald-trump-republi… | [View]
389013502 | /NZG/ - New Zealand Genera: >Why NZ’s all black mood bodes ill for Ardern ahead of election https… | [View]
388973915 | Matt Walsh exposes another climate hoax: Jesus Christ, does the right ever get tired of embarrassing… | [View]
388998184 | why is /pol/ scared of abortion? honestly. It literally does not affect you in any minimal way. Do … | [View]
389006875 | Refute this: 100% of the white supremacists on this board are only such because they have nothing el… | [View]
389010478 | Africans love gay sex | [View]
389013357 | What are some doomsday conspiracy: that might happen this year? Need some copium to feel like things… | [View]
389013245 | Why the fuck are you schizophrenics all going on about WW3 being imminent? | [View]
389004001 | Join the great Aryan awakening. The pic is a symbol of our race and movement. Here is more info. New… | [View]
388992085 | BREAKING NEWS!!!. Will COVID win this time?? BIDEN infected again.: US President Joe Biden tested po… | [View]
389009839 | how does anyone actually take Ellon Musk seriously? | [View]
388997445 | Russian spy is charged with stoking racial division in US: Russian national Alexander Ionov is accus… | [View]
389004008 | sweden rape statistics: is this fake? Unless the country is in a constant civil war I don't see… | [View]
389010397 | Country and People Archetypes: Let's find out the similarities of some countries and peoples. Y… | [View]
389003520 | >meet an 21-years old Arab guy on discord >He's pretty chill, dosen't really believe… | [View]
388941073 | Neder /pol/der general: the CIVIL WAR Of The Netherlands: >Another day, another escalation: - CAO… | [View]
389003111 | What are /pol/s thoughts on Aryans?: These guys are responsible for 1/3-1/2 of White peoples DNA. Wh… | [View]
389010363 | Meet the world’s biggest pussies.: >Threatened to shoot down pelosi’s plane if she goes ahead and… | [View]
388999624 | HAHAHAHAHA WHAT THE FUCK | [View]
389009750 | Soon | [View]
389005430 | When you're alone and life is making you lonely you can always go: Downtown. | [View]
389002934 | UK orders shutdown of child tranny clinic after investigation: >The Tavistock Gender Identity Dev… | [View]
389011487 | >If YOU GO TO TAIWAN THIS MEANS WAR >doesn't do shit Is this the power of the almighty ch… | [View]
389001530 | NAFRIS OR SYRIANS: Now that the dust has settled Was it nafris or syrian rapefugees ? I believe it w… | [View]
389008281 | Who wants monkey pox! Got a new batch coming in a minute! | [View]
389003264 | wtf you guys told me r*ddit wasn't based | [View]
388995756 | The nukes are airborne. What do you do in your final minutes? | [View]
389005721 | Redditors and zog apologists think they are smarter than 130+ I.Q. PhDs. When the data bears out tha… | [View]
388969755 | Elvis Presley was the downfall of the white race: Elvis critics were right when they said that allow… | [View]
389010171 | 90% of ethnic Russians have blue eyes Does that trigger you pol mutts? | [View]
388978407 | Why are British houses so ugly, poor quality and built of some stupid dirty bricks? | [View]
389008699 | Industrial society is destroying everything that we value.: Technological progress not only is chang… | [View]
388956938 | 'the schools in this area are really good' is code for this is a white neighborhood | [View]
389010200 | How do we solve the homeless problem?: Do we just kill em or what? | [View]
389008408 | How can 1 small british country named 'Falkland Islands' make Argentinians seethe so much? | [View]
389011656 | Based Pinoy on the Capitol Siege: >The famous Philippine 'walis tambo' was spotted on the Capitol… | [View]
389005537 | There you go, answer settled permanently, now let’s move on | [View]
388999028 | IF YOU CHOOSE TO JOIN US YOU WILL NOT WANT FOR ANYTHING IN YOUR LIFE EVER AGAIN. YOU WILL BE GIVEN A… | [View]
389007228 | Kushner says John Kelly ‘shoved’ Ivanka at White House: Kelly, who Kushner and wife saw as ‘consiste… | [View]
389006257 | >What do you think about slavery? Was it wrong? >It was wrong to bring them over here to start… | [View]
389007223 | American Airlines passengers were left 'sobbing' after being held on a hot plane for six h… | [View]
388981351 | SAFE AND EFFECTIVE | [View]
389006323 | What's the deal with Anonymous now?: Do they even hang out on 4chan anymore? It seems like a bu… | [View]
388992220 | She's going to cause WW3. | [View]
389008927 | Finally some good news, sounds like this whole pandemic thing is starting to wind down now. | [View]
389008532 | Is he the real mastermind behind everything that has been happening? | [View]
389003464 | Who's winning? Or is it a co-op type of game? | [View]
388977864 | Historic | [View]
388993333 | these are terrorists, not activists: Just deflate their juggular | [View]
389009327 | Having a rare flag should be considered avatarfagging. | [View]
389002050 | Blue Beam Incoming: “Blue” “Blue Dress” You ready? | [View]
389010944 | Those who study history are doomed to watch other people repeat it | [View]
389006717 | Am I the only one who sees the similarities here?? | [View]
389009148 | The Ukraine War was orchestrated by China to solve its incel problem.: >China has 35 million unma… | [View]
389010650 | Why did we lose the cup match bros? Is the manager a jew? | [View]
389005513 | ON PATROL: LIVE #1 PREGAME EDITION: Yesterday and last weekend baker here. I won’t be able to bake t… | [View]
389003113 | Comfy WW3 General Countdown Thread #3: Previous Thread: >>388979550 Some US Military airplanes… | [View]
389007094 | Is there anything more based than being a hobo in Portland?: https://www.oregonlive.com/news/2022/07… | [View]
388991520 | /ptg/ - PRESIDENT TRUMP GENERAL - IDIOT AND FRUIT IS NOT FOR M00T EDITION: PRESIDENT DONALD J TRUMP … | [View]
388998580 | > claim to be the sane ones > trash 'mental illness' of other groups > obsessed with eugeni… | [View]
389004449 | Americans...: Hello, anyone else see through the Americans on this board? They are the biggest prete… | [View]
389006805 | Why hasn't anyone mentioned that Q destroyed the Guides Stones?: barely seen this posted | [View]
388998891 | I keep seeing people claim that monkeypox is an std. It's apparently spread exclusively in the … | [View]
389009900 | Kneel before Chinese superiority gweilo | [View]
389008396 | What would happen if we /pol/ tards suddenly became giants and ruled the world with a smelly but big… | [View]
388997518 | Why did mentally ill leftists attempt to steal the word 'based'? | [View]
389005887 | Schizo thread great | [View]
389009621 | America is collapsing. >And that's a good thing | [View]
388993342 | They need to increase the speed limit on the highways. Half of the german Autobahn has no speed limi… | [View]
389003324 | 12th century politics: >Here begins our laws, and we shall bend towards the east >and give ou… | [View]
388998756 | Why DOES Applebee's have a child bride section? | [View]
388997887 | Catalyst Converter Ring busted: “one stolen vehicle, 455 converters, 29 guns, 2,800 oxygens sensors … | [View]
389007866 | Why does this board avoid discussing Indo-Europeans: >Is called /pol/itically incorrect >1000s… | [View]
389003764 | Why have women fallen for the globalist propaganda so badly? Is it the need to conform and be liked… | [View]
389001448 | How come trains don't derail in japan? America is a shit nigger country | [View]
389008296 | Why American gotta start shit?: Bully the whole world, and for what? I don't feel rich. | [View]
388997973 | Why are they so afraid to wear the label?: This just makes her appear as a coward. We need more peop… | [View]
388991406 | In the 70s scientists came up with the nuclear pulse engine (More commonly known as the orion drive)… | [View]
389007551 | Russian, Chinese, and Israeli spies are sowing dissent in our countrie-ACK! | [View]
388998352 | WOMEN WERE A MISTAKE: https://twitter.com/RexChapman/status/1552839661709565952 | [View]
388993742 | WTF GUYS: I thought you guys were being ironic about not getting the clot shot. All my friends told … | [View]
389008100 | Druk and drug bros: It’s time to get fucked up the nukes will fly | [View]
389008070 | All of you are gay. Prove me wrong. >Protip, you can't | [View]
388982337 | SilverSteele is right, you know?: Why is Andy Ngo doing this to a fellow gay man? | [View]
389008074 | On Patrol Live /opl/ WHERES THE BAKER EDITION: On Patrol Live (formerly LivePD) thread. Didn't … | [View]
388958366 | World War 3 would be a blessing for Europe: Assuming USA and China don't nuke each other and on… | [View]
389000882 | /chug/ - Comfy Happening in Ukraine General #4755: Previous: >>388992350 Timeline /tug/: http… | [View]
389003214 | Why is Great Shitain still called a country of freedom these days?: I mean, the political standards … | [View]
388999088 | Why are the republicans in the US seemingly allowed to work their religious belief into their laws? … | [View]
388997004 | Homeowners Association: Can somebody explain why these organizations are even a thing and what justi… | [View]
388998200 | Minecraft Update: What are the political ramifications of the best selling game of all time rolling … | [View]
388990129 | Antithesis of communism: The antithesis of communism is Calvinism | [View]
388997515 | What is the solution to Western media? | [View]
388971054 | If being gay is 100% biological than no amount of propaganda can turn kids gay. Virtually nothing ca… | [View]
388972724 | White people are stupid as fuck: Why get mad at brown folk like us taking over the place when your b… | [View]
388995638 | Popular conservative writer Ann Coulter called (https://www.express.co.uk/news/world/1647823/Piers-M… | [View]
388998255 | We've been seeing articles coming out linking a rise of health issues being attributed to every… | [View]
389007880 | Why are Romania and Hungary so boring these days?: These two countries used to have some of the stro… | [View]
388993689 | Why haven’t they taken Ukraine yet | [View]
389004199 | I'm double vaxxed+ double boostered. When am I going to die? | [View]
388999163 | ‘Woke’ billionaire who trashed the Founding Fathers - (((Rubenstein))): https://nypost.com/2022/07/3… | [View]
388981480 | The saviors of the white race have arrived. | [View]
389005854 | ON PATROL LIVE: Anyone got any links that work? | [View]
389005711 | Boomers of /pol/: What is the point of wagekeking if this society will collapse in 10 years or less?… | [View]
389002002 | Will Nancy Pelosi make it out alive? | [View]
389005979 | Should we tax psycopathy?: Should we tax those companies that are toxic for human minds, bodies and … | [View]
389005097 | What happen to the Climate Change Scare of Last Week?: Memory hole… | [View]
388982397 | aus/pol/ - fuck vaxxies morning edition: >https://www.news.com.au/finance/economy/australian-econ… | [View]
388990144 | The Germans are starting getting angry again | [View]
389004218 | Gun Owners Shooting Criminals: Hey /pol/ the last thread hit the limit but lets get your weekend sta… | [View]
389002331 | This is your brain on scientism: https://www.youtube.com/watch?v=YM1HwIFBd9U | [View]
389000804 | Why do right wing white guys who accuse others of being se sexually degenerate perverts so often get… | [View]
388997451 | Serious question: How many of you are economically maintained by mum and dad or are just too young t… | [View]
389004689 | War on Ukraine is a failure.: Russians are barely able to move on, they failed with their attacks on… | [View]
389006511 | Into the Gulag: The Insane Tribe of Chicken Twirlers is at it again; Marxist by nature that lot are!… | [View]
389003413 | AMERICA IS COLLAPSING | [View]
389002581 | What the fuck it's going on bros? It's the president of the u.s a fucking deepfake? Is he … | [View]
389003877 | Violence towards health care workers on the rise: S o o n 100% political since it directly correlate… | [View]
389004783 | Why are thots and housewives becoming the faces of the alt right? These fucking thots shouldn’t be a… | [View]
389005007 | post yfw they come out and admit that biden just died (because he did and they're in a panic) I… | [View]
389005498 | WESTOIDS WHAT'S WRONG WITH YOU?: Why do you promote downie homosexual dwarf drag hobbos? VID : … | [View]
389002707 | It's almost spicy time.: It's time to learn about HF radio comms. Dead drops Institutiona… | [View]
389004860 | Food prices/scarcity is for the SHEEP: >go to big name store >food is shit-tier quality and co… | [View]
388987235 | How do we stop whites obsessing on nigger “culture” even you could even got it that | [View]
388969922 | Why does /pol/ support Russia if they have more in common with these guys? | [View]
388997557 | US military base hosting a drag show at a 'family friendly' festival: I don't get it, why aren… | [View]
389004273 | Russian video: https://youtu.be/A68d-14O0-Y OMFG AHAHAHAHAHAHHAAJAJAJAJAJAHHA I haven't laughed… | [View]
389004579 | Whats taking so long? Are they waiting for china to shoot down pelosi? I can’t take another blue bal… | [View]
389005704 | Why do bongs/north euros hate their own ancestors so much that they compare them to modern shitskin … | [View]
389001170 | The CIA program uses psychiatrists to turn children into shooters: CIA psychiatrists break the child… | [View]
388996732 | Would it be accurate to say that the dissident right is now mostly an anti-woman Christian fundament… | [View]
388988610 | /pol/ movie night: We're watching Onions Green and of course discussing the political implicati… | [View]
389003274 | itt: we write a get well letter to our leader president Joe Biden I'll start Dear, | [View]
388999539 | Biden was vaxxed, infected, cured, and infected again: COVID-19 hysteria has got to be one of the mo… | [View]
388997317 | Why aren't more people calling for a separation between science and government?: Why should any… | [View]
389003175 | Spread the word...: NIGGERS LIED, TRANNIES DIED! | [View]
389005324 | Did putin get бaнaн yet? | [View]
389005092 | L'Jarius Sneed | [View]
389002694 | you don't see people from this country here because they're happy | [View]
389003750 | APOLOGIZE: Snopes DEBUNKS /pol/ once again, do they ever get tired of winning? | [View]
388998283 | A Solution to Japan’s Overwork: Sleep in an Upright ‘Nap Box’: https://www.bloomberg.com/news/articl… | [View]
388997991 | Biden got COVID again the same day Pelosi deported to provoke war with China. What are the chances i… | [View]
388977707 | Warning to all vatniks: Official statement of the temporary acting commander of the 'Azov' regiment,… | [View]
389004116 | What are the political implications of: >Saturday night drink cobras… | [View]
388989407 | why do amerifats still have pennies? | [View]
388997981 | Picture related: Opinion on anglos? | [View]
388997983 | /pol/ story time: >Be me >Some minority kid with glasses from the Philadelphia Area. >Its … | [View]
388998795 | John Howard Carpenter will DIE on.....: Obamas 61st birthday in a satanic ritual maybe https://gemat… | [View]
388976782 | We need to rally behind Owen Benjamin in order to save the United States | [View]
388965982 | Italy has a George Floyd: SAY. HIS. NAME. >alika ogochukwu https://youtu.be/1a60BZJrNJA… | [View]
389003396 | Political implication of circumcision ban: What would the political implications of making male geni… | [View]
389001626 | psycho streamer: Jerma fan cuts her tits off and decides to share with the Twitch Gender Studies cla… | [View]
389000993 | >https://www.documentcloud.org/documents/22123849-free-speech-systems-bankruptcy-july-29-2022 … | [View]
389001820 | FUCK THE DUTCH FARMERS: Anyone else think we should fucking drop some AGENT ORANGE on them n shit? … | [View]
388998872 | Russia is stealing gold from people of color using the wagner group to fund its war in Ukraine. You … | [View]
389000231 | Should the media be free from consequences? | [View]
389003176 | Anon, you've read the 1619 Project right?: It was a NY Times best seller. Americans declared in… | [View]
388967800 | MONKEY POX WAS FIRST OBSERVED TESTING POLIO VACCINES IN A LAB: >https://youtu.be/G0AZsQ_UCbg?t=32… | [View]
388995972 | Why don't they just agree to be separate countries? Taiwan gives up claims on Mainland, mainlan… | [View]
389003683 | /nsg/ Z National Socialism General Z: >I acknowledge the existence of the Israeli nuclear arsenal… | [View]
389002526 | He redpilled an entire generation. | [View]
389003510 | It is no longer safe to be pregnant in a red state. Pregnancy complications and miscarriages are mor… | [View]
388987634 | Taylor Swift has emitted more co2 this year than an average US american does within 550 years and mo… | [View]
389001302 | 'White boys': White men have politely used the term 'white woman' while black dudes and pedo females… | [View]
388987723 | Why is Germany so bad at politics? | [View]
389001892 | Joe have covid again. How do we save joe from covid? | [View]
388994799 | What was the morning of 9/11 like? | [View]
389002338 | Maintain order and purity. | [View]
388998511 | /pol is basically leftist at this point: This place is just a hub for retards and subversives who wa… | [View]
388969918 | RUSSIA SENDING UNIRONIC BOOMERS TO THE FRONT: RU volunteers heading to the war with Ukraine. Not exa… | [View]
389002351 | Biden rebounds on kung flu: https://web.archive.org/web/20220731001210/https://www.foxnews.com/polit… | [View]
389002656 | City people are unironically insane. | [View]
388993307 | We need KEK global revolution: >The head of the Swiss State Secretariat for Economic Affairs (SEC… | [View]
389001883 | M I C H I G A N: By all acounts Michigan should be kicking the shit out of Minnesota and Illinois. B… | [View]
388995674 | Daily reminder that the Holocaust didn't happen But it should have | [View]
388985955 | For those that lived through the 1990's, was life really better than in modern times? https://w… | [View]
389001147 | ‘Soon it will be unrecognisable’: Hothouse Earth and near term human extinction are inevitable. That… | [View]
388995236 | How do Mao supporters explain away the three pests campaign? How do you sweep that ridiculous level … | [View]
388998737 | preemptive strikes on NATO facilities?: nothing to see here folks just Moscow practicing air raids. … | [View]
389000425 | Single handily changes world history for some better future. is there a bigger GIGACHAD? | [View]
389002520 | whitepill thread | [View]
388992557 | memory hole thread | [View]
388974238 | Prove you’re not a blind schizo: Say one (1) thing you like about Klaus Schwab | [View]
388991620 | I fixed the US: thoughts? | [View]
389000757 | Britbong police arrest someone because his social media post caused anxiety for someone. The police … | [View]
388998979 | Grifter Maximus ...: When Trump started “Save America” and begged for “recount money” I learned from… | [View]
388995927 | India: Hello /Pol/ What is the first thing that comes to your mind when someone mentions India. I me… | [View]
388998850 | is there a single country (where they aren't the majority) where blacks don't commit a dis… | [View]
388991458 | It's over whitoids: This literally comes from the guy who directed the agency that oversees the… | [View]
388997729 | I would be extremely embarrassed if I was Chinese.: >Didn’t stop pelosi’s plane as they said >… | [View]
388996147 | Do you support iran or usa? | [View]
389000202 | Some buldings in European cities are literally older than muttmerica: How does that make you feel?… | [View]
388998923 | >thanks for the billions of dollars you repulsive obese maggots | [View]
388973947 | What are the political implications of mutts larping as nationalists?: Why do mutts LARP like they… | [View]
389001513 | Post some other redpill movies/documentaries: It has 2.4 on IMDB so it might be controversial. Post … | [View]
388997700 | Why do cute twinks like the July 4th shooter go on killing sprees instead of getting a man to love h… | [View]
388987577 | HOLY GUACAMOLE MEMES IN REAL LIFE: https://youtu.be/Yc-Va7IqVvw | [View]
388999126 | >Russia invades the Ukraine >massive influx of pro Russian posters that seemingly came from no… | [View]
389001498 | greg johnson: why is this guy never discussed on pol? | [View]
388996399 | Without immigrants how can you have kebab? | [View]
388991421 | Brit/pol/ - Freedom for Nasty People Edition: >PETER HITCHENS: Freedom for all means freedom for … | [View]
389000732 | What are the political implications of Michigan's next conservative governor being a total smok… | [View]
388999295 | Latvia leeches in recession: They did it to themselves | [View]
388994215 | They are poisoning the water supply.: The CDC is given access to municipal water supplies to test co… | [View]
388995386 | Ivana Trump's grave at Trump golf course: Hahahaha holy shit what is wrong with Drumpf. | [View]
388987533 | FUN FACT If Poland joined the Axis the Axis powers would win, and we would have conquered entirety o… | [View]
388992350 | /chug/ - Comfy Happening in Ukraine General #4754: Previous: >>388985935 Timeline /tug/: http… | [View]
388994585 | Fuck it, Nuke Ukraine: What's stopping Russia from Nuking Ukraine? | [View]
389000951 | Happening; US are doing exercise drills at Honolulu: Pelosi hasn't left Hawaii still and they… | [View]
388996442 | Why are bunker chuds so low IQ?: Every single nuclear weapon holder posses modern nuclear missles wh… | [View]
388994688 | SLAVA TAIWANI: SLAVA TAIWANI | [View]
388983073 | only Native-Americans should be allowed to live within the America's: please get tf off our lan… | [View]
388967164 | How common is being friendless in 2022?: I feel like it's way more common than it seems I will … | [View]
388995569 | Boomers becoming homeless: Boomers, in their infinite wisdom, set everything up to make housing comp… | [View]
388988197 | Be careful out there bros... | [View]
388976512 | HAPPENING: PELOSI SPOTTED: >USAF >no callsign >no destination >this one is actually real… | [View]
388994698 | Geography reveals the reason: vengeance for first zion: https://en.wikipedia.org/wiki/Doh%C3%A1ny_St… | [View]
388987114 | ABSOLUTELY HAPPENING: I'm a geologist and I can tell you 100% there are NO asteroids scheduled … | [View]
388987562 | China invasion of Taiwan is imminent. Just a matter of weeks like Russia and Ukraine. https://www.d… | [View]
389000088 | Thoughts /pol/? | [View]
388988270 | /uhg/ - Ukraine Happening General #3558: Prev:>>388977020 Jannies tongue my anus edition ▶Day:… | [View]
388979550 | Comfy WW3 General Countdown Thread: Previous thread: >>388973573 At least 3 planes are on the … | [View]
388993984 | California Santa Clara San Diego Los Fresnos Florida Colorado Montans Tejas San Francisco Las Vegas … | [View]
388998190 | Am I the only one who is fine with their being a Jewish state that spans from the Nile to the Euphra… | [View]
388997721 | There is no recession, /pol/: And even if it is, it’s a no biggie. | [View]
388987399 | The saviour of western civilization: IF SHE DOESN'T GO TO TAIWAN THEN AMERICA IS ALL TALK NO SH… | [View]
388948265 | What did they mean by this? | [View]
388998089 | Communism comes from the talmud and Lenin was a kike. Why does Putin lie so much? | [View]
388966039 | QRD on this shit. my job requires vax and this is available near me now. | [View]
388995732 | > be me > try to sell some unused electronics from my basement > some of the stuff is more … | [View]
388987668 | These two cunts are running for governor of Arizona: I can't afford to move to another state.… | [View]
388998733 | United Kingdom - Home of the Monkey Fuckers: Lmao. I just found out you are nigger lovers. You fucke… | [View]
388994476 | 4chan shut down September: Is this some sort of prank or troll? I seen several anons mentioning this… | [View]
388979988 | SELF IMPROVEMENT GENERAL /SIG/: Welcome to /SIG/, a classic staple not only of /pol/, but all of 4ch… | [View]
388993872 | Paganism is on the Rise: Embrace your Native European roots and reject the Abrahamic faiths. Restora… | [View]
388997776 | Lauren Southern is in the news again | [View]
388991415 | white genocide isn't real. but it should be | [View]
388996441 | NON-GENDERED PEOPLE OF EARTH, I PRESENT TO YOU THE NEXT PRESIDENT OF THE USA!: It's not too soo… | [View]
388990882 | Why haven't you taken the minimalist-pill yet? | [View]
388998674 | political DALL e / craiyon thread: post em if you got em | [View]
388998014 | >All weather events are caused by CLIMATE CHANGE! >CLIMATE CHANGE is caused by HUMANS! >Whi… | [View]
388997394 | >speak about the war in the ukraine >get 15 years in a prison… | [View]
388975197 | Ctrl-f humor no humor thread: Humor thread Fuck off jannies, political humor is politics. | [View]
388985454 | Europoors will never understand this level of freedom | [View]
388995683 | What does /int/ think about the Russia-approved ‘decolonization of Europe’ map? fr fr i think they’r… | [View]
388994413 | Straight men can get monkeypox: It really needs to STOP being reported as a gay disease. Straight me… | [View]
388998379 | China announces live-fire naval exercises ahead of possible Pelosi Taiwan visit: >Pelosi announce… | [View]
388992363 | John F Kennedy would be proud of Pelosi: Today Nancy Pelosi got my respect. Not gonna lie. She is a … | [View]
388996134 | What's a woman? | [View]
388996999 | Why the fuck americans do this?: 20k americans pay 18k usd tickets to fill a stadium to see a youtub… | [View]
388996404 | Are lawyers based and redpilled? | [View]
388985202 | Tavistock Gender Identity Development Service (GIDS), England’s hub for child gender reassignment wh… | [View]
388997573 | SECOND EURO MONKEY POX DEATH: SOMETHING BURGER CONFIRMED >https://www.washingtontimes.com/news/20… | [View]
388979865 | Why is Japan doing so well economically?: They lost the war against the Jews, got fully occupied by … | [View]
388988702 | FARMS: I want to live on a farm | [View]
388993407 | I don't feel anything: Wtf happened to this world | [View]
388976602 | Are the Dutch the superior race?: >Tallest >Aryan >Very high standard of living >Better … | [View]
388986847 | Pelosi Fly By With Elite Military Escort About To Arrive In Taiwan: How bad ass is she? Flying right… | [View]
388997865 | We Wuz Kangz | [View]
388997863 | Who is jewing who? | [View]
388989833 | Norwegian Consul Elisabeth Ellingsen at the Murmansk hotel was asked to wait until her room was clea… | [View]
388997774 | Wake up already, The shooters all have CIA psychiatrist: Fuck the CIA and their gas lighting tactics… | [View]
388997733 | WLM are a bunch of snobby fags: All these fuckers do is throw up posters and put stickers around but… | [View]
388994464 | Stop sucking Republican dick: All of you ‘patriots’ who waste their lives shooting up schools or sup… | [View]
388994209 | POWERFUL | [View]
388982268 | Question for /pol/.: Is there a balance between the Malthusian Spirit and Faustian Spirit? | [View]
388996906 | Why is China so afraid of Covid?: Any Chinese person can tell me what’s going on I’m assuming this r… | [View]
388996670 | Professional NEET here.: 15 years on the force. Seen some comfy shit. AMA | [View]
388991925 | It's Over Goyim, we won: You will own nothing and we will be happy. | [View]
388993088 | San Francisco AIDS Foundation 'cover up your bumps and don't skip the piggy parties': Encouragi… | [View]
388996029 | We have already banned the letter Z. What is the best letter we need to ban when these guys are inva… | [View]
388993982 | >people bought in at $200+ Was this just another kike scam? | [View]
388996648 | Why would anyone fear the bugman army? Their weapons & vehicles are held together by duct tape a… | [View]
388996579 | Gaymers, Nigger: What happens when niggers and muslims murder all the 'gamer' types because the NWO(… | [View]
388991281 | Anons hold hag wants to start a World War 3 hate this cunt so much: https://www.latimes.com/opinion/… | [View]
388977928 | /pol/ BTFO by real life: >pol: BLACKS ARE STUPID, I HATE THEM AND THEY ARE INCAPABLE OF ANYTHING!… | [View]
388985895 | Inter-racial Relationships: picrelated explains it all Its an act of sadistic revenge You have to si… | [View]
388969565 | The 3 blacks that stomped Ethan Liming to death are indicted on lesser charges: https://nypost.com/2… | [View]
388996522 | So do we need cops or don't? They ain't gonna do shit about blacks commiting crime. At thi… | [View]
388996816 | Reminder that nothing ever happens, 2 more weeks. This is theatre for goyim and it won't affect… | [View]
388996231 | I just got unironically call a “cracker”: So, I just moved into a new apartment in a new city. My pa… | [View]
388976446 | A.I. What is it really?: It seems like a giant meme >''Once we have true A.I. everythin… | [View]
388991796 | Fundies suck. | [View]
388992508 | >tfw no trad Iranian wife >tfw no homecooked stew and bread handmade in the beautiful Alborz M… | [View]
388992806 | A bag of cherries costs $12 | [View]
388989305 | Explain what business house speaker has in foreign countries | [View]
388982738 | Does anyone have any evidence that they are feds? I just want to know. Their Telegram looks pretty a… | [View]
388995860 | >claim to be against digital surveillance >still owns one of these Uhm, you guys hypocrites m… | [View]
388995751 | he created the best opportunity, but failed then got his Ideology fucked by post war propaganda. so … | [View]
388992093 | Okay, I get that the Jews control the world. Can I go home now? | [View]
388980808 | Close encounters of the 5th kind: Any anons see the film? Any anons have & tried the protocols?… | [View]
388983993 | Time to Move to Russia, /pol/: Spanish embassy in Russia posted this today. Very based if you ask me… | [View]
388989936 | Our cannot survive without massive migrating!: /pol/ needs to understood this without massively migr… | [View]
388993055 | ATTENTION DUELISTS: OPERATION I DON'T TRUST THE GOVERNMENT: WHEN YOU GO TO VOTE IN THE PRIMARY … | [View]
388996066 | IF THE US STANDS IDLY BY SOMEONE ELSE WILL ACT: If a certain group within the US chooses not to use … | [View]
388988573 | I was anally molested by my aunts because my female cousin lied and said i raped her when they caugh… | [View]
388995851 | What fuels you to remain complacent and idle despite knowing the truth? Is it your relationship with… | [View]
388974030 | How strong is China militarily speaking?: Can these gooks fight? What was the last war they fought? … | [View]
388982928 | Soon You Will Be Begging For Bug Food: because you will not have enough money for anything else… | [View]
388993513 | So Chinese super soldiers are basically slavic? Oh shit. | [View]
388988574 | How can people claim that MAGA isn't one gigantic cult following when people are literally open… | [View]
388993564 | What We Learned From Hating the Unvaccinated https://archive.is/76Y88 > The battlefield is still … | [View]
388987245 | >American men What went wrong? | [View]
388995455 | It's over. | [View]
388991554 | Slopping the HOG.: PELOSI dines on the delicacys of Asia. I WONDER WHAT NANCY WILL BE EATING TONIGHT… | [View]
388985896 | Why do zoom zooms suck so bad? I'm being serious. What's their problem? | [View]
388986652 | Wealthy blacks commit more crime than poor whites | [View]
388993412 | Why Did Ted Cruz Fist Bump Senators Voting Against Burn Pit Vet Funding?: Republicans and white supr… | [View]
388990645 | Doctors HATE this easy trick that could solve 99% of America's problems!!! | [View]
388994479 | DEMOCRATS ARE RETARDED: >Mandate Vaccines >force CRT and Globohomo Why do we have a Teachers s… | [View]
388990292 | In Defense of Colonialism: We have spent over 5 Marshall Plans to get Africa on its feet, and it is … | [View]
388972738 | Zelensky strips citizenship from Jewish oligarchs. https://www.jpost.com/international/article-71330… | [View]
388991611 | Why do so many anons wish death upon others: I've been on /pol/ too much for the past week, and… | [View]
388992727 | >Triggers WW3 and indirectly turns you into burned minced meat Heh nothing personal kid… | [View]
388992544 | Fagpox or Pridepox?: As you may or may not know a new sodomite plague has appeared and it's spr… | [View]
388995009 | What ever happened to this leaf? Where did he move to? | [View]
388989553 | I can’t help but feel somewhat responsible for these people | [View]
388990968 | Nazis cringe! Denazification based!: Why does /pol/ wholeheartedly support Denazification? You peopl… | [View]
388922421 | Trans women have been legally able to marry men for decades.: Why are courts on board with the trans… | [View]
388994796 | ITT we pour all of our meme magic into making ww3 start from pelokikes plane crash >RRRRRRRRRRRR… | [View]
388994375 | Chinese are still wearing mask Chinese are still having lock downs and restricting their freedom an… | [View]
388994535 | Dicklets are dying loudly: Going by history and precise dick measurement data available online, wome… | [View]
388991719 | Anyone have the 388888888 get?: Was it wasted? | [View]
388993614 | Damn it feels good to be a pureblood!: >Unjabbed >Untested >Unmaksed >Uncut… | [View]
388992835 | Brandon can’t catch a break.: But he can catch a rebound. Finally gets legislation to celebrate and… | [View]
388987483 | Powerful… | [View]
388993366 | Xi is a kiked ineffective leader who is destroying China from within for Jews.: The fat shitskin con… | [View]
388963315 | Ben Garrison Comic: Ben Garrison Based Again! Who do you think is the greater evil, Communist China … | [View]
388981128 | Revelation 16:2: >And the first went, and poured out his vial upon the earth, and there fell a so… | [View]
388960485 | Describe Her With One Word: Be nice. | [View]
388960601 | /nsg/ - National Socialism General - Ignore the Z spamming Christcuck shill edition: Thread for disc… | [View]
388985873 | [OFFICIEL] JOE BIDEN is in hospital due to covid: https://risibank.fr/media/250332-covid-19-joe-bide… | [View]
388993869 | >Mesopotamian civilization is credited with the invention of the wheel.[4][5][6] However, unlike … | [View]
388993057 | >'There's too much people in this world! we must have populational decline, another pandemic… | [View]
388993816 | Sign the petition: https://www.change.org/p/world-heath-organization-legalize-cocain-and-crystal-met… | [View]
388985211 | God bless the South, God bless NC. | [View]
388978828 | LoiCenCe: In scenes akin to those traditionally associated with authoritarian regimes, police in Bri… | [View]
388993106 | Paul the Apostle: >For we wrestle not against flesh and blood, but against principalities, agains… | [View]
388990753 | Consumerism is good | [View]
388976032 | ITS HAPPENING DONETSK IS LOST!: https://twitter.com/AFP/status/1553471579220230144 I thought Ukraini… | [View]
388993082 | Economic fluctuations are a normal part of life.: Even a child understands that 'line always goes up… | [View]
388992472 | Seung-Hui Cho - Based or cringe?: What is the /pol/ verdict on Seung-Hui Cho? | [View]
388985877 | Watch this movie It's the most pol movie I ever seen. | [View]
388993189 | In this one moment in time, Pelosi is based.: Fuck letting the chinks tell our congressmen where the… | [View]
388993109 | Vibes | [View]
388959951 | NIGGER GETS CHOKED TO DEATH BY ITALIAN CHAD: https://twitter.com/rulajebreal/status/1553423471908102… | [View]
388991065 | With Pope Francis likely to give up his position soon due to failing health. How do y'all feel … | [View]
388984116 | Open Field Doctrine: https://reason.com/2022/07/28/pennsylvania-poaching-police-warrantlessly-instal… | [View]
388992869 | >my pic did 9/11 and USS liberty kek https://www.youtube.com/user/AliAmer00/videos… | [View]
388990911 | Slovenians and Serbians love black cock | [View]
388992503 | DAS RITE WHYT BOI YOUS BE GIVIN DA REPARATIONS PERIODT: These nigs are pretty crafty when thinking a… | [View]
388982290 | Two of the same is good. /pol/ can't refute this because fascist politics are only built on fee… | [View]
388980165 | >Biden has Covid again Biden is 79 years old. What are the odds he unironically dies of Covid?… | [View]
388992764 | We've been seeing articles coming out linking a rise of health issues being attributed to every… | [View]
388992735 | Anyone else go through an instagram rabbit hole just to end up finding accounts like this? How is th… | [View]
388989656 | DC goes full 1984: We live in a communist country if they can constitutionally do this. | [View]
388992569 | How come it’s hard to look for information about the holohoax. All the results are just about holoca… | [View]
388990692 | >Germany bans hot water | [View]
388992558 | Global Hyperinflation General /GHG/ #88: Welcome to Global Hyperinflation General /GHG/ #88 Previous… | [View]
388992532 | Steven Anderson is a snake and a false teacher | [View]
388991586 | I fixed Europe and fucked up the cities placements but whatever. | [View]
388991074 | Europe has a problem: Africa and South America are known for BIG BOOTY BITCHES, and they have both e… | [View]
388985935 | /chug/ - Comfy Happening in Ukraine General #4753 - comfy witching hour: Previous: >>388980164… | [View]
388987143 | The number of black Americans in the middle class has grown tremendously in the past few years. They… | [View]
388990955 | Russia invites UN and Red Cross experts to investigate POW camp bombing: 3, 2, 1, nobody is going to… | [View]
388939542 | /SKG/ SKYKING General - IT'S TIME EDITION: Wide-band Web Receiver >http://websdr.k3fef.com:8… | [View]
388985498 | BIDEN HAS COVID AGAIN: AHAHAHAHAHAHAHAHHAH AH HAHAHAH H AHAHA HAH HAHA HAH HAHAHAHAHAHHAHAHAHAHAH HH… | [View]
388982984 | muh strong fascist regime: Only a cattle race would enjoy a totalitarian and autoritarian regime, et… | [View]
388988284 | Reminder that Ukrainian men are dying for their country and for a future that does not exist as all … | [View]
388992127 | LunaMedia will be the next Chris-Chan! | [View]
388982422 | Why are Americans some of the most religious people in the world whereas Europeans are almost all at… | [View]
388981259 | /pol/ is playing football today!: >What is the 2022 4chan Summer Cup? The 2022 4chan Summer Cup w… | [View]
388985382 | Man burns woman’s body in cemetery, tells cops she died during sex: https://news.yahoo.com/man-burns… | [View]
388990932 | Russia is stealing gold from niggers using the wagner group to fund its war in Ukraine. You literall… | [View]
388963782 | BIDEN GOT COVID AGAIN LMAOOO: WHAT THE FUCK IS THEIR PLAN GUYS ARE THEY TRYING TO KILL HIM OFF?!? ht… | [View]
388985012 | What are the political implications of an EO Stopping ALL arms shipping?: Screen cap this lads. Not… | [View]
388985474 | The racist West is only dominant due to robbing African people: It's time for /pol/ to accept t… | [View]
388991848 | I hate niggers. | [View]
388989858 | Millennials Are Now Rich.: How did we do it, bros? | [View]
388972282 | /ptg/ - PRESIDENT TRUMP GENERAL - YOU ARE THE CARBON THEY WANT TO REDUCE EDITION: PRESIDENT DONALD J… | [View]
388990792 | YOU SHALL NOT PASS | [View]
388986705 | Your thoughts? | [View]
388974200 | ALCOHOL WILL BE BANNED: >Alcoholics B.T.F.O! Alcoholics B.T.F.O! https://twitter.com/FoxNews/stat… | [View]
388985891 | What colour is your Bugatti, wagie | [View]
388982621 | PORN in the woods in the 80s: isn't it weird that so many people who were kids in the 80s and 9… | [View]
388990240 | What did the ai mean by this? | [View]
388949416 | What We Learned From Hating the Unvaccinated https://archive.is/76Y88 > The battlefield is still … | [View]
388991580 | Record number of Americans moving to Europe: > More Americans are relocating to Europe, driven ac… | [View]
388982514 | The return of the Luddites: What are the political implications of the great unwashed turning on the… | [View]
388989329 | How long will the NW/globohomo last? will it end until the end of humanity? Is humanity doomd to sla… | [View]
388967768 | Psychiatrists are a scam: Don’t tell them the truth. In fact, don’t use them at all. | [View]
388987332 | I don’t vote | [View]
388990856 | Personal research question to the /pol/: are you aware that if it is good or bad, right or wrong (fr… | [View]
388991047 | Having kids is bullshit.... wtf he can't even drive me to the store for smokes. You fags are fu… | [View]
388978569 | HAPPENING: Pelosi switched from the SPAR19 government aircraft to a military C-17 at Pearl Harbor. T… | [View]
388975503 | White Genocide promoted officially by al-Germanistanian (((Universities))): https://twitter.com/Frit… | [View]
388987747 | > Go to estate sale to look for cool shit > Maga qultist iconography all over > Gay porn in… | [View]
388990715 | Here ya go, Mexibros... help yourselves to the scraps from the hunt left around the campfire >Noo… | [View]
388965690 | /pol/ BTFO yet AGAIN: https://twitter.com/APFactCheck/status/1553073134974259200 | [View]
388986353 | Bros? Why is a 'american plane' coming from Hong Kong going to Tiawan? Is this it? China will invade… | [View]
388985348 | >be me >wake up late because work night shift >tired as fuck probably because drink too muc… | [View]
388989343 | How many of the 'vaccinated' are lying?: Additionally, why would anyone who doesn't want to be … | [View]
388989587 | Will Donald Trump Run For President In 2024?: https://www.youtube.com/watch?v=Cp3XFmEr9oA&ab_cha… | [View]
388990414 | Piece of shit scammer: Piece of shit scammer That likes to scam women! Call them ugly and show them … | [View]
388977957 | Anti-vaxxers will inherit the Earth and usher in a New Age of Reason: ..while vaxxers die off with e… | [View]
388979339 | Brit/pol/: >Police alerted following deliberate Wheelie-Binfire at Westbrook, Warrington https://… | [View]
388985462 | AMERICA NOW OWNS EUROPE: I can't believe EuroNiggers actually fell for it. Did they honestly be… | [View]
388980763 | GOD SPEED TO THIS CRAZY BITCH: I hate her guts but I hope she has a safe trip and shows China who… | [View]
388987215 | where can I discuss my Politically Incorrect views other than 4chan and Session groups without getti… | [View]
388966379 | The 2020's are so fugging miserable holy fuck anons its the beginning of cyberpunk dystopia | [View]
388987568 | Very fun fact about Palestine >Palestinians sold their lands to Jews from GB but when they arriv… | [View]
388945585 | Turkey has the second strongest army in NATO | [View]
388988695 | Anglo status: Eternal | [View]
388970923 | He’s right. | [View]
388988704 | I am a man that has bucked the decay of civilization. I am married, I'm not a wagie. I have chi… | [View]
388989054 | Helen Keller flew a plane over the Mediterranean Sea: Helen Keller flew a plane over the Mediterrane… | [View]
388989140 | Are all nazis just cucks/bottoms?: All auth-right and nazi/fash adjacent men worship power, especial… | [View]
388988889 | What would life be like under The Third Reich if the Nazis won?: If Germany won WW2 would a thousand… | [View]
388959580 | Whitepill me | [View]
388987469 | Why didn't you listen to Yang? Hope it wasn't because he's not white. | [View]
388989234 | 3 Blacks kill white in cold blood, weak charges.: > Court papers from earlier this week show the … | [View]
388986804 | /pol/ infographics/wordcloud: 30 July 'kind shit posting' edition | [View]
388988535 | Invent your sjw words in german | [View]
388988991 | Have you ever pulled this up with a Leftist or Normie?: They can’t explain it without just outing th… | [View]
388989301 | Pox Pride Month: Why can't we have a month to celebrate leftist gays sharing love, and disease?… | [View]
388985990 | >Ironically one of the most revealing discoveries in the past couple of years is the revelation t… | [View]
388984946 | Family law: These people; the lawyers, the judges, the clerks; should all be dragged into the street… | [View]
388988034 | If Korea has mass non asian immigration it's over | [View]
388971673 | So /pol/, whose side are you on?: China or the USA? | [View]
388985811 | >imagine thinking anyone will give up their guns after the failed COVID coup… | [View]
388975135 | >White genocide is rea- | [View]
388988629 | /Pol/ humor thread: Ayo I gots to break dis shit up https://youtu.be/Yc-Va7IqVvw | [View]
388988917 | Yes, United Kingdom!: > British army veteran filmed being arrested after posting offensive meme o… | [View]
388988226 | /pol/ tard live: This guy is what happens when you take too many redpills lmfao, who of you fuckers … | [View]
388978905 | Can someone explain exactly how it is physically possible to catch covid multiple times in a row? If… | [View]
388988250 | >https://youtu.be/jfSPGAzjlMA Italian man kills black immigrant, happened a couple hours ago in o… | [View]
388987367 | Pelosi dead already?: Someone added Nancy Pelosi's date of death on Wikipedia, reads 31st of Ju… | [View]
388985016 | ready to die for your country?: hahaha they make threads when they are recruited or transatlantic mi… | [View]
388988005 | There are 'people' (boomers) on /pol/ who believe that corporations are innocent and that if they si… | [View]
388988528 | how long till they remove the $1 coins from circulation? pretty much worthless at this point now. | [View]
388987844 | How many cheers for dead queers? | [View]
388979567 | CHINKS CANT FIGHT: Imagine thinking an army of mindless insects which never fired a bullet in a real… | [View]
388986916 | Why did he love moors so much? | [View]
388981116 | Sources familiar with Timcast say...: Tim Pool's real name is Gabriel Walden | [View]
388965280 | LMAOOO Vatnik scums have suffered such heavy losses their recruiting chinks now: >Be vatnik scum … | [View]
388984849 | I do not trust this fucking guy | [View]
388985529 | Is TuckTuck losing his goddamn mind? This is literally what it looks like when success goes to your … | [View]
388987915 | Did you share some truth about Israel today?: Military aid to Israel is illegal under the Leahy Law … | [View]
388986798 | Any good docos about the great reset? Red pill me please | [View]
388987816 | Not my problem | [View]
388984904 | Is there an explanation for how the government can put the average citizen into a war trance even if… | [View]
388987773 | . | [View]
388973328 | BIDEN BEATS COVID TWICE, MEANWHILE PUSSY TRUMP HAD TO BE AIRLIFTED TO THE HOSPITAL: >After testin… | [View]
388983946 | /pol/-approved books: /pol/ approved books thread fiction and non-fiction | [View]
388983295 | Republicans only want to hurt people who disagree with them | [View]
388976288 | White women aging: Why are white women the hottest out of all races until they hit 25? Why do they a… | [View]
388980836 | Nothing ever happens: Take your meds schizos and have some Sex. Also touch some gras | [View]
388980092 | Remember your birthday? Remember how your mum decided to conceive a child with a black man? This is … | [View]
388977020 | /uhg/ - Ukraine Happening General #3557: Prev:>>388967198 ▶Day: 157 - Daily battlefield assess… | [View]
388971175 | Supposedly in hiding with (((COVID))) again...: Has he actually been dead this whole time? The first… | [View]
388986432 | monkey pox: i have a proposition i saw faggots on a web post waiting to get there monekypox disgnon… | [View]
388983479 | The political ramifications of Wattpad: Most of you have never heard of this site but almost every g… | [View]
388982636 | Poles, how does it feel knowing the borders of the modern polish state were literally drawn by stali… | [View]
388983500 | i hope this fucking bitch dies in a fiery explosion in mid-air | [View]
388980117 | The Greater Poland will soon be reborn, we planned it all. We struck a deal with Russians, they get … | [View]
388985579 | When you whine about Disney being run by pedophile jews but the current CEO of Disney isn't eve… | [View]
388986435 | My dream is being an Elite Fascist Shock Stormtrooper https://youtu.be/j4sEMA0MGo0 | [View]
388983712 | China is the greatest country in the world! There is no other country that can compare to its histor… | [View]
388985829 | Guatemala's President Alejandro Giammattei & Entourage Come Under Shooting Attack: https://… | [View]
388983825 | The narrative about recessive white traits diluting over time has been used for demoralization purpo… | [View]
388966026 | The Occult In Politics: I'm an expert on the occult ITT, I drop redpills on how occult knowledg… | [View]
388968758 | Stonetoss is a fucking nazi | [View]
388986547 | What the fuck, bros? How is that possible? He's got all the boosters. | [View]
388978435 | overall, which countries are better, those with emblems or those with purely simple shapes in their … | [View]
388986226 | how do we break the chains of goy typography? why can't we create fonts/signs and ligatures in… | [View]
388980044 | After the failed blitz, can russia still win I'm Ukraine? | [View]
388986257 | Was Reies Tijerina based or cringe? | [View]
388984769 | Hermit Politics: Should those who are hermits be able to vote and participate in politics. I’m am 21… | [View]
388963597 | OH NO OH NONONONONONO | [View]
388983797 | You son will cut his dick, you will be happy: You son will cut his dick, you will be happy. You daug… | [View]
388984963 | How do you respond to this? | [View]
388983136 | Russian stabbing yanks: https://www.broadcastify.com/listen/feed/17752 I just heard on this feed tha… | [View]
388985860 | Who was he?: I only saw his video on jews and breadtube which both were super good but can't fi… | [View]
388985248 | What would the US actually do if China zapped the old witch??: Like we wouldn't just launch nuk… | [View]
388985425 | What is the 'golden billion'? | [View]
388980164 | /chug/ - Comfy Happening in Ukraine General #4752: Previous: >>388974992 Timeline /tug/: http… | [View]
388985776 | Alright Americanons how are we splitting up China once we conquer it? > All of it becomes the 51 … | [View]
388984272 | Reminder China, with all its flaws, is actually doing some good in the world | [View]
388984388 | Why did this board turn into a cuckservative haven and r/donald clone? | [View]
388982669 | The Nation Gets what it Deserves: We deserve to be run over by lunatic communists. We deserve to hav… | [View]
388985439 | >I was involved in that? hm. well, that's nice | [View]
388984839 | MK Ultra: What is the criteria that makes people receptive to propaganda and other not? Women: they … | [View]
388983944 | CIA NSA CBS IRS ABC CNN FOX DOJ FBI: All parts of the system to enslave you. They are not news stati… | [View]
388977320 | HONOR THE GAYS OR YOU WILL NOT PLAY: god what a fucked up world we live in where you have to honor m… | [View]
388985308 | When it comes to covid: >If you don't wear a mask all the time and get 5 vaccines you litera… | [View]
388984531 | Which one of you was this?: https://www.reddit.com/r/PublicFreakout/comments/wbttyj/trailer_park_bum… | [View]
388965891 | Loving Gay Families: Should gay couples have access to taxpayer funds to promote surrogacy? After al… | [View]
388984895 | Prepare for more restrictions. They are going hard this fall | [View]
388980090 | Balkan federation: Is it possible and why not | [View]
388984564 | Every day Americans continue to watch the rape of democracy from the sidelines indifferently, thousa… | [View]
388963801 | 'Jesus' was invented about 1000AD, not 30AD.: Nothing Jewish existed prior to arrival of Romans. Jew… | [View]
388941932 | /pol/ is basically leftist at this point: This place is just a hub for retards and subversives who w… | [View]
388981711 | what's his fucking problem? | [View]
388983563 | Imagine not being able to buy alcohol at 18: So much for freedom i guess.. | [View]
388977191 | >see transgender flags all over town >images of botched surgeries or surgeries that went right… | [View]
388984241 | Dentistry is a scam: Last time I went to the dentist was more than 15 years ago. I'm 32 now and… | [View]
388980216 | 2.5 yrs later and now we know it was heard immunity: Not the vax, not mutations, simple herd immunit… | [View]
388984647 | >be me >be in China >witness firsthand the economic miracle >see how happy and prosperou… | [View]
388951276 | Gun Owners Shooting Criminals: Hey /pol/ the last thread hit the limit but lets get your weekend sta… | [View]
388971117 | ITS HAPPENING Nancy Pelosi plane: guarded with F35 and F16 https://streamable.com/896c80 | [View]
388983857 | /pol/ is frown town. | [View]
388981573 | Why are boomers to entitled? | [View]
388976650 | What's the chuds endgame?: >Kill random people for some dumb meme manifesto on 4chung >ge… | [View]
388984641 | WW3 will be Europeans vs Mutts: It may not be the conflict you wanted, but it's the one you get… | [View]
388984362 | All the deep state black op sites in Tiawan about to be crushed: Tiawan is next YOU BETTER RUN RUN … | [View]
388983595 | Why do Americans bow down to the jew? | [View]
388982004 | LIVE IN THE FUCKING LINE GOYIM!!!!!: https://youtu.be/0kz5vEqdaSc It'll be perfect. It totally … | [View]
388980363 | Why would they block the PACT Act? That is fucking horrible for vets | [View]
388984211 | Will COVID redeem itself??? | [View]
388984206 | You vill not buy anysing und be glücklich: https://www.commbank.com.au/articles/newsroom/2022/07/CBA… | [View]
388983052 | Why was this thread archived??? >>388969963' | [View]
388982859 | Art is over! AI has replaced it: >I just spent an hour on Midjourney, the AI that produces an ima… | [View]
388959473 | Is Christianity white?: Everyone knows that Christianity originates in the Middle East and that Jesu… | [View]
388977738 | White lives matter: White lives matter | [View]
388983574 | How much longer will CNN pretend that Pelosi is a hero?: Just asking. | [View]
388983432 | What does POL think of MOnkeyPox?: What does POL think of MOnkeyPox? | [View]
388954152 | HAPPENING INDIA OFFICIALLY A SUPERPOWER | [View]
388970095 | Most of the early Nazis were socialists and the only reason the Nazi Party became successful is beca… | [View]
388981171 | Politics of Circumcision: What would the political consequences of acknowledgment that circumcision … | [View]
388978426 | Normies everyone... So now that it's politically correct to talk about this how is Russia gonna… | [View]
388975144 | Mike Vallely says 'If the senate doesn't ban rifles, my fists will.': There was this dude he hu… | [View]
388983781 | Liberals in 2020? Liberals in 2022? | [View]
388979445 | Will monkeypox spread to the heterosexual population?: I’m getting scared that it will | [View]
388970265 | Russians are the whitest people in the world. | [View]
388983114 | What are the political implications of Cosa Nostra? Are they based, compromised? Does honor actually… | [View]
388971934 | This is how you sound to people who know what they're talking about. | [View]
388981026 | I hurt myself today | [View]
388975589 | Americans: This country is clearly beyond saving. What's your exit strategy? | [View]
388983447 | I can't wait to kill bugs: https://youtu.be/nZ_zNUmr8fM | [View]
388976445 | When will it end /pol/? | [View]
388973675 | So most of /pol/ rightly supports Ukraine but I'm still seeing people say 'Kiev'? WTF is a 'Kie… | [View]
388983238 | the perfect grocery store for the ethnostate?: 1. grassfed, pasture raised dairy, meat, egg, milk 2.… | [View]
388979642 | The final solution to the tranny problem: 'Do you have XX or XY chromosomes?' There is no way around… | [View]
388977194 | >OH N- | [View]
388982517 | 'Fascism' is the centralization of political tribalism. Hitler did manifest that on a global scale, … | [View]
388977310 | IMAGINE BEING THIS FREE: >No Capitalism >No Communism >No Globohomo Just a man living off … | [View]
388976586 | Poccия is Supяpower!: motherland of cultur and much wealth! u jelly, west? | [View]
388970233 | >fascism is the way forward! >no fascist government has survived a transfer of power… | [View]
388979851 | >gets covid >gets better >deepfakes a video >gets 'rebound' covid 8 1 m i l l i o n ?… | [View]
388976101 | It’s ok to drink Fanta: Fanta is not “national socialism in s bottle”, stop calling it “Hitler’s fav… | [View]
388982395 | Nanny Dog Appreciation Thread | [View]
388973373 | Idiots | [View]
388982745 | Remeber when we had a President who made peace instead of war? | [View]
388982844 | CO2: > While private jets are used by rich folks of all kinds, their use among celebrities has co… | [View]
388974879 | What would brother Malcolm say about the state of America if he was here today? | [View]
388980849 | /RPG/ - Red Pill General: Post a redpill, take a redpill. >pic This is an improved version of the… | [View]
388980680 | Are western white people becoming stupider over time? Cops shot a (white) guy in Vancouver today bec… | [View]
388980807 | IF YOU'RE WONDERING HOW CLOWN WORLD BECAME REALITY: https://www.techdirt.com/2013/07/15/anti-pr… | [View]
388980285 | SIMPLE AS. | [View]
388981970 | Can we discuss Ron Perelman and how his company is poised to make bank from this latest monkepox (((… | [View]
388977229 | Is China gonna bomb Hawaii after shooting down Pelosi? I have friends there | [View]
388978162 | German anons: How do you think will the protests in fall/winter unfold ?: Genuinely curious about th… | [View]
388980953 | DEMS WORK FOR CHANG: LMAO POLTARDS WRONG AGAIN. HOW DOES IT FEEL TO BE PROVEN AN UNWITTING CYBER COM… | [View]
388948561 | Give it to me straight, /pol/. Can the west still be saved? It doesn't matter whether it's… | [View]
388982349 | Can china finally invade taiwan? We all are waiting for it | [View]
388982341 | Six months ago I couldn't so much as sit down at a single restaurant without presenting a gover… | [View]
388981039 | Why the fuck is america sending someone to taiwan? Are they TRYING to start a war? | [View]
388981223 | >globohomo fears this | [View]
388979847 | I reject your narrative!: That thing you are trying to push now is untrue and your assignment is des… | [View]
388967501 | Richard Dawkins: >Constantly BTFO Christcucks stuck in the Dark Ages >Coined the term 'meme' I… | [View]
388981972 | Stop using banks: Use a credit union. Imagine if everyone did this. | [View]
388976630 | >And you too, darkness | [View]
388980229 | Creepy DALL-E AI asked to predict last selfie taken on Earth and it’s horrifying: A TIKTOK account d… | [View]
388982017 | Is this a good book? It's on libgen.rs I read maybe one page. | [View]
388981780 | /pol/, I have a plan. As you know, the definition of Recession was changed to downplay Biden’s mista… | [View]
388981017 | Monkey pox is scary for straight people too.: So you wash your hands before taking your dick out to … | [View]
388981602 | If you needed any proof that the news media will only report on killers that are western, white and … | [View]
388969310 | Happening in Sweden: An elderly black man is pushed down on the Subway rails by a Crazy Woman in Swe… | [View]
388957725 | >tranny >jew This guy is such a disappointment. Nothing has changed. He has learned nothing. h… | [View]
388949489 | For those of you wondering about: How the Covid shots effect babies. Looks like it’s going awesome!… | [View]
388981140 | Bing bong ching chong, me like dog meat | [View]
388952394 | Why does it seem like people in America are so depressed nowadays? | [View]
388981246 | >he's still in a major metro area >he thinks the collapse will be gradual and he can just… | [View]
388965708 | IT'S ACTUALLY HAPPENING: >US can't cuck without looking weak as fuck >China can… | [View]
388962119 | Can someone explain this?: It’s commonly said that you get paid what the market values you at, and t… | [View]
388980492 | I'll trade you a depopulation vaccine genocide shot for a delicious Giant Cockroach: or i'… | [View]
388973105 | OSTRIV ZMIINYI IS UKRAINE CLAY: kek Russian orcs get internationally humiliated by brave Ukraine “Ru… | [View]
388978973 | America must burn in hell | [View]
388981070 | Hello The muslim concept of jannah and reincarnation arent that mutally exclusive as one might thin… | [View]
388976706 | I Can’t be the only guy here who wants to suck a big fart outta this woman’s hole: All hail the beau… | [View]
388975165 | I think it's kind of weird when people who live in the West claim to be Muslims. It seems to me… | [View]
388980607 | Remember that one time gooks leaked the coof and ruined the world? | [View]
388968964 | FUCKING HAPPENING: BIDEN TESTS POSITIVE FOR REBOUND COVID: Biden reportedly 'continues to feel quite… | [View]
388980978 | Let's go to war with China!: You Trannys and fags get on the front lines. All you ladies, get i… | [View]
388977417 | Canada: 4 doctors dead in a week: Move along nothing too see here >>According to her obituary,… | [View]
388960250 | LMFAO Germans are taking cold showers in the dark to 'own da Russians'. http://archive.today/VwZ5P | [View]
388966618 | NJP GOES FULL-ON MASKS OFF FOR CHINA: ERIC STRIKER AND WARREN BALOGH OF THE NJP HAVE GONE FULL-ON MA… | [View]
388957328 | HAPPENING: FEDS SHUTDOWN FLIGHT RADAR: CIA SHUTDOWNS FLIGHT RADAR | [View]
388980608 | /a u s/ pol: https://www.qantas.com/au/en/travel-info/baggage/carry-on-baggage.html Quantas now has … | [View]
388980274 | Rulers of the West: Are they inbred goblins? | [View]
388971164 | I think it's time for a Gen X discussion thread to discuss the political implications of Gen X … | [View]
388973725 | The world is ending, and I'm tired to the bone.: I'm completely and utterly demoralized. I… | [View]
388979219 | Trained to be Retard: Civil servants in Britain’s deep state bureaucracy have been trained that thei… | [View]
388964328 | Russia warns U.S. against 'provocative' moves toward China: PUTIN IS GIVING YOU A FINAL WA… | [View]
388973069 | The Florida teacher shortage is so bad they’re literally letting anybody do it.: No degree required.… | [View]
388977750 | WE LOST HER | [View]
388969433 | What is his endgame?: He is demanding that every Ukrainian die to fight an unwinnable war. Why didn… | [View]
388966218 | >Germany: Muslim who stabbed train passengers wanted to rid the country of ‘non-Muslims’ https://… | [View]
388979985 | You will pay your taxes or be sentenced to prison. | [View]
388974992 | /chug/ - Comfy Happening in Ukraine General #4751: Previous: >>388962425 Timeline /tug/: http… | [View]
388976990 | mad xipoopoo? | [View]
388976694 | Propaganda and conditioning is now underway, everything but the vaccine will be blamed for the wave … | [View]
388979635 | >I don't get it. What does this post mean? | [View]
388979090 | I think they're going to take the infowars domain: I was doing research into the sandy hook shi… | [View]
388978911 | Americans give their kids this shit for breakfast and then wonder why their kids do poorly in school… | [View]
388974383 | when did you guys realize it was over | [View]
388978830 | Serious question about christkikery: Did christkikery turn White people into cucks through 2000 year… | [View]
388973717 | I’m going to have eight children with my cousin: And whites are going to pay for it | [View]
388949265 | New York declares state disaster emergency for monkeypox outbreak: 'The measure comes as New York… | [View]
388958867 | Wtf is wrong with france?: Visiting from bongland and holy SHIT this city and country is a mess. Eve… | [View]
388964839 | Brit/pol/: >Police alerted following deliberate Wheelie-Binfire at Westbrook, Warrington https://… | [View]
388976917 | >NOOOOOO YOU CAN'T JUST GO TO A SMALL ISLAND BECAUSE IT MIGHT MAKE CHINA CHIMP OUT the absol… | [View]
388979592 | Europe is so pretty: What are some places I should visit? | [View]
388976976 | CHINA SHOT DOWN PELOSI'S PLANE AND IS INVADING TAIWAN ! IT HAPPENING!: TURN ON CNN! XI TOLD YOU… | [View]
388977458 | Why are black immigrants so much successful than black americans? | [View]
388978263 | A Jewish communist endorsed a Muslim woman for congress last week.: I just noticed this today. Trump… | [View]
388978992 | Look at this clown. He's pathetic. I hope you're vaccinated and consider taking a booster … | [View]
388967897 | Post-scarcity: The greatest political, moral, and philosophical question of our time is whether or n… | [View]
388977073 | BREAKING NEWS: President Biden has tested positive for COVID-19 again | [View]
388956180 | Why is science dying? | [View]
388976843 | Breaking: Biden couped by Kamala | [View]
388976719 | GLOBAL WARMING IS NOT RE- ACK: Why is /pol/ always wrong? | [View]
388979093 | It's happening, Biden is moving to China: He finally made a decision the world was longing for.… | [View]
388973573 | Countdown for WW3 has started Plane with Pelosi just took off | [View]
388970223 | Tila Tequila - New /OurGirl/?: Tila Tequila Claims ALL BLACK PEOPLE ARE CURSED and 'the synagogue of… | [View]
388972784 | The jews are behind it.: That's all you need to know for now. Await further instructions.… | [View]
388976450 | Breaking news: vaxxies cannot breathe. >g-get the booster, you anti-science chu--ACK! Political i… | [View]
388976571 | When did my brothers become lazy fucking retards?: What happened fellow bongs? | [View]
388967360 | RUSSIA IS COLLAPSING: -GDP plunging, not even a G20 nation anymore -post-Soviet levels of unemployme… | [View]
388961863 | This piece of shit Orban is flooding: Europe with migrants, yet the right is in europe is supporting… | [View]
388976277 | What are the political implications of agreeing to be Milana Vayntrub’s Shabbos Goy. Would you agree… | [View]
388978773 | Arent female protestors so beautiful, /pol/? You rebels should Marry them. | [View]
388975394 | Why are southern europeans often mistaken for arabs/turks? | [View]
388972467 | The crap the Catholic Church has gotten away with is unacceptable: Oglala Sioux tribe is fed up with… | [View]
388978425 | >/pol/ will defend this | [View]
388969349 | Biden Gets Ligma Again: Those 4 vaxxes are working https://www.dailymail.co.uk/news/article-11065075… | [View]
388977899 | What are the geopolitical ramifications of climate change in this region?: I think Europe will colla… | [View]
388974902 | Over two thousand years ago the self-styled 'Sons of Light' declared war on the seventy nations of t… | [View]
388977789 | Why the left wing in third world is nationalist than the western left wing | [View]
388948060 | >just live off grid-: surprise surprise the government prevents you from setting up residential b… | [View]
388977598 | Is Appalachia really that miserable? | [View]
388976466 | The past is gone and only the foolish would want it to come back. Sure, previous eras were more mate… | [View]
388962964 | This Cunt’s Plane will be downed by Chinamen: Who else would you’d like to see on the doomed flight?… | [View]
388978118 | Biden runs a Ukrainian oil company: Being a career politician should be illegal. You should be requi… | [View]
388968286 | Norwegian Diplomat: I hate Russians: 'I hate Russians' - the consul of Norway, Elisabeth Ellingsen, … | [View]
388978209 | Reminder that corporations are never your friend, they are always trying to squeeze money out of you… | [View]
388976959 | how do we stop the moskal mongrel menace? | [View]
388978175 | Millenials are heirs to the generational warfare provoked by media since the end of WW1, which will … | [View]
388956083 | Paki beheads loli in UK: '''''''Stabbing''''… | [View]
388977875 | China hate: hey chinkbots, tell your fucking overlord to blow pelosi and start ww3, this shit is bor… | [View]
388923739 | do you have an '''expat''' problem in your country?: https://www.reddit.com/r/mexico/comments/wb2ybo… | [View]
388975447 | Sorry, but you're white | [View]
388977961 | Pay Respects: https://abc7.com/woman-killed-dog-attack-pitbull-albertson-ny/12077526/… | [View]
388974935 | Wait what: Andrew Yang wants the military to step in and run our elections? | [View]
388975531 | China: As a Hispanic male living in USA, the Chinese I know who support the CCP always act like down… | [View]
388969647 | Buck bros.... | [View]
388976801 | So what are Democrats going to do once in power? | [View]
388974286 | Don't forget - August 25th is SAINT KYLE DAY!!!: Clothing to wear in honor of Saint Kyle: -Back… | [View]
388977529 | 2020: >don't visit your dying grandmother it's irresponsible 2022: >don't tell … | [View]
388955386 | Political Implications of the catholic church worshipping satan? | [View]
388975150 | Why archive >>388969963 Im not finished | [View]
388977223 | Lol: Lol | [View]
388977180 | We've done it this time, fellow wignats. Biden and dems taking our guns is a great victory for … | [View]
388973570 | DEMS OVERTAKEN REPS IN POLLS: NOOOOOOOOOOOOOOO | [View]
388967982 | ! | [View]
388972551 | FUCK JEWS - Charges in Ethan Liming Case: Initially charged with murder but the (((prosecutor))) wor… | [View]
388976353 | So why did the baby formula thing make so much news and then go quiet? The plant hasnt turned back o… | [View]
388964919 | PUTIN SAYS IT'S THE END OF THE 'RACIST AND NEOCOLONIAL WEST': THE KING OF POL 'Of co… | [View]
388976859 | Why does his face look like he knows everything about Jewish tricks? | [View]
388967198 | /uhg/ - Ukraine Happening General #3556: Prev:>>388959069 ▶Day: 157 - Daily battlefield assess… | [View]
388957304 | Irish political representation: The irish need political representation as soon as possible. With t… | [View]
388976829 | Did they told us in advance?: So /pol/tards, reading news of chinchongs preparing what looks like an… | [View]
388970438 | Daily reminder, you can't escape the eternal femoid even as an incel. >Be me >Retard wor… | [View]
388975694 | The age of men is over.: The time of the Orc has come! | [View]
388974317 | >Based Western People Hating Russian sub humans: >/pol cries about >is /pol just a group of… | [View]
388975038 | Anti muslim thread | [View]
388976389 | Modern War Considered: Wars these days aren't decisive. Whole populations don't typically … | [View]
388974797 | USA will fully collapse before 2030. Just keep that in mind mutts. | [View]
388964331 | Women are a walking parody at this point: https://notthebee.com/article/first-ever-female-tour-de-fr… | [View]
388957109 | >Portugese people went to America: >Saw this >Bred with it >Created mexicans What the fu… | [View]
388973633 | Demon | [View]
388975703 | Do you guys go out in the Weekend?: It is weekend. I have a strong urge to go out and get a bit drun… | [View]
388976364 | Looks like they haven't re-written every definition yet. >Odd >spoiled or ruined… | [View]
388976263 | Vaxxed kids TWICE as likely to catch COVID: Does every breakthrough COVID case convert a Democrat to… | [View]
388974672 | Redpill me on TCM (Traditional Chinese Medicine): If 1.4+ billion people swear by it, there must be … | [View]
388975800 | Le Globohomo is not homo anymore: WHO recommends gay and bisexual men limit sexual partners to reduc… | [View]
388974669 | Why would anyone from Russia willingly go to war with Ukraine? I don't understand. Do they re… | [View]
388958712 | You are the new king of Poland: The gov collapsed, the Sejm choose you lead our people in these hard… | [View]
388974598 | Ethan Liming deserved it: If a nigger walked up to me and started shooting me with a toy gun I’d pro… | [View]
388975989 | ATTENTION TO THE NEXT SHOOTER: Kill this ghoul in minecraft instead of random kids, people shopping … | [View]
388975196 | Vaxxie apologize to purebloods thread: Post you reconciliation after stigmatizing us the past two ye… | [View]
388975118 | Dangerous information )))You((( shouldn't know about: #1: https://archive.is/mZc2F#problem.html… | [View]
388975074 | Civilization is on the brink of destruction: I've had a very insightful experience. There were … | [View]
388973685 | >HIV comes from monkeys, in Africa >gays somehow contract this disease and infect society wit… | [View]
388942644 | BREAKING: The House passes assault weapons ban by a vote of 217-213: It’s over. | [View]
388966417 | CCP DON AT IT AGAIN!: >Former President Trump on Friday criticized Speaker Nancy Pelosi’s (D-Cali… | [View]
388964960 | got rejected from the army: what the title says. i didnt pass the psych eval because i failed the qu… | [View]
388975742 | I hope I live long enough to see the brown golems turn on the jews: I'll love to see them tryin… | [View]
388975688 | I bet the Jew's did this. | [View]
388972772 | Gentiles, Orthodox Jews are on your side. Ask any orthodox Jew about trannies, destruction of the fa… | [View]
388975524 | >major wins under Trump and even our neo-Fascist uncle that helped escalate the war in Ukraine … | [View]
388973960 | https://www.youtube.com/watch?v=FtLjCEVf3NQ | [View]
388932685 | What's wrong with well controlled merit based immigration??: Suppose there is an Indian boy who… | [View]
388969394 | Australian TV exposing Zelenskyy: https://www.youtube.com/watch?v=KEPWgMXut_8 | [View]
388969761 | Crazy Keith: Any surprise he's grifting shitbulls? The pitbull lobby must make a lot of money o… | [View]
388974900 | Monkeypox is political.: Romans 1:27. /thread. They thought they had overcome their due punishment b… | [View]
388970728 | Operation PridePox: Let's help these fags end the stigma, bois | [View]
388970006 | CSRQ-SM: You will own nothing, you will eat the bugs, and you will be happy! | [View]
388956993 | Germany is not yet lost: Not gonna make the same mistake as we did in 1939 and picked wrong side. Kr… | [View]
388971832 | https://youtu.be/rkRWaJFCLlQ so if you are not wicked enough, just powder your nose like Zelensky do… | [View]
388972793 | > statue of spanish explorer from 500 years ago must be taken down!! > statue of meth dealers … | [View]
388969747 | No way out but absolute monarchy | [View]
388974898 | Putin before: >everything putin ever did since 1999 was trying to integrate russia with the west.… | [View]
388964259 | Settle down:: Hey, Instead of being mad all the time, how about you settle down? Smoke a fatty, watc… | [View]
388973133 | Burgerturds immediately BTFO: >pic related >inb4 triggered burgers sperging around… | [View]
388974335 | What exactly is the end game of the elites importing muslims in to Europe? 50 or 100 years from now … | [View]
388947581 | >WE TOTALLY KILLED HIM DUDE >BULLET THROUGH THE EYE >LIKE MOE GREEN >HE SHIT HIS PANTS D… | [View]
388970827 | Fuck you, i'm voting for them | [View]
388971901 | California sheriff orders raid on Indiana Batmobile garage, allegedly as favor for friend: How the f… | [View]
388974626 | So you red-pilled MAGA fucks have been projecting this whole time? | [View]
388974602 | >civilian I fucking hate this word. If a vet called me a civilian to my face I'd tard out. I… | [View]
388964487 | Why though I'm not even a smoker with the price of a pack why would they do this knowing there… | [View]
388971752 | Marjorie The Gathering: What's her endgame? | [View]
388962425 | /chug/ - Comfy Happening in Ukraine General #4749: Previous: >>>>388953295 Timeline /tu… | [View]
388970560 | Political implications of Deepfakes: >Pic related is Ana Kasparian a respectable political commen… | [View]
388974248 | South Africans are fighting against rap culture. What have you done?: A production crew was filming … | [View]
388967924 | incelbros let's fucken gooooooooooooooo | [View]
388974026 | It is about to be happening: >birthrates plummeting >abortion banned >'The House voted 228 … | [View]
388972281 | What the FUCK is gonna happen when Queen Liz dies?: I get the feeling that the commonwealth will jus… | [View]
388973593 | Why are eco-lefties so fucking dumb?: I have been homesteading for quite some time grow about 80% of… | [View]
388973427 | Majority of Americans are leftists. Being a right winger would get you cancelled or even worse getti… | [View]
388969910 | Homeless: Sometimes whenbI really think about it. Homeless people are the only truly free people in … | [View]
388972978 | If ukrs think that bandera is hero then he is a role model to follow as hero. So russians (and other… | [View]
388964366 | A/C's: I live in Vancouver bc, supposedly the leftist capital of Canada full of libtards who su… | [View]
388972709 | This is an american who was arrested for having a hidden camera in a girls change room: What fucking… | [View]
388971747 | HE'S GONNA DIE BEFORE THE END OF THE YEAR: https://www.usatoday.com/story/news/politics/2022/07… | [View]
388958171 | DEEP STATE IS COMING OUT IN THE OPEN: THEY AREN'T EVEN HIDING IT ANYMORE THIS IS THE FINAL PHAS… | [View]
388970801 | The castration video was an SBU false flag attempt Castration video debunking thread Current facts o… | [View]
388961348 | i wouldnt want to miss a happening: so is this china war thing gonna pop off today or should i just … | [View]
388962159 | PELOSI CHICKENS OUT: China's red line stays intact | [View]
388973226 | Smart-Tech illuminates darkness, but does not reveal the light. I mean, imagine waking up every day,… | [View]
388969138 | I'm afraid of the forthcoming winter, lads. No gas, no heating, no water, no electricity the in… | [View]
388971306 | The Glorious Wet Rapture: >20-something drowned Appalachian hillbillies Good, clear those fuckers… | [View]
388971728 | Most people don’t know this, but Israel took dna from Hitlers corpse and cloned him. They keep him a… | [View]
388963072 | >5 hour long programme about the transatlantic slave trade, trying to put things into perspective… | [View]
388947494 | HAPPENING: CHINA READY FOR WAR | [View]
388967140 | I hate reddit so fucking much | [View]
388952256 | 99% of people on /pol/ don't know one fucking thing about logic. I've only listened to a f… | [View]
388969146 | So are we all forgetting that Biden admitted he has cancer because he was reported to have Coronavir… | [View]
388969246 | So nukes will fly tonight, r-right?: Theres literally no way China will allow Nancy Pelosi to land i… | [View]
388964043 | If you could choose an place on earth to create your ideal state,where would it be? And i am not tal… | [View]
388964412 | Did the Nazis produce any interesting fiction novels during their reign? Maybe we can learn how to f… | [View]
388972387 | NOTHING BURGER: >China in the midst of economic crisis x50 worse than 2008, where loans are backe… | [View]
388972031 | You city boys are pathetic, I can gun down you capeshits any day. | [View]
388971419 | BIDEN GETS COVID AGAIN DESITE BEING QUADRUPLE-VAXXED: are they trying to kill him? does this mean it… | [View]
388970718 | Uh, if Biden 'dies from the coof', and China created the coof. Doesn't that mean China killed o… | [View]
388964649 | CHILDREN BEING GROOMED BY TRANNIES ON THIS DISCORD SERVER: THEY LITERALLY JUST TOLD A 12 YEAR OLD BO… | [View]
388972459 | The reality of amerimuth: >Brave against goat herders >Cowardly against a strong enemy… | [View]
388971086 | Nothing in the universe is infinite. Even souls are finite. There’s only so much soul to be divided … | [View]
388956818 | Why is the developing world not backing Ukraine?: Russia is hardly an 'anti-colonialist' power, by t… | [View]
388971119 | >self-proclaimed right wing Americans are now defending Nancy Pelosi and neoliberalism to 'own th… | [View]
388971588 | Real map of Europe | [View]
388969402 | Many people believe that recessive white traits will only dilute over time, causing white people to … | [View]
388961729 | /ptg/ - PRESIDENT TRUMP GENERAL - THAT WOULD BE A REAL MAVERICK MOVE EDITION: PRESIDENT DONALD J TRU… | [View]
388953684 | Ticktock vaxxies: It's just weak heart, goyim. What a bummer. | [View]
388967999 | You are witnessing the birth of first digital President: https://www.youtube.com/watch?v=UXfePyffll4… | [View]
388945012 | Monkey Pox Thread: What should be the appropriate response to a gay virus that's literally maki… | [View]
388969963 | Covid back, monkeypox goku defeated by cell.x4tk covid mutated to even less deadly than a cold but b… | [View]
388958066 | Official statement of the temporary acting commander of the 'Azov' regiment, Major Mykyta Nadtochii,… | [View]
388972182 | happening trends in the media: >DUDE THE MULTIVERSE >DUDE WW3 AND NUKES >DUDE CERN >DUD… | [View]
388970253 | COOFCOOFCOOFCOOFCOOFCOOFCOOFCOOFCOOFCOOFCOOFCOOFCOOFCOOFCOOFCOOFCOOFCOOFCOOFCOOFCOOF | [View]
388972138 | how is that that every good black is mixed with white genes ? they get smarter that way and still a… | [View]
388968656 | Why do muslims look so dysgenic?: I know its probably happening because of inbreeding since muzzies … | [View]
388970437 | >The Bible says... | [View]
388971930 | Do American politicians care about small towns? | [View]
388963779 | RUSSIA RECRUITING COMMUNIST CHINESE SUPER SOLDIERS TO FIGHT IN UKRAINE: What will Ukraine do against… | [View]
388965284 | Kikes BTFO by Gab Founder Andre Torba: >Naturally I responded to this media onslaught and defende… | [View]
388949971 | Images that broke (((THEM))): This is the thread for simple images that BTFO out of millions of man … | [View]
388971797 | Why are (((they))) like this?: And what can be done about these (((people))), politically? | [View]
388971332 | Why did Jews brainwash Americans into being against socialism? | [View]
388971755 | Covid does not exist, i say this as an unvaxxed man that never catched it despite not giving a fuck … | [View]
388965908 | I want to live on a farm. It has nothing to do with niggers. Being free of niggers is just a bonus. … | [View]
388971070 | Croatian president Zoran Milanović: >'Once Upon a Time in America is a better film than The Godfa… | [View]
388970351 | Is Joe Biden DEAD? WHITEHOUSE DEEPFAKE VIDEOS: I just tried to post this but it rejected my image fi… | [View]
388971364 | Is fighting inherently gay? Wrestling another man. Sweating in another man. Hugging another man. Pen… | [View]
388970917 | It's almost like they hated Kaepernick because of something else... | [View]
388969417 | What kind of shitty drug is this? | [View]
388970632 | How the fuck can one race be so smart, intelligent and beautiful and another race be so stupid, lazy… | [View]
388966654 | 'Poo in the loo, pajeet' >be 1st worlder >buy a loo >it connects to the city sewer system … | [View]
388971534 | Question for Russians: Do you think if it were not for Khruschevite revisionism, the counterrevoluti… | [View]
388930712 | Wholesome | [View]
388966659 | China is gay and full of bugmen. Japan is vastly superior. Fight me. | [View]
388965287 | Why do gooks eat bugs and rats? It's gross. | [View]
388968611 | Threatens to shoot down pelosi and invade taiwan: Nothing happens, china looks even weaker to the wo… | [View]
388968261 | Absolutely degenerate | [View]
388970621 | Why are Zoomers and Millenials the loneliest and the saddest generation? | [View]
388971149 | That guy is a kike!!!: I must support other kike! Nupol is retarded, whats next? 2 party system work… | [View]
388967130 | China will invade Taiwan: >pic related is chinese attack helicopters during excersize >thread… | [View]
388950865 | Circumcision coincides with the downfall of the USA: It is no coincidence that the prevalence of cir… | [View]
388963713 | Biden has Schlong Covid: It's over. https://twitter.com/disclosetv/status/1553450525181493248… | [View]
388964466 | Pat Tillman: Why was he killed? | [View]
388967976 | Which is more likely?: If elected President, Ronald Dion deSantis will a) increase funding to Israel… | [View]
388970989 | safe and effecti-ACKKKKK | [View]
388967111 | Everything but the vaccine: We've been seeing articles coming out linking a rise of health issu… | [View]
388970081 | ww3 never everyone is a spineless coward there are no good men, least of all you faggots | [View]
388970949 | /pol/ humor thread: Keep it on topic | [View]
388970353 | They want to fight against American Hegemony and return the world to a multipolar one with Regional … | [View]
388969616 | White and NatSoc thread: Christkikes and anglos created degeneration and globohomo. That's as o… | [View]
388970891 | Can one of you autistic /pol geniuses create an art generating AI that isn't censored or kiked?… | [View]
388970286 | Can someone please explain WTF she said? https://twitter.com/DanTypo/status/1552717727906893827 I… | [View]
388969814 | Have you ever had a friend like Israel? | [View]
388959890 | US State Department Discriminates Against Whites: Ted Cruz STUNS By Reading Emails Showing State Dep… | [View]
388958564 | /pol/ is playing divegrass today!: >What is the 2022 4chan Summer Cup? The 2022 4chan Summer Cup … | [View]
388970097 | CHICKEN: Where are your aircraft carriers HAHAHAHAHAHAHHAHAHAHAHAHAHAHAHAHHAHA HAHAHAHAHAHAHHAHAHAHA… | [View]
388969753 | Look at this fat faggot manlet you really think Winnie the Pooh has the balls to do anything but lar… | [View]
388965438 | The reason this is happening is because CHina is on the edge of collapsing and the chinese people ar… | [View]
388969474 | Does anyone remember that single mom who got scammed at a buy here pay here lot?: I can't remem… | [View]
388970343 | Hail to the chiefess: Hail to the one we selected as our leader? Lmao believing democracy means the … | [View]
388969670 | Why is it that their best offense is to cast you in their own image? | [View]
388970308 | Zoomer reading problems: What are the political implications that zoomers are only use to small text… | [View]
388969992 | אני גיי: the future of white race is sissy. chang wins black wins spic wins white race gone | [View]
388967815 | HEADS UP: Public service announcement: The mass of land known as People's Republic of China act… | [View]
388951393 | how fucked am i? | [View]
388969957 | Not a single person can possibly believe: This fucking ghoul got 81 million votes , | [View]
388966671 | I have to go to NYC in a week: How bad is it? | [View]
388957294 | The sun is 92 gorillion miles away and this is completely normal, chuds: weather.com/news/weather/vi… | [View]
388960783 | >hyper military based society >tries to convince itself it's the strongest aryan military… | [View]
388969912 | UHHHHHHHH BIDEN BROS…….: oh noes not again! https://www.foxnews.com/politics/biden-tests-positive-co… | [View]
388969847 | >quintuple jabbed world leader gets covid twice in TWO WEEKS >monkey pox finally killing in no… | [View]
388968722 | What the fuck is going on with him?: It all started ten days ago when he accidentally said he has ca… | [View]
388967715 | They're coming for hockey...: Only a sprinkle of niggers in the entire leauge, so they are tryi… | [View]
388967953 | How dangerous is Nuvaxovid/Novavax compared to the Biontech/Pfizer m-RNA?: About to get vaxxed with … | [View]
388967075 | Are drag queens and trannies part of conservatism now? | [View]
388968150 | What did Biden mean by this? How come I'm fine when this winter was supposed to kill me and Bid… | [View]
388961477 | Russians are supporting any movements in the US that are divisive.: https://www.businessinsider.com/… | [View]
388969243 | Greetings frens, based game dev here. I've been lurking for years. Some of you may remember me:… | [View]
388962305 | What Do You Do?: This guy pulls up, and tells you and your family to download a QR code app on your … | [View]
388966637 | Azov gets nuked by their own side while in prison: HIMARS hit a separatist POW camp. 50+ dead prison… | [View]
388966954 | Inside of every white man is a soldier, Murdoch | [View]
388902097 | Russia's planned mapof a decolonized of Europe: Europefags what are your thoughts about the new… | [View]
388954654 | MAJOR HAPPENING. AZOV is preparing assassination of Ukrainian President Zelensky: Why Zelensky is ki… | [View]
388959350 | -WW3 IS STARTING IN TAIWAN-: Are you prepared anon? major happening soon. I hope you stocked up on r… | [View]
388968357 | The amount of registered silver in the comex vaults is now down to 55 million ounces and falling. 'T… | [View]
388962319 | The new holohoax in Canada: Pope says that catholic schools committed genocide: This is even more ab… | [View]
388968600 | Why are Z-mongels pushing communism so hard? Are they all leftist troons/shitskins? | [View]
388968976 | Michael: Was looking for this picture when chatting with a bro and I've noticed Michelle is way… | [View]
388967087 | Is leftism really that bad? | [View]
388968948 | Come on niggers: Yo last minute thread if the nukes go where do us white men go? Other than Valhalla… | [View]
388968558 | Mr bones wild ride: Has only made the first corner ... we haven’t even reach the hill for the drop y… | [View]
388968637 | Oh no Biden bros | [View]
388968353 | The Chinese are coming: https://www.youtube.com/watch?v=tAzUWdleVbg https://www.youtube.com/watch?v=… | [View]
388966918 | Once you pop you just can't stop. And how could you, given that nothing satisfies or indeed can… | [View]
388931470 | Ukrainian women are FUCKING the Russian soldiers KEK: The ukrop nationalist are PISSED OFF https://s… | [View]
388968205 | Based poos: How do Americans/British feel that chadjeets are stealing millions of dollars from their… | [View]
388962537 | Should taxpayer funds be allocated to pay for hormone therapy for transgender people, for instance, … | [View]
388964557 | BLACK. LIVES. MATTER. | [View]
388963284 | Holy war: Reincarnation is REAL and it happens ONLY within racial lines, as the Soul is undying and … | [View]
388948338 | Remind me why free healthcare is bad. | [View]
388935870 | It's over.: >The media is now preparing to make Pelosi a martyr Lmao it's the end.… | [View]
388965191 | I have a bad feeling that America is going to crash and burn very soon... A shinning city upon a hil… | [View]
388964349 | How to exit the loop anons? | [View]
388966059 | Biden tests positive for covid again | [View]
388967531 | That means its working https://www.cnn.com/2022/07/30/politics/joe-biden-covid-19-positive/index.htm… | [View]
388950110 | A Case for Monarchies: Reject Elections, Praise Monarchy. I think that a monarch can represent his … | [View]
388947020 | A study extract in how to lie and improve the cattle compliance for the next one: >BUILDING AND M… | [View]
388953470 | IT’S HAPPENING: You do realize once House Speaker Nancy Pelosi lands in Taiwan: It’s over for the Co… | [View]
388968034 | The Colonizer's Burden: There it is. That's the look. I've seen it for 17 years on fa… | [View]
388966321 | I met Kobach at the Dodge City Republican Steakhouse Rally, and he told our crowd of 150 that he wil… | [View]
388889175 | Why does the world economic forum want to ban tobacco | [View]
388967901 | If you had the chance: If you were given the change, would you bang this women with the joker smile … | [View]
388966065 | Taiwan vs China: *starts WW3* Whats her problem? | [View]
388964797 | Joe Biden tests positive for COVID: Positive AGAIN Vaxxed to the maxxx | [View]
388967270 | >Online records >Oral law Excuse me, but do I not already live in a country where my rights ar… | [View]
388967812 | >the american democratic parties symbol is an ass and you wonder why people don't take you s… | [View]
388953685 | Stop siding with Russia Yesterday mornong in Mykolaiv. People were waiting for a bus to go for a wor… | [View]
388966201 | Joseph Robinette Biden Jr. got COVID again..: a local yellowpress-newspaper reported. https://www.kr… | [View]
388966631 | Chinese nationalist commentator deletes Pelosi tweet after Twitter blocks account: > Prominent Ch… | [View]
388965355 | Daily reminder all of you are American | [View]
388955812 | What (lower) percentage of white christians would America have to have in order to elect an openly J… | [View]
388957308 | My ideas for fixing society: 1) Nationalize housing 2) Universal basic income 3) Carless cities I… | [View]
388964885 | >Anon, It seems you've been living...two lives. Or three or four. or more. We have actually … | [View]
388967115 | What are the political implications of most of the posts here being generated by GPT3? | [View]
388965362 | Kikes and Niggers making a kid beat up a uterus: Look at the nose on that jew holding the piñata w a… | [View]
388963292 | 'I have a message. Speaker of the House ... Nancy Pelosi's plane ... was shot down ... over the… | [View]
388967450 | just another day of mutts using their embassy to police and micromanage how foreign politicians shou… | [View]
388965676 | Leftybros I don't feel so good... | [View]
388958397 | will they get her bros???: I really hope they get her. It would restore my faith in nature for sure… | [View]
388967000 | Republicans made such fools of themselves with Trump nobody will ever take you seriously again | [View]
388962246 | /chug/ - Comfy Happening in Ukraine General #4749: Previous: >>388953295 Timeline /tug/: http… | [View]
388961853 | Schadenfreude Women BTFO http://archive.today/Os2um | [View]
388965576 | Disappeared today in 1975 | [View]
388967135 | Why didn't you pokemon go to the polls... | [View]
388966921 | >CHINANUMBAONE: Hahaha | [View]
388966219 | Does he have your vote this November?: I have a dream. That one day every person in this nation will… | [View]
388967036 | AZOV BATTALION about to CRUCIFY pig Soviet rape baby Chechens: THE AZOV BATALLION WREAKS HAVOC ON RU… | [View]
388965083 | Supranational Nation: What would be preventing the white man from creating a supranational, semi-vir… | [View]
388964350 | President Joe Biden tests positive for Covid-19 again: >>388963597 (OP) >>388908961… | [View]
388959069 | /uhg/ - Ukraine Happening General #3555: Prev:>>388948562 ▶Day: 157 - Daily battlefield assess… | [View]
388963023 | based pfizer killing niggers one at a time: there should be more scamdemics with experimental mRNA v… | [View]
388965456 | Some of you are alright. DON'T come to Europe this Fall!: https://www.youtube.com/watch?v=evTET… | [View]
388964606 | >he won't eat the bugs | [View]
388961803 | How was America once a Christian conservative country, and is now a Godless cultureless shithole? | [View]
388962777 | >Antifa >some of the most intelligent, best educated people in the world mixed in with firebra… | [View]
388963461 | It was literally revealed to me in a dream, the only army that will liberate palestine and slaughter… | [View]
388952097 | People were not able to spend their final minutes with their loved ones due to Covid: They were unab… | [View]
388966137 | If Trump runs again, will he have support from the alt-right? The alt-right helped him get elected i… | [View]
388963818 | Hispanic is a race, wether you're black, white or native american: Or fucking asian | [View]
388957934 | Why haven't we banned cars on Sundays yet? | [View]
388961626 | Khashoggi: Why did they kill him? | [View]
388966339 | China won't do shit | [View]
388956356 | Israel thread: Does the United States have a more faithful friend and ally? | [View]
388966262 | based incel: >be incel >get into law school >ask classmate out on date >she rejects >… | [View]
388966088 | What are the political implications of streaming shrek on twitch???: Does dreamworks shut down your … | [View]
388966056 | >all of my cryptos are losing value why isn't joe biden doing something about this?… | [View]
388960790 | FUCK PELOSI: Those who would miss Pelosi, The Lich, are unAmerican, evil, and brain damaged. Real Am… | [View]
388966051 | >major wins under Trump and even our neo-Fascist uncle that helped escalate the war in Ukraine … | [View]
388965310 | Biden should really take this whole covid thing more seriously | [View]
388964550 | /pcvg/ - PRESIDENTIAL CANDIDATE VALLELY GENERAL - DRESS FOR LESS EDITION: PRESIDENTIAL CANDIDATE MIK… | [View]
388963692 | Indiana passes abortion ban: https://fox59.com/news/national-world/live-blog-senate-votes-on-abortio… | [View]
388964324 | is white islam based? if muslims weren't sandniggers, would /pol/ convert? | [View]
388964989 | >pendejo americano me mucho white! >what are yo-AYAYYAYAYA!!!!… | [View]
388949051 | GOOD MORNING, SUNDAY MORNING: fuck glowies and run them over with your car | [View]
388963071 | Is the Russian state destined for failure? Would it be better off to be broken into smaller countrie… | [View]
388965002 | Jews mad kek: Which one of you faggots bought it? https://www.msn.com/en-xl/news/other/hitlers-watch… | [View]
388965062 | Lt Sulu Loves Being a F*G: When he's not pushing for more Clot Shots, he goes on Howard Stern… | [View]
388948065 | Why do women, especially young women, ruin their bodies like this? >that regret face on the left… | [View]
388965566 | Why are some Russians blond and blue eyed like Nords?: I got this friend who claims to be pure Vikin… | [View]
388957783 | What is pol's official position towards this? | [View]
388964645 | The doctors need to be excuted: This is a crime against humanity and as such the doctors should be c… | [View]
388962064 | ((RUSSIA)) CONSCRIPTING POORFAG GOYIM FODDER EN MASSE TO DIE IN UKRAINE: 75,000 CASUALTIES ALREADY T… | [View]
388961313 | In 1930 there were 3 million jews in whole Europe: 6 millions died in holocaust and 6 millons to thi… | [View]
388965243 | Harry Potter is about whiteness: Here's why Harry Potter is about whiteness >Asians are name… | [View]
388965403 | MADAME PRESIDENT: Say it loud, say it proud! | [View]
388961871 | TRANNIES AND MUNCHIE PARENTS BTFO: /pol/ was right again. As per usual. >The U.S. Food and Drug … | [View]
388964789 | Again.....lmao | [View]
388963474 | (((List for Normies))): Hello pol, am seeking help compiling a comprehensive list of notable Jewish … | [View]
388960852 | >future of the UK: Apologize. | [View]
388955180 | Would you vote for a frilly-dress wearing sissy for President if they shared your exact political vi… | [View]
388964133 | Is this the italian George Floyd? | [View]
388950780 | brit/pol/ --- BANNED MEME edition: >LincolnshireLive: Man arrested on suspicion of murder in conn… | [View]
388963703 | >mindin' own business >see this Wat do?… | [View]
388945675 | *breathes in* HAHAHAHAAHAHAHHAHAHAAHAHAHAHAHAHAHAHAHHAHAHAHAHAHAHAHAHHAHAHAHAHAHAHAHAHAHAHAHHAHAHAHH… | [View]
388959612 | next ukraine thread: where is next ukraine? taiwan? south korea? poland? georgia? where?? | [View]
388957418 | Are there any actual downsides to living in Finland? | [View]
388963786 | Missourians: VOTE DENNIS LEE CHILTON: The primary election is on Tuesday, and Chilton is /our guy/ f… | [View]
388962784 | this nigger stinks like nigger shit. now all zog are puppets but this nigger STINKS https://www.yout… | [View]
388958196 | How come Canada is so much more advanced culturally than USA? >sane gun laws >legal cannabis … | [View]
388963620 | Huge Happening: Joe Biden tests positive for Corona AGAIN | [View]
388964523 | What's his problem?!? | [View]
388959089 | How are Germans taught about this period of their history?: Based or cringe? Inb4 > > >… | [View]
388964513 | Dangerous information )))You((( shouldn't know about: #1: https://archive.is/mZc2F#problem.html… | [View]
388951351 | Anyone else hate how they're replacing plastic with inferior nigger paper everywhere? | [View]
388958193 | There will be no collapse in the sense people think of it.: It’s not going to be like the movies whe… | [View]
388958327 | Are the Indians and Chinese really that smart as they are made out to be if at all? | [View]
388962953 | Can I get monkey pox from toilet seat? There are a ton of fags working night shift at the factory I … | [View]
388964370 | The greatest race war in history.: Jews and Aryans are biological racial enemies. The Jews are a dem… | [View]
388953111 | What are the political implications of rogue County Sherriffs?: >Then, they showed the warrant sa… | [View]
388960547 | russia is so pathetic | [View]
388963010 | Just a photo of todays /pol/ meetup in Hungary. It was fun, too bad for that cigány. | [View]
388963392 | Wait so China literally threatened to shoot down Pelosi's plane for real? Where was that threat… | [View]
388962193 | if hohols get genocided, they deserve it: they allowed a jew to lead their country so hohols deserve… | [View]
388962966 | I get why the left hates Biden, but why does the right?: He’s kept all the same policies as Trump an… | [View]
388961708 | HUNTER BIDEN WON THE $1 BILLION DOLLAR LOTTERY LAST NIGHT: That lucky bastard | [View]
388962588 | ((,Russian)) seems to misrepresent 90% of it's people with every decision: THE ((RUSSIAN LEADER… | [View]
388961906 | Guys what's it gonna take: To make the majority of people see that our 'healthcare' system is j… | [View]
388953635 | Is this skirt too short for a journalist to wear to an Alabama execution?: Female journalist told to… | [View]
388962098 | Woah, Russians look like THIS!?!?! | [View]
388964016 | Right wing research thread: Post studies, infograph, memes and videos that can help redpill normies.… | [View]
388963256 | I assume the girls that go to the bathroom together are all degenerate lesbian trash and avoid them … | [View]
388963686 | Knowledgeable fascists get in here: https://youtu.be/VRfPCEydGkw @ 19:52 Major simplification but it… | [View]
388960096 | Indonesia to start banning western platforms: Is this the beginning of the end of western's dom… | [View]
388959530 | Stop saying the R word. It's misinformation. | [View]
388958339 | Sins, morality and politics: Pride - Feudalism Wrath - Fascism Envy - Communism Greed - Capitalism G… | [View]
388958858 | Which side in the upcoming US-China war should the west back? You know all european factories are lo… | [View]
388956746 | Russian Armed Forces destroy two US M777 howitzers in Zaporozhye region: Russian armed forces destro… | [View]
388962437 | What's your plan for the end of the World /pol/? How will you spend the reminder of your short … | [View]
388963555 | Breast reduction needs to be banned: The only exception is to where the woman can no longer function… | [View]
388963074 | can't Pelosi just talk with Taiwan on the phone and shit? | [View]
388962636 | are you sick and tired of being sick and tired of seeing people you hate everywhere. | [View]
388951076 | You are next. What do you say to Putin? You have one chance. | [View]
388963551 | I took my COVID vax nearly two years ago. I don't have much time left, it's based on- | [View]
388961160 | League streamer going full 1488: This guy is what happens when you take too many redpills lmfao, who… | [View]
388962682 | /RPG/ - Red Pill General: Post a redpill, take a redpill. >pic This is an improved version of the… | [View]
388956937 | Can you feel it? The world is changing. Even reddit normalfags are tired of woke bullshit. They ove… | [View]
388958874 | Ethnic European Unity thread #001: Look Polish anons(And this apply's to all EuropeanVsEuropean… | [View]
388959238 | This confuses and enragles the europoor | [View]
388961478 | What happens if Trump wins and Kamala Harris refuses to certify the electoral college count? | [View]
388962415 | so /pol/ was wrong for the 1000th time...again LMAO: >BRO BROO LOOK AT MY THREAD TALKING ABOUT PE… | [View]
388962887 | Muslims thrive submitting to torture, it's their culture. They ask for it. | [View]
388959862 | Refute Homosexuality without using talmud,torah and bible I give you 10sec. Picrel is gay russian m… | [View]
388955045 | ANYONE WHO REPLIES IN THIS THREAD AUTOMATICALLY DENOUNCES THE TALMUD: Admiration and love of the Ary… | [View]
388962106 | Anya for President. | [View]
388962134 | Would returning to the gold standard save the economy, or is fiat currency more politically viable? | [View]
388939360 | Unvaxxed are spiritual nobility: Unvaxxed bros stop considering yourselfs the same as vaxxed. They a… | [View]
388956126 | Traditionalism: When are nationalists going to realise that the preservation of traditionalism canno… | [View]
388962855 | China has all the same problems as us: >minority groups in China exempt from one child policy … | [View]
388902520 | love and hate countries folks. | [View]
388958324 | do you find this iraqi handsome?: Abu Sufyan, a famous top model in Middle East | [View]
388959587 | Why do white people do this? | [View]
388962412 | What are the political implications of sending these torpedoes to Taiwan? | [View]
388962748 | CHINESE DABBING ON (((MORTGAGES)))mor: What are an implications for global economy if chinese proper… | [View]
388962532 | If You Give A Gay Their Way: Getting sick of gay nonsense? Tired of trans 'people'? Feeling that fag… | [View]
388962470 | The un-*'vaccinated': Political implications of millions of people in the workforce that are now tre… | [View]
388962310 | Why the fuck do people think Pelosi's plane is going to be shot down by China and this will tri… | [View]
388962680 | Can a Finn fill me in on this torture video?: What's going on in this? What's being said? … | [View]
388962162 | Who will win ww3? | [View]
388916247 | PREPARE FOR WAR: https://www.msn.com/en-xl/news/other/pelosi-taiwan-visit-region-tense-as-chinese-na… | [View]
388949792 | Which do you prefer, white or black women? (The name is 'Stacey Abrams' to save you from googling, n… | [View]
388961212 | Belgiumbros: I married a Belgian woman here in the the states. America seems like it’s on it’s last … | [View]
388962421 | /pol humor thread: Ghost of Kyiv, Samuyil Hyde, turned CCP sleeper agent starting WW3 edition | [View]
388957266 | Christianity Series Threads: Part 1 - Saint Peter: I will make a thread every day in which we discus… | [View]
388959592 | I have a message: Nancy Pelosi's plane was shot down over the Sea of Japan....It spun in....The… | [View]
388962521 | LGBTQ is moral.: https://m.youtube.com/watch?v=yunU4q1xSfM&t=668s | [View]
388953566 | Daily Reminder: You need to be archiving, documenting, preserving, and saving all of European histor… | [View]
388960610 | Stop posting about other countries. Only post about American stuff. Will Smith just slapping Chris R… | [View]
388959763 | House passes ban on 'assault' weapons: And changes the definition of assault weapon to any and all s… | [View]
388961757 | ITS HAPPENING: A PIECE OF PELOSI JUST FLEW OVER MY HOUSE | [View]
388961287 | I don't vote. | [View]
388958729 | Trick Answer: Can you answer why pol? Don’t look it up. Answer may surprise you | [View]
388961966 | >we wuz da law | [View]
388947407 | Anything but pay them a living wage: The Republicans have been trying to do away with public educati… | [View]
388961259 | Haha | [View]
388960301 | Why are you against abortion, /pol/??? | [View]
388961234 | Men aren't men anymore: >And that's okay No it isn't, because when times inevitabl… | [View]
388945972 | /ptg/ - PRESIDENT TRUMP GENERAL - DIVERSITY RAPES KIDS EDITION: PRESIDENT DONALD J TRUMP @POTUS45 ht… | [View]
388959691 | Settle down:: Hey, Instead of being mad all the time, how about you settle down? Smoke a fatty, watc… | [View]
388960309 | Why do we build houses?: Whats wrong with just sleeping outdoors? | [View]
388942034 | What is preventing right wingers to organize and start political movements: Well obviously Jews are … | [View]
388959814 | When did you realize that 90% of people have no idea that taxes are what is used to pay for the gove… | [View]
388960634 | bros why cant we track the plane supposedly carrying Nancy Pelosi on flight tracker anymore? we were… | [View]
388957136 | Now, that the dust is settled: Who won? | [View]
388961730 | Why are liberals so mad about Russia arresting drug smugglers?: Has anyone told Biden that weed is s… | [View]
388923806 | Alex Jones Free Speech Systems declares bankruptcy to stall 2nd Trial: Wow he's really getting … | [View]
388961709 | Steven Anderson is a snake and a false teacher | [View]
388947681 | Why you aren't learning French yet, Anon? | [View]
388949877 | Millennials and zoomers are the most laziest pieces of shit this country has ever seen. These indole… | [View]
388961000 | If you're under 30, male and American, you've never known a lived in a world where the pow… | [View]
388961420 | Has anyone caught any Russian news lately? | [View]
388961018 | Ukraine is the 'spiritual' Fourth Reich.: I mean spiritual in the sense of symbolism where the use o… | [View]
388950896 | Yuval Noah Harari Is A Monster (Repost): This post resonated with many lsst night. I will repost to … | [View]
388939723 | WTF? Trump buried his ex wife in a shitty tomb on his golf course | [View]
388959963 | still a poor neet, never playing the stupid tax again: all gambling should be permanently banned wor… | [View]
388959779 | How do we stop wicked jewish leftists from promoting homosexuality in schools? | [View]
388958742 | Remember this white man if the black hemities had not introduced hygiene and cooking to the Greeks t… | [View]
388959051 | 99% of Ztards are shitskins. Are they jealous of Europeans, or do they think shitposting will improv… | [View]
388960617 | Why didn’t IsraelXi do anything, bros?: >Prepares china for war >China says they will shoot do… | [View]
388948704 | DEMOCRATS TURN ON ANARCHISTS: THEY'RE ATTACKING THEIR OWN BASE | [View]
388953295 | /chug/ - Comfy Happening in Ukraine General #4748: Previous: >>388946296 Timeline /tug/: http… | [View]
388960382 | Have you guys received your government-issued Latinas yet? I'm behind on my breeding schedule w… | [View]
388956521 | Euros make fun of the age of content being 18 in US: But here's what I really don't get. W… | [View]
388960386 | Daily reminder Eric Clopper ranted against the jews at Harvard for 2 hours straight https://www.yout… | [View]
388957186 | >Atheism is growing exponentially amongst younger people >zoomers are now more likely to commi… | [View]
388957260 | Are we witnessing the biggest political choke this century? Biden's approval is underwater, inf… | [View]
388952735 | Is she trying to mimic baphomet? | [View]
388960563 | Would you go to war for a jew?: Well, would you? | [View]
388949499 | CHINESE ROCKET REENTER EARTH WITHIN 20 MINUTES: AHHH GET IN HERE!! ROCKET BOOSTER IS EXPECTED TO HIT… | [View]
388959623 | As a believer in God and Christ, how do you justify being on /pol/?: Seriously. I feel immense guilt… | [View]
388954034 | Zelenskyy: 'Americans are ridiculous, decadent, over-fed and I have contempt for them': This is just… | [View]
388952150 | CLOWNWORLD: How do you cope with clownworld? | [View]
388952057 | Russia war crimes: Russia is Le bad okaay? | [View]
388939568 | Baka-anal: Why it exist? Based or Cringe? | [View]
388956670 | Do sanctions even work?: Despite being the most sanctioned nation on earth for the past 40 years, Ir… | [View]
388953544 | Why are they like this | [View]
388950884 | >Wanted to undo 150 years of precedent in a case related to ye olde slaughter-house cases to rest… | [View]
388960274 | Connect the lines goy | [View]
388957506 | Plugged Into The Matrix: Plugged Into The Matrix https://www.youtube.com/watch?v=pEXu3nBoAPM… | [View]
388953043 | Trust the liars! FYI Alzheimers disease is caused by lack of choline. Eat eggs and defund the scienc… | [View]
388908201 | Leftypol Humor thread: Bash the MAGA Fash Edition | [View]
388958195 | Why are so many Toronto doctors dying spontaneously while jogging?: 5 doctors taken down by the kill… | [View]
388947387 | 96% of the US temperature sensors are in the wrong place /pol/ was right again. https://www.heartlan… | [View]
388951031 | You should be afraid of gooks and sandniggers and not imaginary Globohomo and trannies >'they wil… | [View]
388959780 | East/west war is fake: Wake up brothers, they've been playing the same game for centuries. All … | [View]
388931427 | The nigger should fear the italian: A street vendor of Nigerian origins was beaten to death in Civit… | [View]
388958272 | https://en.wikipedia.org/wiki/Talk:Recession >he simps for globohomo >he does it for free Sad!… | [View]
388958979 | Guys, there's a shit ton of low air traffic going on over here, not kidding. Is it finally goin… | [View]
388959712 | Alito calls out Moloch worship in Notre Dam speech.: @22:43 >Suppose a group wanted to revive the… | [View]
388957472 | The Russia/Ukraine conflict is fake: It's all just a dialectic to create an arms race and bring… | [View]
388952092 | Tinder Thread: What are the political implications of men chadfishing whores, and standing them up o… | [View]
388939364 | What are your thoughts on the 200 year old Polish geopolitical goal of an eastern Europe united agai… | [View]
388957491 | Should Trump retire? | [View]
388957912 | Iraq anons are you alright?: What's going on down there? | [View]
388959483 | Things the media is no longer allowed to talk about: In this thread we post things that have been me… | [View]
388950507 | Don't help anybody, don't offer any advice to anyone ever. If you see someone struggling, … | [View]
388957665 | Ancaps utopia is african warlord states: tell me what's the diference between the ancap utopia … | [View]
388959221 | SK, Sweden, Norway and Finland are the only first world nations: South Korea, Norway, Sweden and Fin… | [View]
388948474 | >rants about far left positions every day to an audience of 6 million >all of the modern lefti… | [View]
388959122 | /nsg/ Z National Socialism General Z: >I acknowledge the existence of the Israeli nuclear arsenal… | [View]
388954348 | The Pride police strike again arresting a veteran and Harry Miller of Fair Cop: Good thing some rand… | [View]
388953652 | I'm concerned. RED PILL GENERAL was last when?: Hey pol, It's been a while since I've… | [View]
388953504 | Happening: Pelosi spotted flying over Taiwan | [View]
388953599 | >download >burn >distribute >Remastered original version without the online edits such a… | [View]
388956619 | He thought she was white: Uh.. bros? | [View]
388952431 | >NOOO YOU CANT JUST FOLLOW COMMON SENSE NOOOO >YOU NEED A LOGICAL, REASONED PRAXIS AND A SET O… | [View]
388955648 | NATO appreciation: I get why /pol/ hates them but they are the only thing keeping us all from speaki… | [View]
388948562 | /uhg/ - Ukraine Happening General #3554: Prev:>>388940756 ▶Day: 157 - Daily battlefield assess… | [View]
388948737 | ULTRA MEGA HAPPENING: DOOMSDAY PLANE IS IN THE AIR THIS IS NOT A DRILL https://globe.adsbexchange.co… | [View]
388958348 | Russia isn't commu-: -ACK | [View]
388935206 | DON'T LEAVE YOUR JOB, JUST 'QUIET QUIT': >people are mad about the state of employment, pay,… | [View]
388945541 | >tfw Russian | [View]
388940291 | Why shouldn't Taiwan be independent? | [View]
388957454 | Is this true or a case of no one having comms? | [View]
388954339 | Poland is preparing for war | [View]
388953614 | So, if Amalek is a product of Jewish tribal imagination, don't they really just try to create h… | [View]
388950783 | I think it's kind of weird when people who live in the West claim to be Muslims. It seems to me… | [View]
388955992 | It's a common belief that everyone will be black or brown in the future, but it could be argued… | [View]
388956775 | Journalist threatens GOP: Liberal journalist threatens Republican Party. By claiming that by blockin… | [View]
388936770 | What's wrong with zoomers? | [View]
388938423 | Xi ChinkChong Threatens To Shoot Down Pelosi's Plane On Chinese National Television: Why does t… | [View]
388929148 | Why doesn't /pol/ understand this? | [View]
388952813 | Why would China win?: If bugs are supposed to be smart and cunning then why would all their military… | [View]
388957937 | But muh guns: Let me ban some guns even though we have this overreaching act that allows us to preve… | [View]
388957434 | vaxxed nigger cattle DOOMSDAY by Malone: https://youtu.be/4ngjpR2IObg?t=1186 NGMI its over vaxxies… | [View]
388956124 | Can Biden take on Putin and Xi at the same time? | [View]
388954380 | Stop saying 'Blue MAGA': We are not a cult. | [View]
388953970 | TAIWAN ABOUT TO BECOME PART OF CHINA: XI TO GIVE OUT REUNIFICATION DISCOUNTS ON GPUS!!! | [View]
388951858 | How can we be in a recession if markets are pumping? | [View]
388951009 | Why did airplanes look better and more futuristic back in the day? Now they look just funny and it s… | [View]
388956823 | Who's in Charge?: Who's in charge of America? Is it Biden or Pelosi? Is it the bureaucrats… | [View]
388957120 | Fools | [View]
388941814 | HAPPENING: Fags betray each other over Monkeypox: Was it wrong of Andy Ngo to do this, politically s… | [View]
388957287 | Where to latinx man? | [View]
388949917 | Daily reminder that faggots who accuse anime for pedophilia are the actual pedos | [View]
388956860 | >'It is hoped that the US will be clear-eyed about this. Those who play with fire will be perishe… | [View]
388935317 | Okay, which of you fuckers did it? | [View]
388953922 | WW3 Prologue: China carried out live ammunition rocket strike practice in Fujian: Video with sound: … | [View]
388955463 | Glowies are going to attempt to assassinate him, right? It's obvious at this point they will do… | [View]
388951027 | What do you think Confucius and Socrates would agree on? | [View]
388944587 | GIVE MONKEY POX YOUR ENERGY TO WIPE OUT AS MANY PEDO DEGENERATE FAGS AS POSSIBLE: AAAAAAAAAAAAAAAAAA… | [View]
388957335 | Test: Just a test | [View]
388957221 | I understand the disgust, but I don't share /pol/s hatred for mixed race couples. There's … | [View]
388871008 | /MOG/ - Monkeypox Outbreak General #128 - First Deaths Brazil/Spain: 23,663 cases in 77 countries … | [View]
388952765 | >The House passed the ban by a narrow 217-213 margin on Friday, with the support of Republican co… | [View]
388955950 | You WILL die for Taiwan, you WILL eat the bugs, and you WILL buy an electric vehicle. | [View]
388952457 | are they catholic, orthodoxy or tengrism ? why do they hate romania and serbia ? is vojvodina hungar… | [View]
388946635 | Are dirty rotten kikes responsible for the demolition of low cut jeans?: I think I read somewhere th… | [View]
388956692 | Troonin': https://www.youtube.com/watch?v=9SnxBvH-0Mc > Lady Luck never smiles > So give … | [View]
388952836 | >makes wh*toids activate their genetic fear again like they should | [View]
388953716 | POLAND IS FUCKED: https://twitter.com/RafalMundry/status/1551984753657757697 https://twitter.com/Krz… | [View]
388941040 | La Quinta Columna: >La Quinta Columna - 5G causes COVID-19 symptoms (radiation sickness), seismic… | [View]
388953249 | Incel here: >saw homeless woman with her ass out, pretty big >I want to RAIL her pussy so damn… | [View]
388934252 | ITS HAPPENING WW3: Holy shit bros it’s over https://twitter.com/eha_news/status/1553383235626860549?… | [View]
388956621 | Braindead Neoliberals: They are the source of MUH ETHNIC FOOD meme. They meme about open borders, ta… | [View]
388954319 | so what do you have aginst the freemasons? they seem pretty based: spiritual, belive in a creator. t… | [View]
388944656 | Trump will start the 2nd civil war: And at least half of you will die as a result. When the war kick… | [View]
388948569 | Why is Western France different from Eastern France? | [View]
388942167 | Pelosi enroute to Taiwan: Do you think she is really on the plane? Or is it all a ploy and she is at… | [View]
388949386 | I feel like 9/10 conservatives would willingly vote in Sharia law if you didn't tell them it wa… | [View]
388953836 | DEFCON 3!!!: Indo Pacific Command just went to DEFCON 3 get comfy boys. | [View]
388953878 | Why do they genuinely hate him? Every time he does a show, there’s dozens of articles that come out … | [View]
388954630 | Would you go? I want a Trump Burger! Now i know where to plan my next vacation Also, they must have… | [View]
388947230 | What preditors meant by this? | [View]
388948758 | Russia Today admits they fund BLM: https://www.youtube.com/watch?v=Z2mK1n2d_Wc | [View]
388946629 | Why are Americans so violent compared to Canadians? | [View]
388952095 | Climate change is the only acceptable reason for any catastrophe: Link: https://www.theguardian.com/… | [View]
388952300 | /tehg/ - The Electronic Harassment General: It escalated. They are going to kill me. september 1st: … | [View]
388954914 | >There's nothing wrong with what modern women are attracted to. You're the problem not … | [View]
388903311 | Anons: How are (YOU) personally coping with reality crumbling around you? | [View]
388945190 | Why is Brazil like this?: They are almost as bad as America | [View]
388953094 | Can someone explain to me the Federal Reserve System?: From my understanding, there are 13 FR Banks … | [View]
388955941 | Oh how the mighty have fallen. | [View]
388949306 | IT'S HAPPENING | [View]
388953832 | Der Boomer - racialist?: This corpo-onions-goy chose to join a zoom call in which himself and others… | [View]
388952824 | Why does /pol/ hate progress?: https://www.cnn.com/2022/07/30/politics/us-recession-gpi-what-matters… | [View]
388954478 | Fox news being idiots about “muh sharks is frendly”: Taking yuppies and bare thighed teenage girls s… | [View]
388951165 | what is the evidence for high infant mortality rates in the middle ages?: we all hear about this 'fa… | [View]
388944697 | GET THE FUCK IN HERE: TAIWAN PREPARING FOR WAR https://twitter.com/dwnews/status/1553404298180014080… | [View]
388955629 | I wish we could all fly off into the sunset in one of these things to a place free of degeneracy and… | [View]
388924812 | This modern world.: >Woman has a penis AHAHAHA YES AHAHAHA Faster Mr Bones, I want to stay foreve… | [View]
388950589 | tranny cringe thread: let's get it going | [View]
388951968 | How is Taiwan different than Ukraine?: They are even more globohomo they have legalized gay marriage… | [View]
388954625 | 'Fuck the BLM and Antifa destruction of our big DEM run cities. Those were peaceful protests. On the… | [View]
388955296 | American culture is centered around niggers. They have holidays for niggers. They killed hundreds of… | [View]
388950907 | /pol/ history pics: >Nguyen Ngoc Loan, the national police chief of South Vietnam, executed a Vie… | [View]
388951218 | How do you deal with the existence of NPCs?: My coworker took a 4th booster. He wasn't forced t… | [View]
388942930 | Do you support Iran or Isreal? | [View]
388953561 | Why can’t u be like this guy? A chad. | [View]
388950265 | You vill post schwabs | [View]
388911354 | MAJOR HAPPENING!!!! PELOSI ON THE MOVE WTF: Pelosi is now en route to Asia GUYS WTF IS HAPPENING!!! … | [View]
388948576 | >no one here is happy hmmmm, I wonder why.... | [View]
388955110 | Trump will never be president again. He's done. | [View]
388949871 | https://files.catbox.moe/sxr6nu.mp4 | [View]
388949052 | If police did not count Latino/Hispanic is white in the crime rate... The Anglo Caucasian crime rate… | [View]
388955007 | Political implications of trannies: Should there be laws against this? Tranny’s test freedom of spee… | [View]
388952600 | /arabpol/ - commander saddam edition: The arabs are waking up, for too long have we been asleep, we … | [View]
388950184 | Why do we grow so much alfalfa? | [View]
388942319 | NO SUGAR IN POLAND: NOOOOOOOOOOOOOOooooo, it wasn't supposed to be like this! I never used suga… | [View]
388952063 | no more tendies this year | [View]
388954049 | Hey faggots time to do something: https://youtu.be/vAKdt174Rzo [Open Last thread got buried and nuke… | [View]
388948099 | Florida has a new custom license plate, based or cringe? | [View]
388954756 | chemtrails confirmed: >spraying aerosols into the atmosphere >consequences for the biosphere h… | [View]
388953941 | Remember, anons. Avoid microplastics. >plastic container - glass instead >non-stick pan - cast… | [View]
388954543 | https://www.google.com/amp/s/katv.com/amp/news/nation-world/fda-warns-puberty-blocker-may-cause-brai… | [View]
388929488 | This nigga definitely browses /pol/. This place truly is the last bastion of freedom. They will all … | [View]
388951237 | If being gay is 100% biological than no amount of propaganda can turn kids gay. Virtually nothing ca… | [View]
388954122 | Be sincere, anon, do you take photos like that? | [View]
388950067 | Andrew Yang is the second coming of Christ Jesus | [View]
388950489 | /MPKG/ - Monkeypox-kun General: We have cute anime mascots for the most based diseases in the world.… | [View]
388953172 | Based poles: >be polish >join the EU >move to western Europe as cheap labour >cry about… | [View]
388940815 | Why are so many of you french motherfuckers unable to speak proper english? What the fuck is your pr… | [View]
388946466 | Castration video debunking thread Castration video debunking thread Current facts on castration vide… | [View]
388940542 | I know fuck all about my country's laws and my rights, but if this happens to you, are you lega… | [View]
388954057 | >Spartans knew they were imperialists non-native to Sparta who subjected the native Helots to sla… | [View]
388951547 | Ukraine bros... How can this happen to us | [View]
388915677 | Dutch civil war looming: Trending here, people are sick of the shitskin invasion 200k Kanker gelukzo… | [View]
388935975 | When ISIS did this we bombed the fuck out of Syria: That includes Russia. Now russians are doing it.… | [View]
388953626 | capitalism isnt capitalism anymore: just like liberals aren't liberal. the globohomos HATE free… | [View]
388946296 | /chug/ - Comfy Happening in Ukraine General #4747: Previous: >>388937791 Timeline /tug/: http… | [View]
388952847 | >Dear God, I just got back from killing baby Hitler, but I-I couldn't stop there... let me j… | [View]
388946304 | Who's your choice for 2024? Zion Don or Zion Ron? | [View]
388935729 | >NOOOO YOU CAN’T TAKE OUR WOMEN WITH THEIR CONSENT THAT’S A HUMAN RIGHTS ABUSE AHAHAHAHHAHAHA… | [View]
388952774 | Is the U.S. even worth dying for? I ask myself what I would do if we ever got invaded but then I rem… | [View]
388930843 | Why isn't the government doing anything about >30% of young men being virgin incels? Men and… | [View]
388953038 | Is pic related possible to achieve in the modern age?: I think this is the only way to keep the elit… | [View]
388935195 | >work hard >get 6 figure income >own house >fit >no debt >haven’t had a gf in 6 ye… | [View]
388952065 | >be american >have sex with a 17 year old >get raped to death by niggers in jail while soc… | [View]
388950151 | Homeless people are like hollows: It’s sad but it’s true especially the drug addicts or schizophreni… | [View]
388952326 | He's getting away with it!: >there is a huge chance that be will be acquitted >White peop… | [View]
388949894 | Hans Explain Yourself: >son of a separated mother run to live with his father because he despise … | [View]
388943865 | Doctors are fearing that Natzi Poolosi will have a heart attack on her trip to Asia: Is American pol… | [View]
388951479 | It is every white mans duty to fight to defend Taiwan. it is the right thing to do all americans mu… | [View]
388937769 | Why are middle aged women treated like shit by society?: >Rowan Atkins grew up feeling defined by… | [View]
388947450 | bertybrincel/pol/ - brit/pol/ edition: >Rishi's sinking! Now defeated centrist Tory Tom Tuge… | [View]
388952725 | Based Fellow Countryman: >Philippine 'walis tambo' was spotted on the Capitol during the January … | [View]
388916931 | Gen-Z Can't Answer the Most Basic Questions: Future isn't looking too good bros https://ww… | [View]
388949856 | >Moustache Man Bad | [View]
388950824 | How do you deal with all the shit that is happening and knowing things will only get worse? The psyc… | [View]
388943714 | redpill me about iranian politics | [View]
388952363 | The narrative about recessive white traits diluting over time has been used for demoralization purpo… | [View]
388944512 | What do you think of rap/hiphop music? | [View]
388944508 | Mystery meat congressman calls twitter commenter retarded for not wanting weapons banned: https://tw… | [View]
388950887 | America constantly shouting at other countries to follow rule based world order.: Ameribros... https… | [View]
388950609 | What happens when sneed stops being funny? | [View]
388951911 | Vaxxie dies of joy: What are the political implications of 'suddenly' and 'unexpectedly' young peopl… | [View]
388952114 | Can you tell which post are bots, /pol/?: https://arch.b4k.co/v/thread/607416647 | [View]
388943913 | This is basically /pol/ in video format. | [View]
388952257 | when you realize the goal was never Ukraine | [View]
388950796 | Copyright laws should not exist. | [View]
388951893 | Will we see the End Times in our life time? | [View]
388949545 | Scusi! Mi scusi!! Italiiiii: https://youtu.be/FxJvU93J7t8 | [View]
388950748 | Rainbow Triangle on Top of Taipei 101: I have lived here for over a decade and never seen a party on… | [View]
388949617 | Why do so called right wing and conservative americans simp and defend the ira so much, a group that… | [View]
388951209 | Poyo: Poyo | [View]
388946436 | three german football players have been diagnosed with testicular cancer this year no one knows what… | [View]
388943921 | Jesus *LITERALLY* said Jews where the children of Satan in John 8:44 | [View]
388951892 | Why aren't smaller nations neutral?: Switzerland is filthy rich because of this. Ex. I was just… | [View]
388945709 | Kobe: Did Iran kill Kobe? | [View]
388946005 | Country and People Archetypes: Let's find out the similarities of some countries and peoples. Y… | [View]
388947817 | Stop Homophobia-End faggotry: Homophobia and norms against homosexuality increase the amount of 'fag… | [View]
388939142 | Was Nikola Tesla the antichrist? What if he was the man performing miracles and creating the technol… | [View]
388950206 | Monkeypox: >covid >0.3% fatality rate 'STAY INSIDE!!! IF YOU DON'T WEAR A MASK YOU'R… | [View]
388946893 | WHAT HAVE YOU DONE!?!?!?!?!?!?!: DR FAUCI BTFO HIMSELF https://www.youtube.com/watch?v=MjVVw841eUo… | [View]
388949762 | > america > White KEK! Pick one. | [View]
388951579 | When will this end?: https://www.usatoday.com/story/news/health/2022/07/28/marburg-virus-disease-out… | [View]
388951500 | New O'Connell: https://youtu.be/vAKdt174Rzo Stop watching tranny porn and pay attention niggers… | [View]
388951191 | Polygamy Politics: why do (((they))) not want you having multiple wives? of course it's okay to… | [View]
388949020 | I'm leaving this place. Will you guys be alright? | [View]
388948827 | Imagine not eating the bugs. > Grasshoppers and Crickets >Ants >Termites >Grubs >Woo… | [View]
388898308 | Kraut/pol/ – Angela Merkel edition: Missing her yet? | [View]
388945990 | Glowies are at it again | [View]
388949587 | CHINKS WON'T DO SHIT | [View]
388950844 | New Timeline--New Timeline--New Timeline: Who is going to go first? | [View]
388949392 | Amerimutt Hate Thread: 50% tax rate for Israel and shitskins, no healthcare, living on corn syrup an… | [View]
388951070 | Seung-Hui Cho: Based or Cringe?: What is the /pol/ verdict? | [View]
388950729 | Slavs + Meds + Celts = FAMILY: Germanics = BLACK SHEEP | [View]
388942318 | Why do Russians look so soulless and dead inside? It's like staring into a void. There is no sp… | [View]
388946792 | AUSTRALIA ARE YOU OK????? | [View]
388937263 | Happening: How can you support this!?: And how much money does this Pibbles thing make? Is re-sellin… | [View]
388947258 | Consequence of unfettered capitalism: https://www.theguardian.com/environment/2022/jul/30/tiny-turtl… | [View]
388943085 | Chinese rocket to crash into California: >DEBRIS FROM CHINESE ROCKET LIKELY TO FALL IN NORTHERN C… | [View]
388950701 | I'm in great pain after I overworked myself. Now I don't want to eat, I can't sleep, … | [View]
388948545 | He's right you know | [View]
388950672 | pelosi is bait china is bluffing wait for october/november for things to actually kick off | [View]
388939370 | mexicans complaining about expats: expats are not learning mores and traditions of mexico. expats ar… | [View]
388949739 | Good day, fuck FIsrael: Just a reminder to denounce the Binnish VPN trannies poisoning this board… | [View]
388948745 | CHINA NO | [View]
388950435 | I hate china but they're going to win | [View]
388950494 | >blocks you from buying food heh nothin personnel kid | [View]
388924315 | ITS HAPPENING: https://twitter.com/chaudharyparvez/status/1553349878406729729?s=21&t=vwkmUmUz3vY… | [View]
388949872 | Tap Water Turns You Into Fags: Since tap water has been proven to turn frogs into hermaphrodites and… | [View]
388947460 | Apple deleted mp3s off of my iPhone the other day: Because I didn’t buy them I guess. Seems like pa… | [View]
388950305 | Cyberpandemic and Recession - discuss -: If the cyberpandemic happens this year that means stocks an… | [View]
388947916 | Journos: What the fuck is their problem?? | [View]
388935187 | I have absolutely no sympathy for anyone who took the vaccine: A ton of my extended family has taken… | [View]
388950114 | Friendly Reminder: That long Covid isn't a real thing. Never was. | [View]
388946977 | How long have these guys been around? They seem pretty active t.me/PatriotFrontUpdates | [View]
388948363 | >2-3% of jabbies will have a stroke | [View]
388943533 | How to improve my preps: Just got back from the store. I now have an entire tub full of food in case… | [View]
388934266 | Its being done on purpose.: You are the carbon they want to reduce. Dicsuss. | [View]
388941994 | HAPPENING: You do realize once House Speaker Nancy Pelosi lands in Taiwan: It’s over for the Conserv… | [View]
388949511 | aging population: has this bullshit ever happened? countries develop at different rates you'd t… | [View]
388946567 | America Collapse 2023: You know, Bidens approval rating is lowest, but not lowest yet. On the contr… | [View]
388939161 | RUSSIA JUST PULLED OUT THE SPECIAL FORCES HOHOLS ABOUT TO BE BTFO | [View]
388946178 | Be Balkan nation person >1995: Finish school, commie state collapsing, things look good >199… | [View]
388949787 | God and Satan should just fucking kill themselves and let a random take over. | [View]
388948790 | Globhomo is inevitable but yet unrealizable, the only way to make it a reality is to advance high sp… | [View]
388948454 | Pennsylvania: Based? Unbased? How good of a state is it? Sure there's the liberal hellhole of P… | [View]
388942117 | It's a nothing burger as usual you fucking faggots. | [View]
388947343 | For one last time, America please call off Pelosi's Taiwan visit.: The World War I was triggere… | [View]
388948054 | post facts about Israel: The United States pays for 20% of Israel's military budget while Israe… | [View]
388924335 | i hate anglos so much its unreal: >hitler about to secure the english channel >churchill distr… | [View]
388941641 | Commies/Antifa at Reddit keep thinking that the only way to get rich is inherit it.: Extend this red… | [View]
388949347 | Current events = biblical end times: This is on topic jannie because a large portion of the populati… | [View]
388945795 | >New World Order >White man replaced by nigger They're just fucking trolling us at this p… | [View]
388947462 | >dear leader is hanging out with trannies Oh no no no no no no no no no… | [View]
388940483 | What is happening there ?: Are these good places for when the SHTF ? Uzbekistan and Kazakhstan look… | [View]
388935103 | how will they cheat again in 2024 to keep Trump out: they know that if Trump wins in 2024, then he w… | [View]
388946557 | More than 100 Russian subanimals have been sent to Satan for eternal torture with an ammo dump explo… | [View]
388949164 | WHY WON'T WE SEND UKRAINE 100 TRILLION DOLLARS!!! AND GET THE FUCKING JABS!!! | [View]
388949163 | After Antikythera, all was decadence - until Tesla. Change my mind. | [View]
388928395 | Why do people who support china and russia hate white people and the white people who want to suppor… | [View]
388942189 | All we are saying is give peace a chance.: China, Iran, Syria, North Korea, Russian are alright in m… | [View]
388942390 | Letter from Mr. Bond in jail | [View]
388914887 | What was the most based moment in european history? | [View]
388949007 | blacked.com is an evil thing made by the jews to promote race mixing and bring racial shame, discrim… | [View]
388945336 | >Venus has run away greenhouse effect from co2 >Mars nuked in previous war >Earth is going … | [View]
388946886 | /pol/ humor thread | [View]
388933593 | The Fuhrers watch has sold at auciton: Kikes are so fucking triggered. Like, it's his watch yo… | [View]
388941914 | Remember when Trump got half the country to demand to see king niggers birth certificate?: Whatever … | [View]
388945975 | HAPPENING: Iraq just got CIA'd again!!!: Supporters of the influential Shiite leader Moktada Sa… | [View]
388946639 | Dominant traits: Anyone see black activists like Dr. Umar Johnson calling dominant traits stronger a… | [View]
388936316 | Protestant work ethic: Calvinism (and Protestantism in general) gave Northwestern Europe the edge ov… | [View]
388939522 | You're going to regret staying indoors all day, go enjoy the scenery , take some pictures and g… | [View]
388941136 | UKRAINE WOMEN ARE BRINGING RUSSIANS HOME OH NO OH NO!!!: https://streamable.com/uvblrq | [View]
388948669 | Will y‘all kneel to China and Xi Jinping if they‘ll actually pull this prank of? | [View]
388945111 | LOL, take that, nazis! | [View]
388948598 | Am I right?: Finno-Ugrics are Manchu-Tungus of Europe Manchu-Tungus are Finno-Ugrics of Asia | [View]
388936041 | Many people believe that recessive white traits will only dilute over time, causing white people to … | [View]
388946741 | Is there a direct correlation between the exponential increase in virgin adult males & the milit… | [View]
388947927 | A nigger just walked by infront of my bench >What do | [View]
388940756 | /uhg/ - Ukraine Happening General #3553: Prev:>>388930984 ▶Day: 157 - Daily battlefield assess… | [View]
388947046 | Are you happy to live in modern times? | [View]
388946396 | >We must secure the existence of black people and a future for trans children. Heil Biden.… | [View]
388946799 | Ohhhhh no, I hope someone didn't steal Epstein's list! | [View]
388948223 | Any Mexicans browsing this board? Do people actually look up to wealthy cartels in your country? Wha… | [View]
388943731 | The CIA is preparing something for 1,. August 2 or 3: The CIA is preparing something for 1,. August … | [View]
388948190 | The collected works of Ben Garrison: 4chan is now hosting the collected works of Ben Garrison, enjoy… | [View]
388948145 | OMG PELOSI JUST FLEW OVER MY HOUSE | [View]
388946421 | Why dont Taiwan politicians just meet with Pelosi in America?: why she going there? | [View]
388947664 | GUESS WHO IT'S YOU | [View]
388945840 | The worst country on /pol/ hands down | [View]
388943394 | Amazon secretly based: All this diversity in Tolkien’s fantasy looks pretty bad. Untill you consider… | [View]
388947158 | Why do white women racistly vote? | [View]
388947215 | 4chan is Dysgenic: Low IQ stop wasting human resource... DIE DIE DIE DIE DIE /g/ is bad /pol/ is bad… | [View]
388947748 | Peggy Norman (age 71) in todays WSJ | [View]
388944119 | Bring it back: Make eurosissies shit their pants again | [View]
388947683 | I think we need to make the millitary intervention of the United Nations to reclaim rightful Britain… | [View]
388947572 | IVAN ILYIN - Where can I get ALL his books on PDF in English?: If not in English then Spanish is fin… | [View]
388942990 | Other boards overrun with Libs: /b/ is over run with libs. Some smaller boards still have healthy mi… | [View]
388938081 | Pootan: What's his endgame? How come he was smart and right about anything else, but so fucking… | [View]
388941719 | #RefuseTheDraft: Rich people created China, rich people can fight their own war against China. Worki… | [View]
388879840 | Zelenskyy: 'Americans are ridiculous, decadent, over-fed and I have contempt for them': This is just… | [View]
388944002 | HAPPENING: RUSSIA IS GLOBOHOMO /RIG/ CONFIRMED: Reposting this so you niggerfaggots dont memoryhole … | [View]
388946882 | >Americans better spend their money wisely, or else! | [View]
388935731 | Why are faggots spreading deadly diseases? When are faggots going to be quarantined forever? | [View]
388946827 | American Natives Declare War on Chile: https://youtu.be/JoXLOIkFmUI Surprise, socialist and communis… | [View]
388939455 | Annex Israel to the US: I think I found a way to deal with the Jews. Let's just annex and make … | [View]
388947015 | Why hasn't China done what Korea did and create more media around their babies? Asian babies ar… | [View]
388937649 | ITT: we conjure up meme magic to crash Pelosi's plane with no survivors | [View]
388945789 | how do you feel about columbine: how do you feel about columbine | [View]
388944926 | If you could choose ONLY ONE of these people to get shot down by China who would it be? | [View]
388946046 | Chinese Space Junk To Crash Into California: Just as Pelosi lands in Taiwan. https://www.msn.com/en… | [View]
388946746 | Any Femcels here?: I’d like to talk to some Femcels to learn about you and your culture if that’d be… | [View]
388940335 | You hate me because you envy me.: No amount of demoralization psyops will work on me. I am RICHER th… | [View]
388944007 | Will US-Russian relations improve again in the medium term? | [View]
388946088 | Boring: This is a boring thread. | [View]
388943988 | tap water: How can I drink water without turning gay or growing a womb ? | [View]
388935041 | is it true that aircraft carriers are just floating targets and would all be sank in 20 minutes by h… | [View]
388943236 | Tavistock Gender Identity Development Service (GIDS), England’s hub for child gender reassignment wh… | [View]
388946341 | PLA begins live-fire exercises: Clearly intended to be a deterrent towards Pelosi's Taiwan trip… | [View]
388945845 | Keep fancy nancy pelosi safe: You can say what you want about this lady politically but she has more… | [View]
388941270 | Revive the Anti-Masonic Party: it's time to wake the fuck up.. There is only an illusion of a s… | [View]
388937791 | /chug/ - Comfy Happening in Ukraine General #4746: Previous: >>388930031 Timeline /tug/: http… | [View]
388943709 | Chinx >bank runs >need green covid code to get out of apartment and use public transport (turn… | [View]
388941303 | Say hello to the new Santa Clause.: From Disney+'s new series based on the Tim Allen movie. Le… | [View]
388944764 | Since our mutual raping in WW2 we are basically same people. So let's unite. And let's cal… | [View]
388945599 | Remember folks, if a war breaks out with China...: It's a war for POC to show how brave they ar… | [View]
388943569 | https://www.youtube.com/watch?v=sfuLrny00t4 | [View]
388944912 | When men marry women 10 years older than them is it mommy issues: Are they looking for a mother in t… | [View]
388943825 | Oh NO NO NO! General mobilisation is now declared in Eastern China.: Don’t say we didn’t warn you – … | [View]
388945508 | what are the political implications of working part or full time for a food delivery service? | [View]
388926219 | /ptg/ - PRESIDENT TRUMP GENERAL - IT'S CATURDAY EDITION: PRESIDENT DONALD J TRUMP @POTUS45 http… | [View]
388899292 | NatSoc General: >Read: https://ia801905.us.archive.org/6/items/mein-kampf-by-adolf-hitler-ralph-m… | [View]
388941946 | Monkeypox: Globohomo response to the COVID cold: >you can't work, go to church , or go outsi… | [View]
388917143 | If Nuclear is so great why haven't we switched away from oil?: It isn't because of Big Oil… | [View]
388944868 | >male hairline >4chan: 'bald' >normal foreskin >4chan: 'phimosis' >having fun >4ch… | [View]
388943683 | kys... plz? | [View]
388943758 | this is a model and an actress in 2022, how did we get here? | [View]
388937197 | Think of how many families don't exist simply because raising a child is too expensive for the … | [View]
388945826 | They have figured out how to tax everything, even the poor and stupid. So poor you cant afford to fe… | [View]
388943441 | Half the NPCs in the US HATED trump and his supporters to the point of wanting you dead: how can we … | [View]
388944981 | COUNTDOWN UNT THE WITCH IS DEAD | [View]
388945357 | Why do zoomers take adhd meds even tho some of them don't have adhd? do they not care about the… | [View]
388932267 | What We Learned From Hating the Unvaccinated https://archive.is/76Y88 > The battlefield is still … | [View]
388940607 | I CANT STAND WITH UKRAINE BECAUSE OF U: U niggers for years told me about globalism, kikes, niggers,… | [View]
388940376 | Hello Goy. We have spent a thousand years inserting our tendrils into societies around the world: Yo… | [View]
388941470 | Why do so called right wing and conservative americans simp and defend the ira so much, a group that… | [View]
388945575 | Breaking News: Parts of the Swedish Power Grid may shut down coming winter: >https://www.aftonbla… | [View]
388936884 | How to defend myself against niggers and primates in general: I unfortunately live in the most nigge… | [View]
388944676 | China shooting down Pelosi's plane would unironically do American people a favor | [View]
388940293 | >be me >decide to browse/tv/ >lurk some thread about superman >Couple of anons discuss a… | [View]
388934057 | Brit/pol/: >Rishi's sinking! Now defeated centrist Tory Tom Tugendhat backs Liz Truss to be … | [View]
388943606 | Were sloths ever employed as a part of the army in the past? | [View]
388939031 | Why are you guys so made? | [View]
388917543 | If world war 3 between the west and the BRICS shitholes would start today, which side would you actu… | [View]
388935952 | This is why I hate white people We can't all just be one human race and just vibe and shit Whi… | [View]
388942332 | Can't wait for China to blast that pelosi cunt out the sky lmao: Anyone who defends that bitch … | [View]
388926229 | FSB goon caught running BLM: CIA glowies catch a FSB goon running BLM propaganda, including tasty bi… | [View]
388924687 | What did Ron DeSantis mean by this? | [View]
388944701 | I'm keeping the guns: Militia = all citizens over 17; civs, military, and government officials … | [View]
388941177 | Leave the sinking ship: I'm white but it's time to recognize that we're on a sinking … | [View]
388943708 | >First world countries have bigger and bigger immigrations from retrograde countries >More and… | [View]
388919463 | ITT: We wait for a Chinese happening or cucking: https://fr24.com/SPAR19/2cdb2d95 | [View]
388934504 | >xue hua pio pio bei fei cha-ACK | [View]
388943634 | dylan klebold or eric harris: who was the best | [View]
388934271 | /tg/ - Taiwan General #2: TAIWAN GENERAL Get in here, you life wasting unwashed losers, it's ti… | [View]
388941969 | Alex’s War: Anybody watch this yet? Is it any good. Is there anywhere we can watch it without giving… | [View]
388944506 | >Gamling, what of the little Ukrainian himars? >They were severed with a boxcutter sir...… | [View]
388920523 | Putin is essentially fighting the Luciferian/Satanic Pedophile-Globalists to save America: Putin sai… | [View]
388942287 | GLOBAL WARMING IS NOT RE- ACK: Why is /pol/ always wrong? | [View]
388943815 | Dios Mio: El atrocidad. El ogro de Las Americas. La Luz extenguido. | [View]
388942399 | Why are zoomers and younger so gay?: What have they been teaching them in schools? Exhibit 1: vidre… | [View]
388943314 | Realistically what is the long term outcome for vaxxies?: I don't buy into the two more weeks a… | [View]
388899864 | Muammar Gaddafi: I have recently learnt the truth about this man and his achievement of removing Lib… | [View]
388942165 | Didn't know so many Californians lived in poverty. How can the free market fix this? | [View]
388944005 | isanyoneup: Any non-zoomers remember “isanyoneup”? There was other “revenge porn” sites but that was… | [View]
388941121 | How can you deny that global warming is real now?!!: Poor brits...Gooood saaave our graaacious queen… | [View]
388942020 | Pennsylvaniafag here. Should I vote for pic related? On one hand, he seems based and his opponent is… | [View]
388914834 | Is anyone genuinely afraid of where things are going?: Knowing about the people who control things, … | [View]
388939666 | Indians: Indians will be the future semi-slaves of the world. They already work the worst kind of jo… | [View]
388943447 | Ummm Based?: >Hermaphroditos was the god of Hermaphrodites and effeminates >He was born a rem… | [View]
388943824 | If you had the power to kickstart a war, which one would it be? A civil war in the US, a war between… | [View]
388942039 | POL BTFO'D: BANNER ADVERTISEMENT WRECK POLTARDS AND CHUDCELS!!! | [View]
388942043 | I want to live on a farm | [View]
388943690 | Inb4 false flag | [View]
388937743 | The strength of the Jew is in its diversity. | [View]
388943399 | AMAZING: Is this why memeflags are so prevalent here? | [View]
388943597 | I-is this true /pol/? Maybe it’s time for us to stop being stupid and get the jabs and boosted so we… | [View]
388942672 | This happened for you to soften your hearts. https://www.bbc.com/news/world-latin-america-62356210 L… | [View]
388931624 | The religion that will save the white race: A 2003 survey by Helen A. Berger and her colleagues foun… | [View]
388939377 | When did you realize true rightism is virtually non-existent in the West today and all we have is li… | [View]
388939814 | Did you know if you click woke ads you cost the advertiser money? About $0.50 a click. | [View]
388943424 | When is the pendulum shift happening. I agree with he left on 99% of issues I just can't stand … | [View]
388943170 | Burger here.: Burger here. Why do Russian and Chinese anons focus so much on black penises? | [View]
388943403 | What are the implications of political actors believing we're in the Kali Yuga? Is this just an… | [View]
388942037 | >Eugenics don't work Heh, think again | [View]
388943359 | How does the assault weapon ban of 1994 stand against the assault weapon ban: electric boogaloo 2022… | [View]
388941580 | Ok WTF is happening ? I m getting spammed with PMC shit and I noticed they started pushing shit like… | [View]
388938319 | Copyright should be abolished: I should be able to make my own versions of others works. >But but… | [View]
388940751 | The success of globalism is due to white people. White people are the greatest destroyers of culture… | [View]
388941822 | >tfw china follows through on threat to pelosi | [View]
388934103 | Right now Hispanics are the future of tradition and cultural conservation, but you racists are too r… | [View]
388939831 | china loses either way: >china shoots down the plane one less libtard figure to ruin america and … | [View]
388938402 | Today is the day: It's finally here bros | [View]
388939301 | Ameriburger here: China and Russian anons, let’s be honest, you hate burgers because of how much bet… | [View]
388941276 | Why does AOC keep on winning, /pol/?: You told me she was a laughingstock. But she’s serious, /pol/.… | [View]
388921201 | Why do Russian chuggers have such a hard time accepting nobody in Western Europe supports them?: I h… | [View]
388942421 | The /pol/ police: Is it real thing? Discuss. | [View]
388941756 | Russians are fucking the Ukraine women in occupied regions: And the Ukraine women are bringing the R… | [View]
388932734 | >Sweden and Finland joining NATO >USA sending ATACMS (300km effective range) and more HIMARS … | [View]
388937056 | It's over fascists: The leftwing Democratic Party is now the largest party in Italy for the fir… | [View]
388942893 | dylan klebold or eric harris? | [View]
388941918 | WW3 China Reminder: China's modern success is thanks to the west buying it's plastic. And … | [View]
388939130 | My nigga vlad stealin gold from African Kangs: Um...hello? Based department? https://www.cnn.com/202… | [View]
388942840 | >haven't had gaysex in a week how is /pol/ dealing with monkeypox?… | [View]
388940226 | Can someone give me sources showing kids are being indoctrinated in school: Can someone give me sour… | [View]
388942784 | Lookner predicts Chines Rocket crash in 50min: https://www.youtube.com/watch?v=R5EsQUX09UE… | [View]
388942776 | Eternal Bong Never Learn: In scenes akin to those traditionally associated with authoritarian regime… | [View]
388936972 | The Jewish God is a Donkey: >Alexandria was a central location in the formation of early Christia… | [View]
388927450 | AUS/POL/ - THE VOICE EDITION: >‘If not now, when?’: Albanese unveils plan for Indigenous Voice to… | [View]
388939559 | Ron DeSantis won't be president. Americans have historically elected tall presidents | [View]
388938181 | What do kiwis think about this? | [View]
388941459 | Charging a electric car is expensive compared to fueling up a car with gasoline | [View]
388941847 | The war against fake 'recession' claims: Facebook and Instagram have begun putting fact checking dis… | [View]
388941105 | Some sincere advice for all of you...: I’ve seen a tremendous number of shill, demoralisation, and s… | [View]
388940022 | LEARN HOW TO SAGE, YOU NEWFAG RETARDS!: >muh bbc SAGE >muh what you say wyboi SAGE >muh Vau… | [View]
388932273 | I’m decomposing: I feel like I'm getting dumber every day. I began to notice that I forget half… | [View]
388941017 | Accepting the Holocaust is fake is the first and last redpill. Accept this fact and everything else … | [View]
388923788 | Is Russia really still gonna win this?: The map hasn't moved in months t. hate globohomo but no… | [View]
388941985 | white ppl fire shots over ed edd n eddy: https://youtube.com/watch?v=x8qY7MlLk04 why are they like t… | [View]
388933294 | I can not wait to see Starship fly on a superheavy: I predict that it is going to explode on the lau… | [View]
388937182 | /GPG/ GeoPolitics General #2338 - 'weekend edition': Palestine, Syria, Ukraine, Taiwan, Turkey, Gree… | [View]
388935115 | What is /pol/'s view on patriotic homosexuality? | [View]
388939440 | Is Polish Korean alliance the new Axis? | [View]
388925874 | Whats wrong with this country?: >be ukraine >largest fertile land in europe >largest wheat … | [View]
388935766 | Are you ever just stunned at how cucked Western countries are?: I'm a leaf. Our country is a lo… | [View]
388938455 | How fucked is the market actually?: Prices are going to shit but even worse this is my last year of … | [View]
388938371 | Prove you are not a (((white w*man))) worhsipping POCel infesting this board and say something bad a… | [View]
388940843 | Shouldn’t we want mass war and inflation etc etc?: it would stop invasion of the west and poors(non … | [View]
388941347 | 'The culture of the white race, which led the peoples to the revolution, is subject to disintegratio… | [View]
388941646 | How is it the CDC shut down churches over the COVID-19 'pandemic,' but can't advise homosexuals… | [View]
388929208 | Notice how everyone is on the Ukrainian side in the boxcutter incident.: Let me explain to you why t… | [View]
388938767 | What's the best state to live on a farm? | [View]
388896354 | I live in a country that is 90% brown, and I have a white gf Whats your excuse? | [View]
388940807 | >Jews all are powerfu... | [View]
388930297 | How do we stop Afticans from fucking monkeys? | [View]
388940724 | A Nation of Spirit, not of Blood.: >Daily reminder that Racial Purity Eugenics is heresy and dege… | [View]
388935282 | If using more fertilizer is so bloody hard, why can't we just waste less food instead? | [View]
388938309 | Problem called Indians: Can this world sustain 1.5 billion Indians who are useless/scammers unlike C… | [View]
388914234 | Why do so many idiots study computers?: Most of my male friends are like “yea man computer is the fu… | [View]
388939744 | look at these fucking idiots lol | [View]
388939266 | We have confirmation this happened.: Simon has the texts on Kino Casino https://youtu.be/i9fs34bxoMY… | [View]
388933509 | There are six things that the Lord hates, seven that are an abomination to him: haughty eyes, a lyi… | [View]
388940915 | Western bros... not like this | [View]
388939855 | Polish-Hohol friendship kek They genocided your children And you are feeding millions of their child… | [View]
388940116 | America Understanding thread: ITT: We listen to what Chad and Stacy countries are saying behind our … | [View]
388940054 | He didn't fight for this. | [View]
388927390 | RUSSIAN SOLDIER IS WANTED: Hunt for Russian soldier from 'SSSR' unit that is notorious for… | [View]
388907050 | Historic | [View]
388938834 | FDA Records Show Concern About Vaccine Booster Timelines That “Make No Sense”: We can confirm that t… | [View]
388936644 | what is wrong with food analogies?: the easiest way i explain complex viewpoints to normies is throu… | [View]
388928147 | When will Putin finally activate the REAL russian army?: We all know he's sent some expeditiona… | [View]
388938310 | Why does casapound, italian neofascist movement, have relations with the karen freedom fighters in B… | [View]
388937993 | Welcome to Britain | [View]
388938014 | Walls don't work!: Should we start calling Joe Hadrian now? | [View]
388931615 | Crime in East Germany was 1/10 of capitalist West Germany: Just found this in an old west german enc… | [View]
388912350 | This isn't gonna end well..... | [View]
388937273 | THERE IS NO LEFT-LEANING MEDIA | [View]
388939988 | M00t giving a speech at a BBC rally in 1967: Colorized | [View]
388938906 | What's a recession? | [View]
388937350 | Why do millenial parents always blame teachers when their kids act like faggot retards in school? … | [View]
388937146 | What are the political implication of women's looks as the only redeeming quality they possess?… | [View]
388936735 | ITS HAPPENING!!!: American mutts get ready to be drafted | [View]
388935641 | Stealing from Amazon: Is this based or nah? >>>/g/87937389 https://desuarchive.org/g/thread… | [View]
388939547 | IMAGINE READING TIK TOK's PRIVACY POLICY: AND STILL USING IT https://youtu.be/wtGwlQWqQWs… | [View]
388936299 | Is Learning Another Language Globalist?: I've started learning French. Am I playing into Schwab… | [View]
388937376 | The Medici School and its consequences have been a disaster for the human race. | [View]
388935967 | Redpills and conversion: How do I explain the pointlessness and negative effects of social media and… | [View]

[Return] [Catalog] [Top]

Return Catalog Top

Style:
[Disable Mobile View / Use Desktop Site]
[Enable Mobile View / Use Mobile Site]
All trademarks and copyrights on this page are owned by their respective parties. Images uploaded are the responsibility of the Poster. Comments are owned by the Poster.